# frozen_string_literal: true

module Projects
  class HgrcSetService < BaseService
    UnsafeSetting = Class.new(StandardError)

    def execute
      hepta_section = project.repository.get_hg_heptapod_config(local: true).transform_values { |v| v.to_s }

      inherit = @params.delete(:inherit)
      inherit = project.repository.get_hgrc["inherit"] if inherit.nil?

      # TODO should be done on the API side
      @params.delete(:id)

      @params.each_entry do |k, v|
        hepta_section[k.to_s.tr('_', '-')] = v.to_s
      end
      values = { heptapod: hepta_section }

      Gitlab::AppLogger.info(
        service: "HgrcSetService",
        message: "setting values",
        inherit: inherit,
        values: values,
        current_user_id: current_user&.id,
        project_id: project.id
      )

      begin
        project.repository.set_hgrc(current_user, inherit, values)
      rescue Gitlab::Mercurial::HgGitRepository::InvalidHgSetting
        raise UnsafeSetting(
          "One of the section, items or leaf values contains "\
          "unsafe characters")
      end
    end
  end
end
