# frozen_string_literal: true

class AddHgMirrorTypeToRemoteMirrors < ActiveRecord::Migration[6.0]
  include Gitlab::Database::MigrationHelpers

  DOWNTIME = false

  disable_ddl_transaction!

  HPD_TABLE = :remote_mirrors
  HPD_COLUMN = :hg_mirror_type

  def up
    unless ActiveRecord::Base.connection.column_exists?(HPD_TABLE, HPD_COLUMN)
      # limits on the text data type are pretty useless in PostgreSQL, unless
      # we really want to restrict some user input instead of using a few
      # curated values (we'd better add a constraint for the possible values instead)
      # rubocop:disable Migration/AddLimitToTextColumns
      add_column(HPD_TABLE, HPD_COLUMN, :text, allow_null: true)
    end
  end

  def down
    if ActiveRecord::Base.connection.column_exists?(HPD_TABLE, HPD_COLUMN)
      remove_column(HPD_TABLE, HPD_COLUMN)
    end
  end
end
