# frozen_string_literal: true

task dev: ["dev:setup", "dev:remove_heptapod_legacy_ssh_key"]

namespace :dev do
  desc "GitLab | Dev | Setup developer environment (db, fixtures)"
  task setup: :environment do
    ENV['force'] = 'yes'
    Rake::Task["gitlab:setup"].invoke

    # Make sure DB statistics are up to date.
    ActiveRecord::Base.connection.execute('ANALYZE')

    Rake::Task["gitlab:shell:setup"].invoke
  end

  desc "Remove the SSH key that was used in previous Heptapod versions for hg-git push to Git repo"
  task remove_heptapod_legacy_ssh_key: :environment do
    Key.where(user_id: 1, title: "HG Conversion").delete_all
  end

  desc "GitLab | Dev | Eager load application"
  task load: :environment do
    Rails.configuration.eager_load = true
    Rails.application.eager_load!
  end
end
