---
stage: Plan
group: Project Management
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://about.gitlab.com/handbook/engineering/ux/technical-writing/#designated-technical-writers
---

<!---
  This documentation is auto generated by a script.

  Please do not edit this file directly, check compile_docs task on lib/tasks/gitlab/graphql.rake.
--->

# GraphQL API Resources

This documentation is self-generated based on GitLab current GraphQL schema.

The API can be explored interactively using the [GraphiQL IDE](../index.md#graphiql).

Each table below documents a GraphQL type. Types match loosely to models, but not all
fields and methods on a model are available via GraphQL.

WARNING:
Fields that are deprecated are marked with **{warning-solid}**.
Items (fields, enums, etc) that have been removed according to our [deprecation process](../index.md#deprecation-and-removal-process) can be found
in [Removed Items](../removed_items.md).

<!-- vale gitlab.Spelling = NO -->

## `Query` type

The `Query` type contains the API's top-level entry points for all executable queries.

### `ciApplicationSettings`

CI related settings that apply to the entire instance.

Returns [`CiApplicationSettings`](#ciapplicationsettings).

### `ciConfig`

Get linted and processed contents of a CI config. Should not be requested more than once per request.

Returns [`CiConfig`](#ciconfig).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `content` | [`String!`](#string) | Contents of `.gitlab-ci.yml`. |
| `dryRun` | [`Boolean`](#boolean) | Run pipeline creation simulation, or only do static check. |
| `projectPath` | [`ID!`](#id) | The project of the CI config. |

### `containerRepository`

Find a container repository.

Returns [`ContainerRepositoryDetails`](#containerrepositorydetails).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`ContainerRepositoryID!`](#containerrepositoryid) | The global ID of the container repository. |

### `currentUser`

Get information about current user.

Returns [`User`](#user).

### `designManagement`

Fields related to design management.

Returns [`DesignManagement!`](#designmanagement).

### `devopsAdoptionSegments`

Get configured DevOps adoption segments on the instance.

Returns [`DevopsAdoptionSegmentConnection`](#devopsadoptionsegmentconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `directDescendantsOnly` | [`Boolean`](#boolean) | Limits segments to direct descendants of specified parent. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `parentNamespaceId` | [`NamespaceID`](#namespaceid) | Filter by ancestor namespace. |

### `echo`

Text to echo back.

Returns [`String!`](#string).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `text` | [`String!`](#string) | Text to echo back. |

### `geoNode`

Find a Geo node.

Returns [`GeoNode`](#geonode).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `name` | [`String`](#string) | The name of the Geo node. Defaults to the current Geo node name. |

### `group`

Find a group.

Returns [`Group`](#group).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `fullPath` | [`ID!`](#id) | The full path of the project, group or namespace, e.g., `gitlab-org/gitlab-foss`. |

### `instanceSecurityDashboard`

Fields related to Instance Security Dashboard.

Returns [`InstanceSecurityDashboard`](#instancesecuritydashboard).

### `instanceStatisticsMeasurements`

Get statistics on the instance. Deprecated in 13.10: This field was renamed. Use the `usageTrendsMeasurements` field instead.

Returns [`UsageTrendsMeasurementConnection`](#usagetrendsmeasurementconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `identifier` | [`MeasurementIdentifier!`](#measurementidentifier) | The type of measurement/statistics to retrieve. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `recordedAfter` | [`Time`](#time) | Measurement recorded after this date. |
| `recordedBefore` | [`Time`](#time) | Measurement recorded before this date. |

### `issue`

Find an Issue.

Returns [`Issue`](#issue).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`IssueID!`](#issueid) | The global ID of the Issue. |

### `iteration`

Find an iteration.

Returns [`Iteration`](#iteration).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`IterationID!`](#iterationid) | Find an iteration by its ID. |

### `metadata`

Metadata about GitLab.

Returns [`Metadata`](#metadata).

### `milestone`

Find a milestone.

Returns [`Milestone`](#milestone).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`MilestoneID!`](#milestoneid) | Find a milestone by its ID. |

### `namespace`

Find a namespace.

Returns [`Namespace`](#namespace).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `fullPath` | [`ID!`](#id) | The full path of the project, group or namespace, e.g., `gitlab-org/gitlab-foss`. |

### `package`

Find a package.

Returns [`Package`](#package).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`PackagesPackageID!`](#packagespackageid) | The global ID of the package. |

### `project`

Find a project.

Returns [`Project`](#project).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `fullPath` | [`ID!`](#id) | The full path of the project, group or namespace, e.g., `gitlab-org/gitlab-foss`. |

### `projects`

Find projects visible to the current user.

Returns [`ProjectConnection`](#projectconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `ids` | [`[ID!]`](#id) | Filter projects by IDs. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `membership` | [`Boolean`](#boolean) | Limit projects that the current user is a member of. |
| `search` | [`String`](#string) | Search query for project name, path, or description. |
| `searchNamespaces` | [`Boolean`](#boolean) | Include namespace in project search. |
| `sort` | [`String`](#string) | Sort order of results. |

### `runnerPlatforms`

Supported runner platforms.

Returns [`RunnerPlatformConnection`](#runnerplatformconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |

### `runnerSetup`

Get runner setup instructions.

Returns [`RunnerSetup`](#runnersetup).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `architecture` | [`String!`](#string) | Architecture to generate the instructions for. |
| `groupId` | [`GroupID`](#groupid) | Group to register the runner for. |
| `platform` | [`String!`](#string) | Platform to generate the instructions for. |
| `projectId` | [`ProjectID`](#projectid) | Project to register the runner for. |

### `snippets`

Find Snippets visible to the current user.

Returns [`SnippetConnection`](#snippetconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `authorId` | [`UserID`](#userid) | The ID of an author. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `explore` | [`Boolean`](#boolean) | Explore personal snippets. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `ids` | [`[SnippetID!]`](#snippetid) | Array of global snippet IDs. For example, `gid://gitlab/ProjectSnippet/1`. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `projectId` | [`ProjectID`](#projectid) | The ID of a project. |
| `type` | [`TypeEnum`](#typeenum) | The type of snippet. |
| `visibility` | [`VisibilityScopesEnum`](#visibilityscopesenum) | The visibility of the snippet. |

### `usageTrendsMeasurements`

Get statistics on the instance.

Returns [`UsageTrendsMeasurementConnection`](#usagetrendsmeasurementconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `identifier` | [`MeasurementIdentifier!`](#measurementidentifier) | The type of measurement/statistics to retrieve. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `recordedAfter` | [`Time`](#time) | Measurement recorded after this date. |
| `recordedBefore` | [`Time`](#time) | Measurement recorded before this date. |

### `user`

Find a user.

Returns [`User`](#user).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`UserID`](#userid) | ID of the User. |
| `username` | [`String`](#string) | Username of the User. |

### `users`

Find users.

Returns [`UserConnection`](#userconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `admins` | [`Boolean`](#boolean) | Return only admin users. |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `ids` | [`[ID!]`](#id) | List of user Global IDs. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `search` | [`String`](#string) | Query to search users by name, username, or primary email. |
| `sort` | [`Sort`](#sort) | Sort users by this criteria. |
| `usernames` | [`[String!]`](#string) | List of usernames. |

### `vulnerabilities`

Vulnerabilities reported on projects on the current user's instance security dashboard.

Returns [`VulnerabilityConnection`](#vulnerabilityconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `hasIssues` | [`Boolean`](#boolean) | Returns only the vulnerabilities which have linked issues. |
| `hasResolution` | [`Boolean`](#boolean) | Returns only the vulnerabilities which have been resolved on default branch. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `projectId` | [`[ID!]`](#id) | Filter vulnerabilities by project. |
| `reportType` | [`[VulnerabilityReportType!]`](#vulnerabilityreporttype) | Filter vulnerabilities by report type. |
| `scanner` | [`[String!]`](#string) | Filter vulnerabilities by VulnerabilityScanner.externalId. |
| `severity` | [`[VulnerabilitySeverity!]`](#vulnerabilityseverity) | Filter vulnerabilities by severity. |
| `sort` | [`VulnerabilitySort`](#vulnerabilitysort) | List vulnerabilities by sort order. |
| `state` | [`[VulnerabilityState!]`](#vulnerabilitystate) | Filter vulnerabilities by state. |

### `vulnerabilitiesCountByDay`

Number of vulnerabilities per day for the projects on the current user's instance security dashboard.

Returns [`VulnerabilitiesCountByDayConnection`](#vulnerabilitiescountbydayconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `endDate` | [`ISO8601Date!`](#iso8601date) | Last day for which to fetch vulnerability history. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `startDate` | [`ISO8601Date!`](#iso8601date) | First day for which to fetch vulnerability history. |

### `vulnerabilitiesCountByDayAndSeverity`

Number of vulnerabilities per severity level, per day, for the projects on the current user's instance security dashboard. Deprecated in 13.3: Use `vulnerabilitiesCountByDay`.

Returns [`VulnerabilitiesCountByDayAndSeverityConnection`](#vulnerabilitiescountbydayandseverityconnection).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `after` | [`String`](#string) | Returns the elements in the list that come after the specified cursor. |
| `before` | [`String`](#string) | Returns the elements in the list that come before the specified cursor. |
| `endDate` | [`ISO8601Date!`](#iso8601date) | Last day for which to fetch vulnerability history. |
| `first` | [`Int`](#int) | Returns the first _n_ elements from the list. |
| `last` | [`Int`](#int) | Returns the last _n_ elements from the list. |
| `startDate` | [`ISO8601Date!`](#iso8601date) | First day for which to fetch vulnerability history. |

### `vulnerability`

Find a vulnerability.

Returns [`Vulnerability`](#vulnerability).

#### Arguments

| Name | Type | Description |
| ---- | ---- | ----------- |
| `id` | [`VulnerabilityID!`](#vulnerabilityid) | The Global ID of the Vulnerability. |

## Object types

Object types represent the resources that the GitLab GraphQL API can return.
They contain _fields_. Each field has its own type, which will either be one of the
basic GraphQL [scalar types](https://graphql.org/learn/schema/#scalar-types)
(e.g.: `String` or `Boolean`) or other object types.

For more information, see
[Object Types and Fields](https://graphql.org/learn/schema/#object-types-and-fields)
on `graphql.org`.

### `AccessLevel`

Represents the access level of a relationship between a User and object that it is related to.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `integerValue` | [`Int`](#int) | Integer representation of access level. |
| `stringValue` | [`AccessLevelEnum`](#accesslevelenum) | String representation of access level. |

### `AddAwardEmojiPayload`

Autogenerated return type of AddAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `AddProjectToSecurityDashboardPayload`

Autogenerated return type of AddProjectToSecurityDashboard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `project` | [`Project`](#project) | Project that was added to the Instance Security Dashboard. |

### `AdminSidekiqQueuesDeleteJobsPayload`

Autogenerated return type of AdminSidekiqQueuesDeleteJobs.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `result` | [`DeleteJobsResponse`](#deletejobsresponse) | Information about the status of the deletion request. |

### `AlertManagementAlert`

Describes an alert from the project's Alert Management.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignees` | [`UserConnection`](#userconnection) | Assignees of the alert. |
| `createdAt` | [`Time`](#time) | Timestamp the alert was created. |
| `description` | [`String`](#string) | Description of the alert. |
| `details` | [`JSON`](#json) | Alert details. |
| `detailsUrl` | [`String!`](#string) | The URL of the alert detail page. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `endedAt` | [`Time`](#time) | Timestamp the alert ended. |
| `environment` | [`Environment`](#environment) | Environment for the alert. |
| `eventCount` | [`Int`](#int) | Number of events of this alert. |
| `hosts` | [`[String!]`](#string) | List of hosts the alert came from. |
| `iid` | [`ID!`](#id) | Internal ID of the alert. |
| `issue` | [`Issue`](#issue) | Issue attached to the alert. |
| `issueIid` **{warning-solid}** | [`ID`](#id) | **Deprecated:** Use issue field. Deprecated in 13.10. |
| `metricsDashboardUrl` | [`String`](#string) | URL for metrics embed for the alert. |
| `monitoringTool` | [`String`](#string) | Monitoring tool the alert came from. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `prometheusAlert` | [`PrometheusAlert`](#prometheusalert) | The alert condition for Prometheus. |
| `runbook` | [`String`](#string) | Runbook for the alert as defined in alert details. |
| `service` | [`String`](#string) | Service the alert came from. |
| `severity` | [`AlertManagementSeverity`](#alertmanagementseverity) | Severity of the alert. |
| `startedAt` | [`Time`](#time) | Timestamp the alert was raised. |
| `status` | [`AlertManagementStatus`](#alertmanagementstatus) | Status of the alert. |
| `title` | [`String`](#string) | Title of the alert. |
| `todos` | [`TodoConnection`](#todoconnection) | To-do items of the current user for the alert. |
| `updatedAt` | [`Time`](#time) | Timestamp the alert was last updated. |

### `AlertManagementAlertConnection`

The connection type for AlertManagementAlert.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[AlertManagementAlertEdge]`](#alertmanagementalertedge) | A list of edges. |
| `nodes` | [`[AlertManagementAlert]`](#alertmanagementalert) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `AlertManagementAlertEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`AlertManagementAlert`](#alertmanagementalert) | The item at the end of the edge. |

### `AlertManagementAlertStatusCountsType`

Represents total number of alerts for the represented categories.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `acknowledged` | [`Int`](#int) | Number of alerts with status ACKNOWLEDGED for the project |
| `all` | [`Int`](#int) | Total number of alerts for the project. |
| `ignored` | [`Int`](#int) | Number of alerts with status IGNORED for the project |
| `open` | [`Int`](#int) | Number of alerts with status TRIGGERED or ACKNOWLEDGED for the project. |
| `resolved` | [`Int`](#int) | Number of alerts with status RESOLVED for the project |
| `triggered` | [`Int`](#int) | Number of alerts with status TRIGGERED for the project |

### `AlertManagementHttpIntegration`

An endpoint and credentials used to accept alerts for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Whether the endpoint is currently accepting alerts. |
| `apiUrl` | [`String`](#string) | URL at which Prometheus metrics can be queried to populate the metrics dashboard. |
| `id` | [`ID!`](#id) | ID of the integration. |
| `name` | [`String`](#string) | Name of the integration. |
| `payloadAlertFields` | [`[AlertManagementPayloadAlertField!]`](#alertmanagementpayloadalertfield) | Extract alert fields from payload example for custom mapping. |
| `payloadAttributeMappings` | [`[AlertManagementPayloadAlertMappingField!]`](#alertmanagementpayloadalertmappingfield) | The custom mapping of GitLab alert attributes to fields from the payload_example. |
| `payloadExample` | [`JsonString`](#jsonstring) | The example of an alert payload. |
| `token` | [`String`](#string) | Token used to authenticate alert notification requests. |
| `type` | [`AlertManagementIntegrationType!`](#alertmanagementintegrationtype) | Type of integration. |
| `url` | [`String`](#string) | Endpoint which accepts alert notifications. |

### `AlertManagementHttpIntegrationConnection`

The connection type for AlertManagementHttpIntegration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[AlertManagementHttpIntegrationEdge]`](#alertmanagementhttpintegrationedge) | A list of edges. |
| `nodes` | [`[AlertManagementHttpIntegration]`](#alertmanagementhttpintegration) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `AlertManagementHttpIntegrationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration) | The item at the end of the edge. |

### `AlertManagementIntegrationConnection`

The connection type for AlertManagementIntegration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[AlertManagementIntegrationEdge]`](#alertmanagementintegrationedge) | A list of edges. |
| `nodes` | [`[AlertManagementIntegration]`](#alertmanagementintegration) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `AlertManagementIntegrationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`AlertManagementIntegration`](#alertmanagementintegration) | The item at the end of the edge. |

### `AlertManagementPayloadAlertField`

Parsed field from an alert used for custom mappings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `label` | [`String`](#string) | Human-readable label of the payload path. |
| `path` | [`[String!]`](#string) | Path to value inside payload JSON. |
| `type` | [`AlertManagementPayloadAlertFieldType`](#alertmanagementpayloadalertfieldtype) | Type of the parsed value. |

### `AlertManagementPayloadAlertMappingField`

Parsed field (with its name) from an alert used for custom mappings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `fieldName` | [`AlertManagementPayloadAlertFieldName`](#alertmanagementpayloadalertfieldname) | A GitLab alert field name. |
| `label` | [`String`](#string) | Human-readable label of the payload path. |
| `path` | [`[String!]`](#string) | Path to value inside payload JSON. |
| `type` | [`AlertManagementPayloadAlertFieldType`](#alertmanagementpayloadalertfieldtype) | Type of the parsed value. |

### `AlertManagementPrometheusIntegration`

An endpoint and credentials used to accept Prometheus alerts for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Whether the endpoint is currently accepting alerts. |
| `apiUrl` | [`String`](#string) | URL at which Prometheus metrics can be queried to populate the metrics dashboard. |
| `id` | [`ID!`](#id) | ID of the integration. |
| `name` | [`String`](#string) | Name of the integration. |
| `token` | [`String`](#string) | Token used to authenticate alert notification requests. |
| `type` | [`AlertManagementIntegrationType!`](#alertmanagementintegrationtype) | Type of integration. |
| `url` | [`String`](#string) | Endpoint which accepts alert notifications. |

### `AlertSetAssigneesPayload`

Autogenerated return type of AlertSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | [`AlertManagementAlert`](#alertmanagementalert) | The alert after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue created after mutation. |
| `todo` | [`Todo`](#todo) | The to-do item after mutation. |

### `AlertTodoCreatePayload`

Autogenerated return type of AlertTodoCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | [`AlertManagementAlert`](#alertmanagementalert) | The alert after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue created after mutation. |
| `todo` | [`Todo`](#todo) | The to-do item after mutation. |

### `ApiFuzzingCiConfiguration`

Data associated with configuring API fuzzing scans in GitLab CI.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `scanModes` | [`[ApiFuzzingScanMode!]`](#apifuzzingscanmode) | All available scan modes. |
| `scanProfiles` | [`[ApiFuzzingScanProfile!]`](#apifuzzingscanprofile) | All default scan profiles. |

### `ApiFuzzingCiConfigurationCreatePayload`

Autogenerated return type of ApiFuzzingCiConfigurationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `configurationYaml` | [`String`](#string) | A YAML snippet that can be inserted into the project's `.gitlab-ci.yml` to set up API fuzzing scans. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `gitlabCiYamlEditPath` | [`String`](#string) | The location at which the project's `.gitlab-ci.yml` file can be edited in the browser. |

### `ApiFuzzingScanProfile`

An API Fuzzing scan profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | A short description of the profile. |
| `name` | [`String`](#string) | The unique name of the profile. |
| `yaml` | [`String`](#string) | A syntax highlit HTML representation of the YAML. |

### `AwardEmoji`

An emoji awarded by a user.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String!`](#string) | The emoji description. |
| `emoji` | [`String!`](#string) | The emoji as an icon. |
| `name` | [`String!`](#string) | The emoji name. |
| `unicode` | [`String!`](#string) | The emoji in Unicode. |
| `unicodeVersion` | [`String!`](#string) | The Unicode version for this emoji. |
| `user` | [`User!`](#user) | The user who awarded the emoji. |

### `AwardEmojiAddPayload`

Autogenerated return type of AwardEmojiAdd.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `AwardEmojiConnection`

The connection type for AwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[AwardEmojiEdge]`](#awardemojiedge) | A list of edges. |
| `nodes` | [`[AwardEmoji]`](#awardemoji) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `AwardEmojiEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`AwardEmoji`](#awardemoji) | The item at the end of the edge. |

### `AwardEmojiRemovePayload`

Autogenerated return type of AwardEmojiRemove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `AwardEmojiTogglePayload`

Autogenerated return type of AwardEmojiToggle.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `toggledOn` | [`Boolean!`](#boolean) | Indicates the status of the emoji. True if the toggle awarded the emoji, and false if the toggle removed the emoji. |

### `BaseService`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Indicates if the service is active. |
| `type` | [`String`](#string) | Class name of the service. |

### `Blob`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | [`String!`](#string) | Flat path of the entry. |
| `id` | [`ID!`](#id) | ID of the entry. |
| `lfsOid` | [`String`](#string) | LFS ID of the blob. |
| `mode` | [`String`](#string) | Blob mode in numeric format. |
| `name` | [`String!`](#string) | Name of the entry. |
| `path` | [`String!`](#string) | Path of the entry. |
| `sha` | [`String!`](#string) | Last commit SHA for the entry. |
| `type` | [`EntryType!`](#entrytype) | Type of tree entry. |
| `webPath` | [`String`](#string) | Web path of the blob. |
| `webUrl` | [`String`](#string) | Web URL of the blob. |

### `BlobConnection`

The connection type for Blob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[BlobEdge]`](#blobedge) | A list of edges. |
| `nodes` | [`[Blob]`](#blob) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `BlobEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Blob`](#blob) | The item at the end of the edge. |

### `Board`

Represents a project or group issue board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignee` | [`User`](#user) | The board assignee. |
| `epics` | [`BoardEpicConnection`](#boardepicconnection) | Epics associated with board issues. |
| `hideBacklogList` | [`Boolean`](#boolean) | Whether or not backlog list is hidden. |
| `hideClosedList` | [`Boolean`](#boolean) | Whether or not closed list is hidden. |
| `id` | [`ID!`](#id) | ID (global ID) of the board. |
| `iteration` | [`Iteration`](#iteration) | The board iteration. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels of the board. |
| `lists` | [`BoardListConnection`](#boardlistconnection) | Lists of the board. |
| `milestone` | [`Milestone`](#milestone) | The board milestone. |
| `name` | [`String`](#string) | Name of the board. |
| `webPath` | [`String!`](#string) | Web path of the board. |
| `webUrl` | [`String!`](#string) | Web URL of the board. |
| `weight` | [`Int`](#int) | Weight of the board. |

### `BoardConnection`

The connection type for Board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[BoardEdge]`](#boardedge) | A list of edges. |
| `nodes` | [`[Board]`](#board) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `BoardEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Board`](#board) | The item at the end of the edge. |

### `BoardEpic`

Represents an epic on an issue board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User!`](#user) | Author of the epic. |
| `awardEmoji` | [`AwardEmojiConnection`](#awardemojiconnection) | A list of award emojis associated with the epic. |
| `children` | [`EpicConnection`](#epicconnection) | Children (sub-epics) of the epic. |
| `closedAt` | [`Time`](#time) | Timestamp of when the epic was closed. |
| `confidential` | [`Boolean`](#boolean) | Indicates if the epic is confidential. |
| `createdAt` | [`Time`](#time) | Timestamp of when the epic was created. |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `descendantCounts` | [`EpicDescendantCount`](#epicdescendantcount) | Number of open and closed descendant epics and issues. |
| `descendantWeightSum` | [`EpicDescendantWeights`](#epicdescendantweights) | Total weight of open and closed issues in the epic and its descendants. |
| `description` | [`String`](#string) | Description of the epic. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `downvotes` | [`Int!`](#int) | Number of downvotes the epic has received. |
| `dueDate` | [`Time`](#time) | Due date of the epic. |
| `dueDateFixed` | [`Time`](#time) | Fixed due date of the epic. |
| `dueDateFromMilestones` | [`Time`](#time) | Inherited due date of the epic from milestones. |
| `dueDateIsFixed` | [`Boolean`](#boolean) | Indicates if the due date has been manually set. |
| `events` | [`EventConnection`](#eventconnection) | A list of events associated with the object. |
| `group` | [`Group!`](#group) | Group to which the epic belongs. |
| `hasChildren` | [`Boolean!`](#boolean) | Indicates if the epic has children. |
| `hasIssues` | [`Boolean!`](#boolean) | Indicates if the epic has direct issues. |
| `hasParent` | [`Boolean!`](#boolean) | Indicates if the epic has a parent epic. |
| `healthStatus` | [`EpicHealthStatus`](#epichealthstatus) | Current health status of the epic. |
| `id` | [`ID!`](#id) | ID of the epic. |
| `iid` | [`ID!`](#id) | Internal ID of the epic. |
| `issues` | [`EpicIssueConnection`](#epicissueconnection) | A list of issues associated with the epic. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels assigned to the epic. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `parent` | [`Epic`](#epic) | Parent epic of the epic. |
| `participants` | [`UserConnection`](#userconnection) | List of participants for the epic. |
| `reference` | [`String!`](#string) | Internal reference of the epic. Returned in shortened format by default. |
| `relationPath` | [`String`](#string) | URI path of the epic-issue relationship. |
| `relativePosition` | [`Int`](#int) | The relative position of the epic in the epic tree. |
| `startDate` | [`Time`](#time) | Start date of the epic. |
| `startDateFixed` | [`Time`](#time) | Fixed start date of the epic. |
| `startDateFromMilestones` | [`Time`](#time) | Inherited start date of the epic from milestones. |
| `startDateIsFixed` | [`Boolean`](#boolean) | Indicates if the start date has been manually set. |
| `state` | [`EpicState!`](#epicstate) | State of the epic. |
| `subscribed` | [`Boolean!`](#boolean) | Indicates the currently logged in user is subscribed to the epic. |
| `title` | [`String`](#string) | Title of the epic. |
| `updatedAt` | [`Time`](#time) | Timestamp of when the epic was updated. |
| `upvotes` | [`Int!`](#int) | Number of upvotes the epic has received. |
| `userDiscussionsCount` | [`Int!`](#int) | Number of user discussions in the epic. |
| `userNotesCount` | [`Int!`](#int) | Number of user notes of the epic. |
| `userPermissions` | [`EpicPermissions!`](#epicpermissions) | Permissions for the current user on the resource |
| `userPreferences` | [`BoardEpicUserPreferences`](#boardepicuserpreferences) | User preferences for the epic on the issue board. |
| `webPath` | [`String!`](#string) | Web path of the epic. |
| `webUrl` | [`String!`](#string) | Web URL of the epic. |

### `BoardEpicConnection`

The connection type for BoardEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[BoardEpicEdge]`](#boardepicedge) | A list of edges. |
| `nodes` | [`[BoardEpic]`](#boardepic) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `BoardEpicEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`BoardEpic`](#boardepic) | The item at the end of the edge. |

### `BoardEpicUserPreferences`

Represents user preferences for a board epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collapsed` | [`Boolean!`](#boolean) | Indicates epic should be displayed as collapsed. |

### `BoardList`

Represents a list for an issue board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignee` | [`User`](#user) | Assignee in the list. |
| `collapsed` | [`Boolean`](#boolean) | Indicates if the list is collapsed for this user. |
| `id` | [`ID!`](#id) | ID (global ID) of the list. |
| `issues` | [`IssueConnection`](#issueconnection) | Board issues. |
| `issuesCount` | [`Int`](#int) | Count of issues in the list. |
| `iteration` | [`Iteration`](#iteration) | Iteration of the list. |
| `label` | [`Label`](#label) | Label of the list. |
| `limitMetric` | [`ListLimitMetric`](#listlimitmetric) | The current limit metric for the list. |
| `listType` | [`String!`](#string) | Type of the list. |
| `maxIssueCount` | [`Int`](#int) | Maximum number of issues in the list. |
| `maxIssueWeight` | [`Int`](#int) | Maximum weight of issues in the list. |
| `milestone` | [`Milestone`](#milestone) | Milestone of the list. |
| `position` | [`Int`](#int) | Position of list within the board. |
| `title` | [`String!`](#string) | Title of the list. |
| `totalWeight` | [`Int`](#int) | Total weight of all issues in the list. |

### `BoardListConnection`

The connection type for BoardList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[BoardListEdge]`](#boardlistedge) | A list of edges. |
| `nodes` | [`[BoardList]`](#boardlist) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `BoardListCreatePayload`

Autogenerated return type of BoardListCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `list` | [`BoardList`](#boardlist) | Issue list in the issue board. |

### `BoardListEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`BoardList`](#boardlist) | The item at the end of the edge. |

### `BoardListUpdateLimitMetricsPayload`

Autogenerated return type of BoardListUpdateLimitMetrics.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `list` | [`BoardList`](#boardlist) | The updated list. |

### `Branch`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `commit` | [`Commit`](#commit) | Commit for the branch. |
| `name` | [`String!`](#string) | Name of the branch. |

### `BulkFindOrCreateDevopsAdoptionSegmentsPayload`

Autogenerated return type of BulkFindOrCreateDevopsAdoptionSegments.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `segments` | [`[DevopsAdoptionSegment!]`](#devopsadoptionsegment) | Created segments after mutation. |

### `BurnupChartDailyTotals`

Represents the total number of issues and their weights for a particular day.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completedCount` | [`Int!`](#int) | Number of closed issues as of this day. |
| `completedWeight` | [`Int!`](#int) | Total weight of closed issues as of this day. |
| `date` | [`ISO8601Date!`](#iso8601date) | Date for burnup totals. |
| `scopeCount` | [`Int!`](#int) | Number of issues as of this day. |
| `scopeWeight` | [`Int!`](#int) | Total weight of issues as of this day. |

### `CiApplicationSettings`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `keepLatestArtifact` | [`Boolean`](#boolean) | Whether to keep the latest jobs artifacts. |

### `CiBuildNeed`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | [`String`](#string) | Name of the job we need to complete. |

### `CiBuildNeedConnection`

The connection type for CiBuildNeed.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiBuildNeedEdge]`](#cibuildneededge) | A list of edges. |
| `nodes` | [`[CiBuildNeed]`](#cibuildneed) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiBuildNeedEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiBuildNeed`](#cibuildneed) | The item at the end of the edge. |

### `CiCdSettingsUpdatePayload`

Autogenerated return type of CiCdSettingsUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CiConfig`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `errors` | [`[String!]`](#string) | Linting errors. |
| `mergedYaml` | [`String`](#string) | Merged CI configuration YAML. |
| `stages` | [`CiConfigStageConnection`](#ciconfigstageconnection) | Stages of the pipeline. |
| `status` | [`CiConfigStatus`](#ciconfigstatus) | Status of linting, can be either valid or invalid. |

### `CiConfigGroup`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `jobs` | [`CiConfigJobConnection`](#ciconfigjobconnection) | Jobs in group. |
| `name` | [`String`](#string) | Name of the job group. |
| `size` | [`Int`](#int) | Size of the job group. |

### `CiConfigGroupConnection`

The connection type for CiConfigGroup.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiConfigGroupEdge]`](#ciconfiggroupedge) | A list of edges. |
| `nodes` | [`[CiConfigGroup]`](#ciconfiggroup) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiConfigGroupEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiConfigGroup`](#ciconfiggroup) | The item at the end of the edge. |

### `CiConfigJob`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `afterScript` | [`[String!]`](#string) | Override a set of commands that are executed after the job. |
| `allowFailure` | [`Boolean`](#boolean) | Allow job to fail. |
| `beforeScript` | [`[String!]`](#string) | Override a set of commands that are executed before the job. |
| `environment` | [`String`](#string) | Name of an environment to which the job deploys. |
| `except` | [`CiConfigJobRestriction`](#ciconfigjobrestriction) | Limit when jobs are not created. |
| `groupName` | [`String`](#string) | Name of the job group. |
| `name` | [`String`](#string) | Name of the job. |
| `needs` | [`CiConfigNeedConnection`](#ciconfigneedconnection) | Builds that must complete before the jobs run. |
| `only` | [`CiConfigJobRestriction`](#ciconfigjobrestriction) | Jobs are created when these conditions do not apply. |
| `script` | [`[String!]`](#string) | Shell script that is executed by a runner. |
| `stage` | [`String`](#string) | Name of the job stage. |
| `tags` | [`[String!]`](#string) | List of tags that are used to select a runner. |
| `when` | [`String`](#string) | When to run the job. |

### `CiConfigJobConnection`

The connection type for CiConfigJob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiConfigJobEdge]`](#ciconfigjobedge) | A list of edges. |
| `nodes` | [`[CiConfigJob]`](#ciconfigjob) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiConfigJobEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiConfigJob`](#ciconfigjob) | The item at the end of the edge. |

### `CiConfigJobRestriction`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `refs` | [`[String!]`](#string) | The Git refs the job restriction applies to. |

### `CiConfigNeed`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | [`String`](#string) | Name of the need. |

### `CiConfigNeedConnection`

The connection type for CiConfigNeed.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiConfigNeedEdge]`](#ciconfigneededge) | A list of edges. |
| `nodes` | [`[CiConfigNeed]`](#ciconfigneed) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiConfigNeedEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiConfigNeed`](#ciconfigneed) | The item at the end of the edge. |

### `CiConfigStage`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `groups` | [`CiConfigGroupConnection`](#ciconfiggroupconnection) | Groups of jobs for the stage. |
| `name` | [`String`](#string) | Name of the stage. |

### `CiConfigStageConnection`

The connection type for CiConfigStage.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiConfigStageEdge]`](#ciconfigstageedge) | A list of edges. |
| `nodes` | [`[CiConfigStage]`](#ciconfigstage) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiConfigStageEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiConfigStage`](#ciconfigstage) | The item at the end of the edge. |

### `CiGroup`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedStatus` | [`DetailedStatus`](#detailedstatus) | Detailed status of the group. |
| `jobs` | [`CiJobConnection`](#cijobconnection) | Jobs in group. |
| `name` | [`String`](#string) | Name of the job group. |
| `size` | [`Int`](#int) | Size of the group. |

### `CiGroupConnection`

The connection type for CiGroup.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiGroupEdge]`](#cigroupedge) | A list of edges. |
| `nodes` | [`[CiGroup]`](#cigroup) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiGroupEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiGroup`](#cigroup) | The item at the end of the edge. |

### `CiJob`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `artifacts` | [`CiJobArtifactConnection`](#cijobartifactconnection) | Artifacts generated by the job. |
| `detailedStatus` | [`DetailedStatus`](#detailedstatus) | Detailed status of the job. |
| `duration` | [`Int`](#int) | Duration of the job in seconds. |
| `finishedAt` | [`Time`](#time) | When a job has finished running. |
| `name` | [`String`](#string) | Name of the job. |
| `needs` | [`CiBuildNeedConnection`](#cibuildneedconnection) | References to builds that must complete before the jobs run. |
| `pipeline` | [`Pipeline`](#pipeline) | Pipeline the job belongs to. |
| `scheduledAt` | [`Time`](#time) | Schedule for the build. |

### `CiJobArtifact`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `downloadPath` | [`String`](#string) | URL for downloading the artifact's file. |
| `fileType` | [`JobArtifactFileType`](#jobartifactfiletype) | File type of the artifact. |

### `CiJobArtifactConnection`

The connection type for CiJobArtifact.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiJobArtifactEdge]`](#cijobartifactedge) | A list of edges. |
| `nodes` | [`[CiJobArtifact]`](#cijobartifact) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiJobArtifactEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiJobArtifact`](#cijobartifact) | The item at the end of the edge. |

### `CiJobConnection`

The connection type for CiJob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiJobEdge]`](#cijobedge) | A list of edges. |
| `nodes` | [`[CiJob]`](#cijob) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiJobEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiJob`](#cijob) | The item at the end of the edge. |

### `CiStage`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedStatus` | [`DetailedStatus`](#detailedstatus) | Detailed status of the stage. |
| `groups` | [`CiGroupConnection`](#cigroupconnection) | Group of jobs for the stage. |
| `name` | [`String`](#string) | Name of the stage. |

### `CiStageConnection`

The connection type for CiStage.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CiStageEdge]`](#cistageedge) | A list of edges. |
| `nodes` | [`[CiStage]`](#cistage) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CiStageEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CiStage`](#cistage) | The item at the end of the edge. |

### `ClusterAgent`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp the cluster agent was created. |
| `createdByUser` | [`User`](#user) | User object, containing information about the person who created the agent. |
| `id` | [`ID!`](#id) | ID of the cluster agent. |
| `name` | [`String`](#string) | Name of the cluster agent. |
| `project` | [`Project`](#project) | The project this cluster agent is associated with. |
| `tokens` | [`ClusterAgentTokenConnection`](#clusteragenttokenconnection) | Tokens associated with the cluster agent. |
| `updatedAt` | [`Time`](#time) | Timestamp the cluster agent was updated. |
| `webPath` | [`String`](#string) | Web path of the cluster agent. |

### `ClusterAgentConnection`

The connection type for ClusterAgent.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[ClusterAgentEdge]`](#clusteragentedge) | A list of edges. |
| `nodes` | [`[ClusterAgent]`](#clusteragent) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ClusterAgentDeletePayload`

Autogenerated return type of ClusterAgentDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `ClusterAgentEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ClusterAgent`](#clusteragent) | The item at the end of the edge. |

### `ClusterAgentToken`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clusterAgent` | [`ClusterAgent`](#clusteragent) | Cluster agent this token is associated with. |
| `createdAt` | [`Time`](#time) | Timestamp the token was created. |
| `createdByUser` | [`User`](#user) | The user who created the token. |
| `description` | [`String`](#string) | Description of the token. |
| `id` | [`ClustersAgentTokenID!`](#clustersagenttokenid) | Global ID of the token. |
| `name` | [`String`](#string) | Name given to the token. |

### `ClusterAgentTokenConnection`

The connection type for ClusterAgentToken.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[ClusterAgentTokenEdge]`](#clusteragenttokenedge) | A list of edges. |
| `nodes` | [`[ClusterAgentToken]`](#clusteragenttoken) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ClusterAgentTokenCreatePayload`

Autogenerated return type of ClusterAgentTokenCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `secret` | [`String`](#string) | Token secret value. Make sure you save it - you won't be able to access it again. |
| `token` | [`ClusterAgentToken`](#clusteragenttoken) | Token created after mutation. |

### `ClusterAgentTokenDeletePayload`

Autogenerated return type of ClusterAgentTokenDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `ClusterAgentTokenEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ClusterAgentToken`](#clusteragenttoken) | The item at the end of the edge. |

### `CodeCoverageActivity`

Represents the code coverage activity for a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `averageCoverage` | [`Float`](#float) | Average percentage of the different code coverage results available for the group. |
| `coverageCount` | [`Int`](#int) | Number of different code coverage results available for the group. |
| `date` | [`Date!`](#date) | Date when the code coverage was created. |
| `projectCount` | [`Int`](#int) | Number of projects with code coverage results for the group. |

### `CodeCoverageActivityConnection`

The connection type for CodeCoverageActivity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CodeCoverageActivityEdge]`](#codecoverageactivityedge) | A list of edges. |
| `nodes` | [`[CodeCoverageActivity]`](#codecoverageactivity) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CodeCoverageActivityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CodeCoverageActivity`](#codecoverageactivity) | The item at the end of the edge. |

### `CodeCoverageSummary`

Represents the code coverage summary for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `averageCoverage` | [`Float`](#float) | Average percentage of the different code coverage results available for the project. |
| `coverageCount` | [`Int`](#int) | Number of different code coverage results available. |
| `lastUpdatedOn` | [`Date`](#date) | Latest date when the code coverage was created for the project. |

### `Commit`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User`](#user) | Author of the commit. |
| `authorGravatar` | [`String`](#string) | Commit authors gravatar. |
| `authorName` | [`String`](#string) | Commit authors name. |
| `authoredDate` | [`Time`](#time) | Timestamp of when the commit was authored. |
| `description` | [`String`](#string) | Description of the commit message. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `id` | [`ID!`](#id) | ID (global ID) of the commit. |
| `message` | [`String`](#string) | Raw commit message. |
| `pipelines` | [`PipelineConnection`](#pipelineconnection) | Pipelines of the commit ordered latest first. |
| `sha` | [`String!`](#string) | SHA1 ID of the commit. |
| `shortId` | [`String!`](#string) | Short SHA1 ID of the commit. |
| `signatureHtml` | [`String`](#string) | Rendered HTML of the commit signature. |
| `title` | [`String`](#string) | Title of the commit message. |
| `titleHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `title` |
| `webPath` | [`String!`](#string) | Web path of the commit. |
| `webUrl` | [`String!`](#string) | Web URL of the commit. |

### `CommitConnection`

The connection type for Commit.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CommitEdge]`](#commitedge) | A list of edges. |
| `nodes` | [`[Commit]`](#commit) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CommitCreatePayload`

Autogenerated return type of CommitCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `commit` | [`Commit`](#commit) | The commit after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CommitEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Commit`](#commit) | The item at the end of the edge. |

### `ComplianceFramework`

Represents a ComplianceFramework associated with a Project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `color` | [`String!`](#string) | Hexadecimal representation of compliance framework's label color. |
| `description` | [`String!`](#string) | Description of the compliance framework. |
| `id` | [`ID!`](#id) | Compliance framework ID. |
| `name` | [`String!`](#string) | Name of the compliance framework. |
| `pipelineConfigurationFullPath` | [`String`](#string) | Full path of the compliance pipeline configuration stored in a project repository, such as `.gitlab/.compliance-gitlab-ci.yml@compliance/hipaa` **(ULTIMATE)**. |

### `ComplianceFrameworkConnection`

The connection type for ComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ComplianceFrameworkEdge]`](#complianceframeworkedge) | A list of edges. |
| `nodes` | [`[ComplianceFramework]`](#complianceframework) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ComplianceFrameworkEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ComplianceFramework`](#complianceframework) | The item at the end of the edge. |

### `ComposerMetadata`

Composer metadata.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `composerJson` | [`PackageComposerJsonType!`](#packagecomposerjsontype) | Data of the Composer JSON file. |
| `targetSha` | [`String!`](#string) | Target SHA of the package. |

### `ConfigureSastPayload`

Autogenerated return type of ConfigureSast.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `status` | [`String!`](#string) | Status of creating the commit for the supplied SAST CI configuration. |
| `successPath` | [`String`](#string) | Redirect path to use when the response is successful. |

### `ContainerExpirationPolicy`

A tag expiration policy designed to keep only the images that matter most.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cadence` | [`ContainerExpirationPolicyCadenceEnum!`](#containerexpirationpolicycadenceenum) | This container expiration policy schedule. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the container expiration policy was created. |
| `enabled` | [`Boolean!`](#boolean) | Indicates whether this container expiration policy is enabled. |
| `keepN` | [`ContainerExpirationPolicyKeepEnum`](#containerexpirationpolicykeepenum) | Number of tags to retain. |
| `nameRegex` | [`UntrustedRegexp`](#untrustedregexp) | Tags with names matching this regex pattern will expire. |
| `nameRegexKeep` | [`UntrustedRegexp`](#untrustedregexp) | Tags with names matching this regex pattern will be preserved. |
| `nextRunAt` | [`Time`](#time) | Next time that this container expiration policy will get executed. |
| `olderThan` | [`ContainerExpirationPolicyOlderThanEnum`](#containerexpirationpolicyolderthanenum) | Tags older that this will expire. |
| `updatedAt` | [`Time!`](#time) | Timestamp of when the container expiration policy was updated. |

### `ContainerRepository`

A container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | [`Boolean!`](#boolean) | Can the current user delete the container repository. |
| `createdAt` | [`Time!`](#time) | Timestamp when the container repository was created. |
| `expirationPolicyCleanupStatus` | [`ContainerRepositoryCleanupStatus`](#containerrepositorycleanupstatus) | The tags cleanup status for the container repository. |
| `expirationPolicyStartedAt` | [`Time`](#time) | Timestamp when the cleanup done by the expiration policy was started on the container repository. |
| `id` | [`ID!`](#id) | ID of the container repository. |
| `location` | [`String!`](#string) | URL of the container repository. |
| `name` | [`String!`](#string) | Name of the container repository. |
| `path` | [`String!`](#string) | Path of the container repository. |
| `project` | [`Project!`](#project) | Project of the container registry. |
| `status` | [`ContainerRepositoryStatus`](#containerrepositorystatus) | Status of the container repository. |
| `tagsCount` | [`Int!`](#int) | Number of tags associated with this image. |
| `updatedAt` | [`Time!`](#time) | Timestamp when the container repository was updated. |

### `ContainerRepositoryConnection`

The connection type for ContainerRepository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ContainerRepositoryEdge]`](#containerrepositoryedge) | A list of edges. |
| `nodes` | [`[ContainerRepository]`](#containerrepository) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ContainerRepositoryDetails`

Details of a container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | [`Boolean!`](#boolean) | Can the current user delete the container repository. |
| `createdAt` | [`Time!`](#time) | Timestamp when the container repository was created. |
| `expirationPolicyCleanupStatus` | [`ContainerRepositoryCleanupStatus`](#containerrepositorycleanupstatus) | The tags cleanup status for the container repository. |
| `expirationPolicyStartedAt` | [`Time`](#time) | Timestamp when the cleanup done by the expiration policy was started on the container repository. |
| `id` | [`ID!`](#id) | ID of the container repository. |
| `location` | [`String!`](#string) | URL of the container repository. |
| `name` | [`String!`](#string) | Name of the container repository. |
| `path` | [`String!`](#string) | Path of the container repository. |
| `project` | [`Project!`](#project) | Project of the container registry. |
| `status` | [`ContainerRepositoryStatus`](#containerrepositorystatus) | Status of the container repository. |
| `tags` | [`ContainerRepositoryTagConnection`](#containerrepositorytagconnection) | Tags of the container repository. |
| `tagsCount` | [`Int!`](#int) | Number of tags associated with this image. |
| `updatedAt` | [`Time!`](#time) | Timestamp when the container repository was updated. |

### `ContainerRepositoryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ContainerRepository`](#containerrepository) | The item at the end of the edge. |

### `ContainerRepositoryTag`

A tag from a container repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `canDelete` | [`Boolean!`](#boolean) | Can the current user delete this tag. |
| `createdAt` | [`Time`](#time) | Timestamp when the tag was created. |
| `digest` | [`String`](#string) | Digest of the tag. |
| `location` | [`String!`](#string) | URL of the tag. |
| `name` | [`String!`](#string) | Name of the tag. |
| `path` | [`String!`](#string) | Path of the tag. |
| `revision` | [`String`](#string) | Revision of the tag. |
| `shortRevision` | [`String`](#string) | Short revision of the tag. |
| `totalSize` | [`BigInt`](#bigint) | The size of the tag. |

### `ContainerRepositoryTagConnection`

The connection type for ContainerRepositoryTag.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ContainerRepositoryTagEdge]`](#containerrepositorytagedge) | A list of edges. |
| `nodes` | [`[ContainerRepositoryTag]`](#containerrepositorytag) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ContainerRepositoryTagEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ContainerRepositoryTag`](#containerrepositorytag) | The item at the end of the edge. |

### `CreateAlertIssuePayload`

Autogenerated return type of CreateAlertIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | [`AlertManagementAlert`](#alertmanagementalert) | The alert after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue created after mutation. |
| `todo` | [`Todo`](#todo) | The to-do item after mutation. |

### `CreateAnnotationPayload`

Autogenerated return type of CreateAnnotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `annotation` | [`MetricsDashboardAnnotation`](#metricsdashboardannotation) | The created annotation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateBoardPayload`

Autogenerated return type of CreateBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | [`Board`](#board) | The board after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateBranchPayload`

Autogenerated return type of CreateBranch.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `branch` | [`Branch`](#branch) | Branch after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateClusterAgentPayload`

Autogenerated return type of CreateClusterAgent.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `clusterAgent` | [`ClusterAgent`](#clusteragent) | Cluster agent created after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateComplianceFrameworkPayload`

Autogenerated return type of CreateComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `framework` | [`ComplianceFramework`](#complianceframework) | The created compliance framework. |

### `CreateCustomEmojiPayload`

Autogenerated return type of CreateCustomEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `customEmoji` | [`CustomEmoji`](#customemoji) | The new custom emoji. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateDevopsAdoptionSegmentPayload`

Autogenerated return type of CreateDevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `segment` | [`DevopsAdoptionSegment`](#devopsadoptionsegment) | The segment after mutation. |

### `CreateDiffNotePayload`

Autogenerated return type of CreateDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `CreateEpicPayload`

Autogenerated return type of CreateEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epic` | [`Epic`](#epic) | The created epic. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `CreateImageDiffNotePayload`

Autogenerated return type of CreateImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `CreateIssuePayload`

Autogenerated return type of CreateIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `CreateIterationPayload`

Autogenerated return type of CreateIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `iteration` | [`Iteration`](#iteration) | The created iteration. |

### `CreateNotePayload`

Autogenerated return type of CreateNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `CreateRequirementPayload`

Autogenerated return type of CreateRequirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `requirement` | [`Requirement`](#requirement) | Requirement after mutation. |

### `CreateSnippetPayload`

Autogenerated return type of CreateSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `captchaSiteKey` | [`String`](#string) | The CAPTCHA site key which must be used to render a challenge for the user to solve to obtain a valid captchaResponse value. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `needsCaptchaResponse` | [`Boolean`](#boolean) | Indicates whether the operation was detected as possible spam and not completed. If CAPTCHA is enabled, the request must be resubmitted with a valid CAPTCHA response and spam_log_id included for the operation to be completed. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |
| `snippet` | [`Snippet`](#snippet) | The snippet after mutation. |
| `spam` | [`Boolean`](#boolean) | Indicates whether the operation was detected as definite spam. There is no option to resubmit the request with a CAPTCHA response. |
| `spamLogId` | [`Int`](#int) | The spam log ID which must be passed along with a valid CAPTCHA response for an operation to be completed. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |

### `CreateTestCasePayload`

Autogenerated return type of CreateTestCase.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `testCase` | [`Issue`](#issue) | The test case created. |

### `CustomEmoji`

A custom emoji uploaded by user.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `external` | [`Boolean!`](#boolean) | Whether the emoji is an external link. |
| `id` | [`CustomEmojiID!`](#customemojiid) | The ID of the emoji. |
| `name` | [`String!`](#string) | The name of the emoji. |
| `url` | [`String!`](#string) | The link to file of the emoji. |

### `CustomEmojiConnection`

The connection type for CustomEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[CustomEmojiEdge]`](#customemojiedge) | A list of edges. |
| `nodes` | [`[CustomEmoji]`](#customemoji) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `CustomEmojiEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`CustomEmoji`](#customemoji) | The item at the end of the edge. |

### `DastOnDemandScanCreatePayload`

Autogenerated return type of DastOnDemandScanCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipelineUrl` | [`String`](#string) | URL of the pipeline that was created. |

### `DastProfile`

Represents a DAST Profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `branch` | [`DastProfileBranch`](#dastprofilebranch) | The associated branch. Will always return `null` if `dast_branch_selection` feature flag is disabled. |
| `dastScannerProfile` | [`DastScannerProfile`](#dastscannerprofile) | The associated scanner profile. |
| `dastSiteProfile` | [`DastSiteProfile`](#dastsiteprofile) | The associated site profile. |
| `description` | [`String`](#string) | The description of the scan. |
| `editPath` | [`String`](#string) | Relative web path to the edit page of a profile. |
| `id` | [`DastProfileID!`](#dastprofileid) | ID of the profile. |
| `name` | [`String`](#string) | The name of the profile. |

### `DastProfileBranch`

Represents a DAST Profile Branch.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `exists` | [`Boolean`](#boolean) | Indicates whether or not the branch exists. |
| `name` | [`String`](#string) | The name of the branch. |

### `DastProfileConnection`

The connection type for DastProfile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DastProfileEdge]`](#dastprofileedge) | A list of edges. |
| `nodes` | [`[DastProfile]`](#dastprofile) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DastProfileCreatePayload`

Autogenerated return type of DastProfileCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `dastProfile` | [`DastProfile`](#dastprofile) | The created profile. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipelineUrl` | [`String`](#string) | The URL of the pipeline that was created. Requires `runAfterCreate` to be set to `true`. |

### `DastProfileDeletePayload`

Autogenerated return type of DastProfileDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DastProfileEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DastProfile`](#dastprofile) | The item at the end of the edge. |

### `DastProfileRunPayload`

Autogenerated return type of DastProfileRun.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipelineUrl` | [`String`](#string) | URL of the pipeline that was created. |

### `DastProfileUpdatePayload`

Autogenerated return type of DastProfileUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `dastProfile` | [`DastProfile`](#dastprofile) | The updated profile. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipelineUrl` | [`String`](#string) | The URL of the pipeline that was created. Requires the input argument `runAfterUpdate` to be set to `true` when calling the mutation, otherwise no pipeline will be created. |

### `DastScannerProfile`

Represents a DAST scanner profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `editPath` | [`String`](#string) | Relative web path to the edit page of a scanner profile. |
| `globalId` **{warning-solid}** | [`DastScannerProfileID!`](#dastscannerprofileid) | **Deprecated:** Use `id`. Deprecated in 13.6. |
| `id` | [`DastScannerProfileID!`](#dastscannerprofileid) | ID of the DAST scanner profile. |
| `profileName` | [`String`](#string) | Name of the DAST scanner profile. |
| `referencedInSecurityPolicies` | [`[String!]`](#string) | List of security policy names that are referencing given project. |
| `scanType` | [`DastScanTypeEnum`](#dastscantypeenum) | Indicates the type of DAST scan that will run. Either a Passive Scan or an Active Scan. |
| `showDebugMessages` | [`Boolean!`](#boolean) | Indicates if debug messages should be included in DAST console output. True to include the debug messages. |
| `spiderTimeout` | [`Int`](#int) | The maximum number of minutes allowed for the spider to traverse the site. |
| `targetTimeout` | [`Int`](#int) | The maximum number of seconds allowed for the site under test to respond to a request. |
| `useAjaxSpider` | [`Boolean!`](#boolean) | Indicates if the AJAX spider should be used to crawl the target site. True to run the AJAX spider in addition to the traditional spider, and false to run only the traditional spider. |

### `DastScannerProfileConnection`

The connection type for DastScannerProfile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DastScannerProfileEdge]`](#dastscannerprofileedge) | A list of edges. |
| `nodes` | [`[DastScannerProfile]`](#dastscannerprofile) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DastScannerProfileCreatePayload`

Autogenerated return type of DastScannerProfileCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `globalId` **{warning-solid}** | [`DastScannerProfileID`](#dastscannerprofileid) | **Deprecated:** Use `id`. Deprecated in 13.6. |
| `id` | [`DastScannerProfileID`](#dastscannerprofileid) | ID of the scanner profile. |

### `DastScannerProfileDeletePayload`

Autogenerated return type of DastScannerProfileDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DastScannerProfileEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DastScannerProfile`](#dastscannerprofile) | The item at the end of the edge. |

### `DastScannerProfileUpdatePayload`

Autogenerated return type of DastScannerProfileUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `id` | [`DastScannerProfileID`](#dastscannerprofileid) | ID of the scanner profile. |

### `DastSiteProfile`

Represents a DAST Site Profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `editPath` | [`String`](#string) | Relative web path to the edit page of a site profile. |
| `id` | [`DastSiteProfileID!`](#dastsiteprofileid) | ID of the site profile. |
| `normalizedTargetUrl` | [`String`](#string) | Normalized URL of the target to be scanned. |
| `profileName` | [`String`](#string) | The name of the site profile. |
| `referencedInSecurityPolicies` | [`[String!]`](#string) | List of security policy names that are referencing given project. |
| `targetUrl` | [`String`](#string) | The URL of the target to be scanned. |
| `userPermissions` | [`DastSiteProfilePermissions!`](#dastsiteprofilepermissions) | Permissions for the current user on the resource |
| `validationStatus` | [`DastSiteProfileValidationStatusEnum`](#dastsiteprofilevalidationstatusenum) | The current validation status of the site profile. |

### `DastSiteProfileConnection`

The connection type for DastSiteProfile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DastSiteProfileEdge]`](#dastsiteprofileedge) | A list of edges. |
| `nodes` | [`[DastSiteProfile]`](#dastsiteprofile) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DastSiteProfileCreatePayload`

Autogenerated return type of DastSiteProfileCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `id` | [`DastSiteProfileID`](#dastsiteprofileid) | ID of the site profile. |

### `DastSiteProfileDeletePayload`

Autogenerated return type of DastSiteProfileDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DastSiteProfileEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DastSiteProfile`](#dastsiteprofile) | The item at the end of the edge. |

### `DastSiteProfilePermissions`

Check permissions for the current user on site profile.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createOnDemandDastScan` | [`Boolean!`](#boolean) | Indicates the user can perform `create_on_demand_dast_scan` on this resource |

### `DastSiteProfileUpdatePayload`

Autogenerated return type of DastSiteProfileUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `id` | [`DastSiteProfileID`](#dastsiteprofileid) | ID of the site profile. |

### `DastSiteTokenCreatePayload`

Autogenerated return type of DastSiteTokenCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `id` | [`DastSiteTokenID`](#dastsitetokenid) | ID of the site token. |
| `status` | [`DastSiteProfileValidationStatusEnum`](#dastsiteprofilevalidationstatusenum) | The current validation status of the target. |
| `token` | [`String`](#string) | Token string. |

### `DastSiteValidation`

Represents a DAST Site Validation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | [`DastSiteValidationID!`](#dastsitevalidationid) | Global ID of the site validation. |
| `normalizedTargetUrl` | [`String`](#string) | Normalized URL of the target to be validated. |
| `status` | [`DastSiteProfileValidationStatusEnum!`](#dastsiteprofilevalidationstatusenum) | Status of the site validation. |

### `DastSiteValidationConnection`

The connection type for DastSiteValidation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DastSiteValidationEdge]`](#dastsitevalidationedge) | A list of edges. |
| `nodes` | [`[DastSiteValidation]`](#dastsitevalidation) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DastSiteValidationCreatePayload`

Autogenerated return type of DastSiteValidationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `id` | [`DastSiteValidationID`](#dastsitevalidationid) | ID of the site validation. |
| `status` | [`DastSiteProfileValidationStatusEnum`](#dastsiteprofilevalidationstatusenum) | The current validation status. |

### `DastSiteValidationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DastSiteValidation`](#dastsitevalidation) | The item at the end of the edge. |

### `DastSiteValidationRevokePayload`

Autogenerated return type of DastSiteValidationRevoke.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DeleteAnnotationPayload`

Autogenerated return type of DeleteAnnotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DeleteDevopsAdoptionSegmentPayload`

Autogenerated return type of DeleteDevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DeleteJobsResponse`

The response from the AdminSidekiqQueuesDeleteJobs mutation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completed` | [`Boolean`](#boolean) | Whether or not the entire queue was processed in time; if not, retrying the same request is safe. |
| `deletedJobs` | [`Int`](#int) | The number of matching jobs deleted. |
| `queueSize` | [`Int`](#int) | The queue size after processing. |

### `Design`

A single design.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `diffRefs` | [`DiffRefs!`](#diffrefs) | The diff refs for this design. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `event` | [`DesignVersionEvent!`](#designversionevent) | How this design was changed in the current version. |
| `filename` | [`String!`](#string) | The filename of the design. |
| `fullPath` | [`String!`](#string) | The full path to the design file. |
| `id` | [`ID!`](#id) | The ID of this design. |
| `image` | [`String!`](#string) | The URL of the full-sized image. |
| `imageV432x230` | [`String`](#string) | The URL of the design resized to fit within the bounds of 432x230. This will be `null` if the image has not been generated |
| `issue` | [`Issue!`](#issue) | The issue the design belongs to. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `notesCount` | [`Int!`](#int) | The total count of user-created notes for this design. |
| `project` | [`Project!`](#project) | The project the design belongs to. |
| `versions` | [`DesignVersionConnection!`](#designversionconnection) | All versions related to this design ordered newest first. |

### `DesignAtVersion`

A design pinned to a specific version. The image field reflects the design as of the associated version.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `design` | [`Design!`](#design) | The underlying design. |
| `diffRefs` | [`DiffRefs!`](#diffrefs) | The diff refs for this design. |
| `event` | [`DesignVersionEvent!`](#designversionevent) | How this design was changed in the current version. |
| `filename` | [`String!`](#string) | The filename of the design. |
| `fullPath` | [`String!`](#string) | The full path to the design file. |
| `id` | [`ID!`](#id) | The ID of this design. |
| `image` | [`String!`](#string) | The URL of the full-sized image. |
| `imageV432x230` | [`String`](#string) | The URL of the design resized to fit within the bounds of 432x230. This will be `null` if the image has not been generated |
| `issue` | [`Issue!`](#issue) | The issue the design belongs to. |
| `notesCount` | [`Int!`](#int) | The total count of user-created notes for this design. |
| `project` | [`Project!`](#project) | The project the design belongs to. |
| `version` | [`DesignVersion!`](#designversion) | The version this design-at-versions is pinned to. |

### `DesignAtVersionConnection`

The connection type for DesignAtVersion.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DesignAtVersionEdge]`](#designatversionedge) | A list of edges. |
| `nodes` | [`[DesignAtVersion]`](#designatversion) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DesignAtVersionEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DesignAtVersion`](#designatversion) | The item at the end of the edge. |

### `DesignCollection`

A collection of designs.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `copyState` | [`DesignCollectionCopyState`](#designcollectioncopystate) | Copy state of the design collection. |
| `design` | [`Design`](#design) | Find a specific design. |
| `designAtVersion` | [`DesignAtVersion`](#designatversion) | Find a design as of a version. |
| `designs` | [`DesignConnection!`](#designconnection) | All designs for the design collection. |
| `issue` | [`Issue!`](#issue) | Issue associated with the design collection. |
| `project` | [`Project!`](#project) | Project associated with the design collection. |
| `version` | [`DesignVersion`](#designversion) | A specific version. |
| `versions` | [`DesignVersionConnection!`](#designversionconnection) | All versions related to all designs, ordered newest first. |

### `DesignConnection`

The connection type for Design.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DesignEdge]`](#designedge) | A list of edges. |
| `nodes` | [`[Design]`](#design) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DesignEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Design`](#design) | The item at the end of the edge. |

### `DesignManagement`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `designAtVersion` | [`DesignAtVersion`](#designatversion) | Find a design as of a version. |
| `version` | [`DesignVersion`](#designversion) | Find a version. |

### `DesignManagementDeletePayload`

Autogenerated return type of DesignManagementDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `version` | [`DesignVersion`](#designversion) | The new version in which the designs are deleted. |

### `DesignManagementMovePayload`

Autogenerated return type of DesignManagementMove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `designCollection` | [`DesignCollection`](#designcollection) | The current state of the collection. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DesignManagementUploadPayload`

Autogenerated return type of DesignManagementUpload.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `designs` | [`[Design!]!`](#design) | The designs that were uploaded by the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `skippedDesigns` | [`[Design!]!`](#design) | Any designs that were skipped from the upload due to there being no change to their content since their last version |

### `DesignVersion`

A specific version in which designs were added, modified or deleted.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `designAtVersion` | [`DesignAtVersion!`](#designatversion) | A particular design as of this version, provided it is visible at this version. |
| `designs` | [`DesignConnection!`](#designconnection) | All designs that were changed in the version. |
| `designsAtVersion` | [`DesignAtVersionConnection!`](#designatversionconnection) | All designs that are visible at this version, as of this version. |
| `id` | [`ID!`](#id) | ID of the design version. |
| `sha` | [`ID!`](#id) | SHA of the design version. |

### `DesignVersionConnection`

The connection type for DesignVersion.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DesignVersionEdge]`](#designversionedge) | A list of edges. |
| `nodes` | [`[DesignVersion]`](#designversion) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DesignVersionEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DesignVersion`](#designversion) | The item at the end of the edge. |

### `DestroyBoardListPayload`

Autogenerated return type of DestroyBoardList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `list` | [`BoardList`](#boardlist) | The list after mutation. |

### `DestroyBoardPayload`

Autogenerated return type of DestroyBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | [`Board`](#board) | The board after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DestroyComplianceFrameworkPayload`

Autogenerated return type of DestroyComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DestroyContainerRepositoryPayload`

Autogenerated return type of DestroyContainerRepository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `containerRepository` | [`ContainerRepository!`](#containerrepository) | The container repository policy after scheduling the deletion. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DestroyContainerRepositoryTagsPayload`

Autogenerated return type of DestroyContainerRepositoryTags.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `deletedTagNames` | [`[String!]!`](#string) | Deleted container repository tags. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DestroyNotePayload`

Autogenerated return type of DestroyNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `DestroySnippetPayload`

Autogenerated return type of DestroySnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `snippet` | [`Snippet`](#snippet) | The snippet after mutation. |

### `DetailedStatus`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `action` | [`StatusAction`](#statusaction) | Action information for the status. This includes method, button title, icon, path, and title. |
| `detailsPath` | [`String`](#string) | Path of the details for the status. |
| `favicon` | [`String`](#string) | Favicon of the status. |
| `group` | [`String`](#string) | Group of the status. |
| `hasDetails` | [`Boolean`](#boolean) | Indicates if the status has further details. |
| `icon` | [`String`](#string) | Icon of the status. |
| `label` | [`String`](#string) | Label of the status. |
| `text` | [`String`](#string) | Text of the status. |
| `tooltip` | [`String`](#string) | Tooltip associated with the status. |

### `DevopsAdoptionSegment`

Segment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | [`ID!`](#id) | ID of the segment. |
| `latestSnapshot` | [`DevopsAdoptionSnapshot`](#devopsadoptionsnapshot) | The latest adoption metrics for the segment. |
| `namespace` | [`Namespace`](#namespace) | Segment namespace. |

### `DevopsAdoptionSegmentConnection`

The connection type for DevopsAdoptionSegment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DevopsAdoptionSegmentEdge]`](#devopsadoptionsegmentedge) | A list of edges. |
| `nodes` | [`[DevopsAdoptionSegment]`](#devopsadoptionsegment) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DevopsAdoptionSegmentEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`DevopsAdoptionSegment`](#devopsadoptionsegment) | The item at the end of the edge. |

### `DevopsAdoptionSnapshot`

Snapshot.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `deploySucceeded` | [`Boolean!`](#boolean) | At least one deployment succeeded. |
| `endTime` | [`Time!`](#time) | The end time for the snapshot where the data points were collected. |
| `issueOpened` | [`Boolean!`](#boolean) | At least one issue was opened. |
| `mergeRequestApproved` | [`Boolean!`](#boolean) | At least one merge request was approved. |
| `mergeRequestOpened` | [`Boolean!`](#boolean) | At least one merge request was opened. |
| `pipelineSucceeded` | [`Boolean!`](#boolean) | At least one pipeline succeeded. |
| `recordedAt` | [`Time!`](#time) | The time the snapshot was recorded. |
| `runnerConfigured` | [`Boolean!`](#boolean) | At least one runner was used. |
| `securityScanSucceeded` | [`Boolean!`](#boolean) | At least one security scan succeeded. |
| `startTime` | [`Time!`](#time) | The start time for the snapshot where the data points were collected. |

### `DiffPosition`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `diffRefs` | [`DiffRefs!`](#diffrefs) | Information about the branch, HEAD, and base at the time of commenting. |
| `filePath` | [`String!`](#string) | Path of the file that was changed. |
| `height` | [`Int`](#int) | Total height of the image. |
| `newLine` | [`Int`](#int) | Line on HEAD SHA that was changed. |
| `newPath` | [`String`](#string) | Path of the file on the HEAD SHA. |
| `oldLine` | [`Int`](#int) | Line on start SHA that was changed. |
| `oldPath` | [`String`](#string) | Path of the file on the start SHA. |
| `positionType` | [`DiffPositionType!`](#diffpositiontype) | Type of file the position refers to. |
| `width` | [`Int`](#int) | Total width of the image. |
| `x` | [`Int`](#int) | X position of the note. |
| `y` | [`Int`](#int) | Y position of the note. |

### `DiffRefs`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `baseSha` | [`String`](#string) | Merge base of the branch the comment was made on. |
| `headSha` | [`String!`](#string) | SHA of the HEAD at the time the comment was made. |
| `startSha` | [`String!`](#string) | SHA of the branch being compared against. |

### `DiffStats`

Changes to a single file.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `additions` | [`Int!`](#int) | Number of lines added to this file. |
| `deletions` | [`Int!`](#int) | Number of lines deleted from this file. |
| `path` | [`String!`](#string) | File path, relative to repository root. |

### `DiffStatsSummary`

Aggregated summary of changes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `additions` | [`Int!`](#int) | Number of lines added. |
| `changes` | [`Int!`](#int) | Number of lines changed. |
| `deletions` | [`Int!`](#int) | Number of lines deleted. |
| `fileCount` | [`Int!`](#int) | Number of files changed. |

### `Discussion`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp of the discussion's creation. |
| `id` | [`DiscussionID!`](#discussionid) | ID of this discussion. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes in the discussion. |
| `replyId` | [`DiscussionID!`](#discussionid) | ID used to reply to this discussion. |
| `resolvable` | [`Boolean!`](#boolean) | Indicates if the object can be resolved. |
| `resolved` | [`Boolean!`](#boolean) | Indicates if the object is resolved. |
| `resolvedAt` | [`Time`](#time) | Timestamp of when the object was resolved. |
| `resolvedBy` | [`User`](#user) | User who resolved the object. |

### `DiscussionConnection`

The connection type for Discussion.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[DiscussionEdge]`](#discussionedge) | A list of edges. |
| `nodes` | [`[Discussion]`](#discussion) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `DiscussionEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Discussion`](#discussion) | The item at the end of the edge. |

### `DiscussionToggleResolvePayload`

Autogenerated return type of DiscussionToggleResolve.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `discussion` | [`Discussion`](#discussion) | The discussion after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `DismissVulnerabilityPayload`

Autogenerated return type of DismissVulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after dismissal. |

### `Environment`

Describes where code is deployed for a project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | [`ID!`](#id) | ID of the environment. |
| `latestOpenedMostSevereAlert` | [`AlertManagementAlert`](#alertmanagementalert) | The most severe open alert for the environment. If multiple alerts have equal severity, the most recent is returned. |
| `metricsDashboard` | [`MetricsDashboard`](#metricsdashboard) | Metrics dashboard schema for the environment. |
| `name` | [`String!`](#string) | Human-readable name of the environment. |
| `path` | [`String!`](#string) | The path to the environment. |
| `state` | [`String!`](#string) | State of the environment, for example: available/stopped. |

### `EnvironmentConnection`

The connection type for Environment.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[EnvironmentEdge]`](#environmentedge) | A list of edges. |
| `nodes` | [`[Environment]`](#environment) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `EnvironmentEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Environment`](#environment) | The item at the end of the edge. |

### `EnvironmentsCanaryIngressUpdatePayload`

Autogenerated return type of EnvironmentsCanaryIngressUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `Epic`

Represents an epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User!`](#user) | Author of the epic. |
| `awardEmoji` | [`AwardEmojiConnection`](#awardemojiconnection) | A list of award emojis associated with the epic. |
| `children` | [`EpicConnection`](#epicconnection) | Children (sub-epics) of the epic. |
| `closedAt` | [`Time`](#time) | Timestamp of when the epic was closed. |
| `confidential` | [`Boolean`](#boolean) | Indicates if the epic is confidential. |
| `createdAt` | [`Time`](#time) | Timestamp of when the epic was created. |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `descendantCounts` | [`EpicDescendantCount`](#epicdescendantcount) | Number of open and closed descendant epics and issues. |
| `descendantWeightSum` | [`EpicDescendantWeights`](#epicdescendantweights) | Total weight of open and closed issues in the epic and its descendants. |
| `description` | [`String`](#string) | Description of the epic. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `downvotes` | [`Int!`](#int) | Number of downvotes the epic has received. |
| `dueDate` | [`Time`](#time) | Due date of the epic. |
| `dueDateFixed` | [`Time`](#time) | Fixed due date of the epic. |
| `dueDateFromMilestones` | [`Time`](#time) | Inherited due date of the epic from milestones. |
| `dueDateIsFixed` | [`Boolean`](#boolean) | Indicates if the due date has been manually set. |
| `events` | [`EventConnection`](#eventconnection) | A list of events associated with the object. |
| `group` | [`Group!`](#group) | Group to which the epic belongs. |
| `hasChildren` | [`Boolean!`](#boolean) | Indicates if the epic has children. |
| `hasIssues` | [`Boolean!`](#boolean) | Indicates if the epic has direct issues. |
| `hasParent` | [`Boolean!`](#boolean) | Indicates if the epic has a parent epic. |
| `healthStatus` | [`EpicHealthStatus`](#epichealthstatus) | Current health status of the epic. |
| `id` | [`ID!`](#id) | ID of the epic. |
| `iid` | [`ID!`](#id) | Internal ID of the epic. |
| `issues` | [`EpicIssueConnection`](#epicissueconnection) | A list of issues associated with the epic. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels assigned to the epic. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `parent` | [`Epic`](#epic) | Parent epic of the epic. |
| `participants` | [`UserConnection`](#userconnection) | List of participants for the epic. |
| `reference` | [`String!`](#string) | Internal reference of the epic. Returned in shortened format by default. |
| `relationPath` | [`String`](#string) | URI path of the epic-issue relationship. |
| `relativePosition` | [`Int`](#int) | The relative position of the epic in the epic tree. |
| `startDate` | [`Time`](#time) | Start date of the epic. |
| `startDateFixed` | [`Time`](#time) | Fixed start date of the epic. |
| `startDateFromMilestones` | [`Time`](#time) | Inherited start date of the epic from milestones. |
| `startDateIsFixed` | [`Boolean`](#boolean) | Indicates if the start date has been manually set. |
| `state` | [`EpicState!`](#epicstate) | State of the epic. |
| `subscribed` | [`Boolean!`](#boolean) | Indicates the currently logged in user is subscribed to the epic. |
| `title` | [`String`](#string) | Title of the epic. |
| `updatedAt` | [`Time`](#time) | Timestamp of when the epic was updated. |
| `upvotes` | [`Int!`](#int) | Number of upvotes the epic has received. |
| `userDiscussionsCount` | [`Int!`](#int) | Number of user discussions in the epic. |
| `userNotesCount` | [`Int!`](#int) | Number of user notes of the epic. |
| `userPermissions` | [`EpicPermissions!`](#epicpermissions) | Permissions for the current user on the resource |
| `webPath` | [`String!`](#string) | Web path of the epic. |
| `webUrl` | [`String!`](#string) | Web URL of the epic. |

### `EpicAddIssuePayload`

Autogenerated return type of EpicAddIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epic` | [`Epic`](#epic) | The epic after mutation. |
| `epicIssue` | [`EpicIssue`](#epicissue) | The epic-issue relation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `EpicBoard`

Represents an epic board.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `hideBacklogList` | [`Boolean`](#boolean) | Whether or not backlog list is hidden. |
| `hideClosedList` | [`Boolean`](#boolean) | Whether or not closed list is hidden. |
| `id` | [`BoardsEpicBoardID!`](#boardsepicboardid) | Global ID of the epic board. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels of the board. |
| `lists` | [`EpicListConnection`](#epiclistconnection) | Epic board lists. |
| `name` | [`String`](#string) | Name of the epic board. |
| `webPath` | [`String!`](#string) | Web path of the epic board. |
| `webUrl` | [`String!`](#string) | Web URL of the epic board. |

### `EpicBoardConnection`

The connection type for EpicBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[EpicBoardEdge]`](#epicboardedge) | A list of edges. |
| `nodes` | [`[EpicBoard]`](#epicboard) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `EpicBoardCreatePayload`

Autogenerated return type of EpicBoardCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epicBoard` | [`EpicBoard`](#epicboard) | The created epic board. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `EpicBoardEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`EpicBoard`](#epicboard) | The item at the end of the edge. |

### `EpicBoardListCreatePayload`

Autogenerated return type of EpicBoardListCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `list` | [`EpicList`](#epiclist) | Epic list in the epic board. |

### `EpicBoardUpdatePayload`

Autogenerated return type of EpicBoardUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epicBoard` | [`EpicBoard`](#epicboard) | The updated epic board. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `EpicConnection`

The connection type for Epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[EpicEdge]`](#epicedge) | A list of edges. |
| `nodes` | [`[Epic]`](#epic) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `EpicDescendantCount`

Counts of descendent epics.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedEpics` | [`Int`](#int) | Number of closed child epics. |
| `closedIssues` | [`Int`](#int) | Number of closed epic issues. |
| `openedEpics` | [`Int`](#int) | Number of opened child epics. |
| `openedIssues` | [`Int`](#int) | Number of opened epic issues. |

### `EpicDescendantWeights`

Total weight of open and closed descendant issues.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssues` | [`Int`](#int) | Total weight of completed (closed) issues in this epic, including epic descendants. |
| `openedIssues` | [`Int`](#int) | Total weight of opened issues in this epic, including epic descendants. |

### `EpicEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Epic`](#epic) | The item at the end of the edge. |

### `EpicHealthStatus`

Health status of child issues.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `issuesAtRisk` | [`Int`](#int) | Number of issues at risk. |
| `issuesNeedingAttention` | [`Int`](#int) | Number of issues that need attention. |
| `issuesOnTrack` | [`Int`](#int) | Number of issues on track. |

### `EpicIssue`

Relationship between an epic and an issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alertManagementAlert` | [`AlertManagementAlert`](#alertmanagementalert) | Alert associated to this issue. |
| `assignees` | [`UserConnection`](#userconnection) | Assignees of the issue. |
| `author` | [`User!`](#user) | User that created the issue. |
| `blocked` | [`Boolean!`](#boolean) | Indicates the issue is blocked. |
| `blockedByCount` | [`Int`](#int) | Count of issues blocking this issue. |
| `blockedByIssues` | [`IssueConnection`](#issueconnection) | Issues blocking this issue. |
| `closedAt` | [`Time`](#time) | Timestamp of when the issue was closed. |
| `confidential` | [`Boolean!`](#boolean) | Indicates the issue is confidential. |
| `createNoteEmail` | [`String`](#string) | User specific email address for the issue. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the issue was created. |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `description` | [`String`](#string) | Description of the issue. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `designCollection` | [`DesignCollection`](#designcollection) | Collection of design images associated with this issue. |
| `discussionLocked` | [`Boolean!`](#boolean) | Indicates discussion is locked on the issue. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `downvotes` | [`Int!`](#int) | Number of downvotes the issue has received. |
| `dueDate` | [`Time`](#time) | Due date of the issue. |
| `emailsDisabled` | [`Boolean!`](#boolean) | Indicates if a project has email notifications disabled: `true` if email notifications are disabled. |
| `epic` | [`Epic`](#epic) | Epic to which this issue belongs. |
| `epicIssueId` | [`ID!`](#id) | ID of the epic-issue relation. |
| `healthStatus` | [`HealthStatus`](#healthstatus) | Current health status. |
| `humanTimeEstimate` | [`String`](#string) | Human-readable time estimate of the issue. |
| `humanTotalTimeSpent` | [`String`](#string) | Human-readable total time reported as spent on the issue. |
| `id` | [`ID`](#id) | Global ID of the epic-issue relation. |
| `iid` | [`ID!`](#id) | Internal ID of the issue. |
| `iteration` | [`Iteration`](#iteration) | Iteration of the issue. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels of the issue. |
| `metricImages` | [`[MetricImage!]`](#metricimage) | Metric images associated to the issue. |
| `milestone` | [`Milestone`](#milestone) | Milestone of the issue. |
| `moved` | [`Boolean`](#boolean) | Indicates if issue got moved from other project. |
| `movedTo` | [`Issue`](#issue) | Updated Issue after it got moved to another project. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `participants` | [`UserConnection`](#userconnection) | List of participants in the issue. |
| `reference` | [`String!`](#string) | Internal reference of the issue. Returned in shortened format by default. |
| `relationPath` | [`String`](#string) | URI path of the epic-issue relation. |
| `relativePosition` | [`Int`](#int) | Relative position of the issue (used for positioning in epic tree and issue boards). |
| `severity` | [`IssuableSeverity`](#issuableseverity) | Severity level of the incident. |
| `slaDueAt` | [`Time`](#time) | Timestamp of when the issue SLA expires. |
| `state` | [`IssueState!`](#issuestate) | State of the issue. |
| `statusPagePublishedIncident` | [`Boolean`](#boolean) | Indicates whether an issue is published to the status page. |
| `subscribed` | [`Boolean!`](#boolean) | Indicates the currently logged in user is subscribed to the issue. |
| `taskCompletionStatus` | [`TaskCompletionStatus!`](#taskcompletionstatus) | Task completion status of the issue. |
| `timeEstimate` | [`Int!`](#int) | Time estimate of the issue. |
| `title` | [`String!`](#string) | Title of the issue. |
| `titleHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | [`Int!`](#int) | Total time reported as spent on the issue. |
| `type` | [`IssueType`](#issuetype) | Type of the issue. |
| `updatedAt` | [`Time!`](#time) | Timestamp of when the issue was last updated. |
| `updatedBy` | [`User`](#user) | User that last updated the issue. |
| `upvotes` | [`Int!`](#int) | Number of upvotes the issue has received. |
| `userDiscussionsCount` | [`Int!`](#int) | Number of user discussions in the issue. |
| `userNotesCount` | [`Int!`](#int) | Number of user notes of the issue. |
| `userPermissions` | [`IssuePermissions!`](#issuepermissions) | Permissions for the current user on the resource |
| `webPath` | [`String!`](#string) | Web path of the issue. |
| `webUrl` | [`String!`](#string) | Web URL of the issue. |
| `weight` | [`Int`](#int) | Weight of the issue. |

### `EpicIssueConnection`

The connection type for EpicIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[EpicIssueEdge]`](#epicissueedge) | A list of edges. |
| `nodes` | [`[EpicIssue]`](#epicissue) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |
| `weight` | [`Int!`](#int) | Total weight of issues collection. |

### `EpicIssueEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`EpicIssue`](#epicissue) | The item at the end of the edge. |

### `EpicList`

Represents an epic board list.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collapsed` | [`Boolean`](#boolean) | Indicates if this list is collapsed for this user. |
| `epics` | [`EpicConnection`](#epicconnection) | List epics. |
| `epicsCount` | [`Int`](#int) | Count of epics in the list. |
| `id` | [`BoardsEpicListID!`](#boardsepiclistid) | Global ID of the board list. |
| `label` | [`Label`](#label) | Label of the list. |
| `listType` | [`String!`](#string) | Type of the list. |
| `position` | [`Int`](#int) | Position of the list within the board. |
| `title` | [`String!`](#string) | Title of the list. |

### `EpicListConnection`

The connection type for EpicList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[EpicListEdge]`](#epiclistedge) | A list of edges. |
| `nodes` | [`[EpicList]`](#epiclist) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `EpicListEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`EpicList`](#epiclist) | The item at the end of the edge. |

### `EpicMoveListPayload`

Autogenerated return type of EpicMoveList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `EpicPermissions`

Check permissions for the current user on an epic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminEpic` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_epic` on this resource |
| `awardEmoji` | [`Boolean!`](#boolean) | Indicates the user can perform `award_emoji` on this resource |
| `createEpic` | [`Boolean!`](#boolean) | Indicates the user can perform `create_epic` on this resource |
| `createNote` | [`Boolean!`](#boolean) | Indicates the user can perform `create_note` on this resource |
| `destroyEpic` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_epic` on this resource |
| `readEpic` | [`Boolean!`](#boolean) | Indicates the user can perform `read_epic` on this resource |
| `readEpicIid` | [`Boolean!`](#boolean) | Indicates the user can perform `read_epic_iid` on this resource |
| `updateEpic` | [`Boolean!`](#boolean) | Indicates the user can perform `update_epic` on this resource |

### `EpicSetSubscriptionPayload`

Autogenerated return type of EpicSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epic` | [`Epic`](#epic) | The epic after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `EpicTreeReorderPayload`

Autogenerated return type of EpicTreeReorder.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `Event`

Representing an event.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `action` | [`EventAction!`](#eventaction) | Action of the event. |
| `author` | [`User!`](#user) | Author of this event. |
| `createdAt` | [`Time!`](#time) | When this event was created. |
| `id` | [`ID!`](#id) | ID of the event. |
| `updatedAt` | [`Time!`](#time) | When this event was updated. |

### `EventConnection`

The connection type for Event.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[EventEdge]`](#eventedge) | A list of edges. |
| `nodes` | [`[Event]`](#event) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `EventEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Event`](#event) | The item at the end of the edge. |

### `ExportRequirementsPayload`

Autogenerated return type of ExportRequirements.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `ExternalIssue`

Represents an external issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp of when the issue was created. |
| `externalTracker` | [`String`](#string) | Type of external tracker. |
| `relativeReference` | [`String`](#string) | Relative reference of the issue in the external tracker. |
| `status` | [`String`](#string) | Status of the issue in the external tracker. |
| `title` | [`String`](#string) | Title of the issue in the external tracker. |
| `updatedAt` | [`Time`](#time) | Timestamp of when the issue was updated. |
| `webUrl` | [`String`](#string) | URL to the issue in the external tracker. |

### `GeoNode`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `containerRepositoriesMaxCapacity` | [`Int`](#int) | The maximum concurrency of container repository sync for this secondary node. |
| `enabled` | [`Boolean`](#boolean) | Indicates whether this Geo node is enabled. |
| `filesMaxCapacity` | [`Int`](#int) | The maximum concurrency of LFS/attachment backfill for this secondary node. |
| `groupWikiRepositoryRegistries` | [`GroupWikiRepositoryRegistryConnection`](#groupwikirepositoryregistryconnection) | Find group wiki repository registries on this Geo node. |
| `id` | [`ID!`](#id) | ID of this GeoNode. |
| `internalUrl` | [`String`](#string) | The URL defined on the primary node that secondary nodes should use to contact it. |
| `mergeRequestDiffRegistries` | [`MergeRequestDiffRegistryConnection`](#mergerequestdiffregistryconnection) | Find merge request diff registries on this Geo node. |
| `minimumReverificationInterval` | [`Int`](#int) | The interval (in days) in which the repository verification is valid. Once expired, it will be reverified. |
| `name` | [`String`](#string) | The unique identifier for this Geo node. |
| `packageFileRegistries` | [`PackageFileRegistryConnection`](#packagefileregistryconnection) | Package file registries of the GeoNode. |
| `primary` | [`Boolean`](#boolean) | Indicates whether this Geo node is the primary. |
| `reposMaxCapacity` | [`Int`](#int) | The maximum concurrency of repository backfill for this secondary node. |
| `selectiveSyncNamespaces` | [`NamespaceConnection`](#namespaceconnection) | The namespaces that should be synced, if `selective_sync_type` == `namespaces`. |
| `selectiveSyncShards` | [`[String!]`](#string) | The repository storages whose projects should be synced, if `selective_sync_type` == `shards`. |
| `selectiveSyncType` | [`String`](#string) | Indicates if syncing is limited to only specific groups, or shards. |
| `snippetRepositoryRegistries` | [`SnippetRepositoryRegistryConnection`](#snippetrepositoryregistryconnection) | Find snippet repository registries on this Geo node. |
| `syncObjectStorage` | [`Boolean`](#boolean) | Indicates if this secondary node will replicate blobs in Object Storage. |
| `terraformStateVersionRegistries` | [`TerraformStateVersionRegistryConnection`](#terraformstateversionregistryconnection) | Find terraform state version registries on this Geo node. |
| `url` | [`String`](#string) | The user-facing URL for this Geo node. |
| `verificationMaxCapacity` | [`Int`](#int) | The maximum concurrency of repository verification for this secondary node. |

### `GitlabSubscriptionActivatePayload`

Autogenerated return type of GitlabSubscriptionActivate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `GrafanaIntegration`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp of the issue's creation. |
| `enabled` | [`Boolean!`](#boolean) | Indicates whether Grafana integration is enabled. |
| `grafanaUrl` | [`String!`](#string) | URL for the Grafana host for the Grafana integration. |
| `id` | [`ID!`](#id) | Internal ID of the Grafana integration. |
| `updatedAt` | [`Time!`](#time) | Timestamp of the issue's last activity. |

### `Group`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | [`Float`](#float) | Size limit for repositories in the namespace in bytes. |
| `additionalPurchasedStorageSize` | [`Float`](#float) | Additional storage purchased for the root namespace in bytes. |
| `autoDevopsEnabled` | [`Boolean`](#boolean) | Indicates whether Auto DevOps is enabled for all projects within this group. |
| `avatarUrl` | [`String`](#string) | Avatar URL of the group. |
| `board` | [`Board`](#board) | A single board of the group. |
| `boards` | [`BoardConnection`](#boardconnection) | Boards of the group. |
| `codeCoverageActivities` | [`CodeCoverageActivityConnection`](#codecoverageactivityconnection) | Represents the code coverage activity for this group. |
| `complianceFrameworks` | [`ComplianceFrameworkConnection`](#complianceframeworkconnection) | Compliance frameworks available to projects in this namespace. Available only when feature flag `ff_custom_compliance_frameworks` is enabled. |
| `containerRepositories` | [`ContainerRepositoryConnection`](#containerrepositoryconnection) | Container repositories of the group. |
| `containerRepositoriesCount` | [`Int!`](#int) | Number of container repositories in the group. |
| `containsLockedProjects` | [`Boolean!`](#boolean) | Includes at least one project where the repository size exceeds the limit. |
| `customEmoji` | [`CustomEmojiConnection`](#customemojiconnection) | Custom emoji within this namespace. Available only when feature flag `custom_emoji` is enabled. |
| `description` | [`String`](#string) | Description of the namespace. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `emailsDisabled` | [`Boolean`](#boolean) | Indicates if a group has email notifications disabled. |
| `epic` | [`Epic`](#epic) | Find a single epic. |
| `epicBoard` | [`EpicBoard`](#epicboard) | Find a single epic board. |
| `epicBoards` | [`EpicBoardConnection`](#epicboardconnection) | Find epic boards. |
| `epics` | [`EpicConnection`](#epicconnection) | Find epics. |
| `epicsEnabled` | [`Boolean`](#boolean) | Indicates if Epics are enabled for namespace |
| `fullName` | [`String!`](#string) | Full name of the namespace. |
| `fullPath` | [`ID!`](#id) | Full path of the namespace. |
| `groupMembers` | [`GroupMemberConnection`](#groupmemberconnection) | A membership of a user within this group. |
| `groupTimelogsEnabled` | [`Boolean`](#boolean) | Indicates if Group timelogs are enabled for namespace |
| `id` | [`ID!`](#id) | ID of the namespace. |
| `isTemporaryStorageIncreaseEnabled` | [`Boolean!`](#boolean) | Status of the temporary storage increase. |
| `issues` | [`IssueConnection`](#issueconnection) | Issues for projects in this group. |
| `iterationCadences` | [`IterationCadenceConnection`](#iterationcadenceconnection) | Find iteration cadences. |
| `iterations` | [`IterationConnection`](#iterationconnection) | Find iterations. |
| `label` | [`Label`](#label) | A label available on this group. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels available on this group. |
| `lfsEnabled` | [`Boolean`](#boolean) | Indicates if Large File Storage (LFS) is enabled for namespace. |
| `mentionsDisabled` | [`Boolean`](#boolean) | Indicates if a group is disabled from getting mentioned. |
| `mergeRequests` | [`MergeRequestConnection`](#mergerequestconnection) | Merge requests for projects in this group. |
| `milestones` | [`MilestoneConnection`](#milestoneconnection) | Milestones of the group. |
| `name` | [`String!`](#string) | Name of the namespace. |
| `packageSettings` | [`PackageSettings`](#packagesettings) | The package settings for the namespace. |
| `packages` | [`PackageConnection`](#packageconnection) | Packages of the group. |
| `parent` | [`Group`](#group) | Parent group. |
| `path` | [`String!`](#string) | Path of the namespace. |
| `projectCreationLevel` | [`String`](#string) | The permission level required to create projects in the group. |
| `projects` | [`ProjectConnection!`](#projectconnection) | Projects within this namespace. |
| `repositorySizeExcessProjectCount` | [`Int!`](#int) | Number of projects in the root namespace where the repository size exceeds the limit. |
| `requestAccessEnabled` | [`Boolean`](#boolean) | Indicates if users can request access to namespace. |
| `requireTwoFactorAuthentication` | [`Boolean`](#boolean) | Indicates if all users in this group are required to set up two-factor authentication. |
| `rootStorageStatistics` | [`RootStorageStatistics`](#rootstoragestatistics) | Aggregated storage statistics of the namespace. Only available for root namespaces. |
| `shareWithGroupLock` | [`Boolean`](#boolean) | Indicates if sharing a project with another group within this group is prevented. |
| `stats` | [`GroupStats`](#groupstats) | Group statistics. |
| `storageSizeLimit` | [`Float`](#float) | Total storage limit of the root namespace in bytes. |
| `subgroupCreationLevel` | [`String`](#string) | The permission level required to create subgroups within the group. |
| `temporaryStorageIncreaseEndsOn` | [`Time`](#time) | Date until the temporary storage increase is active. |
| `timelogs` | [`TimelogConnection!`](#timelogconnection) | Time logged in issues by group members. |
| `totalRepositorySize` | [`Float`](#float) | Total repository size of all projects in the root namespace in bytes. |
| `totalRepositorySizeExcess` | [`Float`](#float) | Total excess repository size of all projects in the root namespace in bytes. |
| `twoFactorGracePeriod` | [`Int`](#int) | Time before two-factor authentication is enforced. |
| `userPermissions` | [`GroupPermissions!`](#grouppermissions) | Permissions for the current user on the resource |
| `visibility` | [`String`](#string) | Visibility of the namespace. |
| `vulnerabilities` | [`VulnerabilityConnection`](#vulnerabilityconnection) | Vulnerabilities reported on the projects in the group and its subgroups. |
| `vulnerabilitiesCountByDay` | [`VulnerabilitiesCountByDayConnection`](#vulnerabilitiescountbydayconnection) | Number of vulnerabilities per day for the projects in the group and its subgroups. |
| `vulnerabilitiesCountByDayAndSeverity` **{warning-solid}** | [`VulnerabilitiesCountByDayAndSeverityConnection`](#vulnerabilitiescountbydayandseverityconnection) | **Deprecated:** Use `vulnerabilitiesCountByDay`. Deprecated in 13.3. |
| `vulnerabilityGrades` | [`[VulnerableProjectsByGrade!]!`](#vulnerableprojectsbygrade) | Represents vulnerable project counts for each grade. |
| `vulnerabilityScanners` | [`VulnerabilityScannerConnection`](#vulnerabilityscannerconnection) | Vulnerability scanners reported on the project vulnerabilities of the group and its subgroups. |
| `vulnerabilitySeveritiesCount` | [`VulnerabilitySeveritiesCount`](#vulnerabilityseveritiescount) | Counts for each vulnerability severity in the group and its subgroups. |
| `webUrl` | [`String!`](#string) | Web URL of the group. |

### `GroupMember`

Represents a Group Membership.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `accessLevel` | [`AccessLevel`](#accesslevel) | GitLab::Access level. |
| `createdAt` | [`Time`](#time) | Date and time the membership was created. |
| `createdBy` | [`User`](#user) | User that authorized membership. |
| `expiresAt` | [`Time`](#time) | Date and time the membership expires. |
| `group` | [`Group`](#group) | Group that a User is a member of. |
| `id` | [`ID!`](#id) | ID of the member. |
| `updatedAt` | [`Time`](#time) | Date and time the membership was last updated. |
| `user` | [`User!`](#user) | User that is associated with the member object. |
| `userPermissions` | [`GroupPermissions!`](#grouppermissions) | Permissions for the current user on the resource |

### `GroupMemberConnection`

The connection type for GroupMember.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[GroupMemberEdge]`](#groupmemberedge) | A list of edges. |
| `nodes` | [`[GroupMember]`](#groupmember) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `GroupMemberEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`GroupMember`](#groupmember) | The item at the end of the edge. |

### `GroupPermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `readGroup` | [`Boolean!`](#boolean) | Indicates the user can perform `read_group` on this resource |

### `GroupReleaseStats`

Contains release-related statistics about a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `releasesCount` | [`Int`](#int) | Total number of releases in all descendant projects of the group. Will always return `null` if `group_level_release_statistics` feature flag is disabled |
| `releasesPercentage` | [`Int`](#int) | Percentage of the group's descendant projects that have at least one release. Will always return `null` if `group_level_release_statistics` feature flag is disabled |

### `GroupStats`

Contains statistics about a group.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `releaseStats` | [`GroupReleaseStats`](#groupreleasestats) | Statistics related to releases within the group. |

### `GroupWikiRepositoryRegistry`

Represents the Geo sync and verification state of a group wiki repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp when the GroupWikiRepositoryRegistry was created |
| `groupWikiRepositoryId` | [`ID!`](#id) | ID of the Group Wiki Repository. |
| `id` | [`ID!`](#id) | ID of the GroupWikiRepositoryRegistry |
| `lastSyncFailure` | [`String`](#string) | Error message during sync of the GroupWikiRepositoryRegistry |
| `lastSyncedAt` | [`Time`](#time) | Timestamp of the most recent successful sync of the GroupWikiRepositoryRegistry |
| `retryAt` | [`Time`](#time) | Timestamp after which the GroupWikiRepositoryRegistry should be resynced |
| `retryCount` | [`Int`](#int) | Number of consecutive failed sync attempts of the GroupWikiRepositoryRegistry |
| `state` | [`RegistryState`](#registrystate) | Sync state of the GroupWikiRepositoryRegistry |

### `GroupWikiRepositoryRegistryConnection`

The connection type for GroupWikiRepositoryRegistry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[GroupWikiRepositoryRegistryEdge]`](#groupwikirepositoryregistryedge) | A list of edges. |
| `nodes` | [`[GroupWikiRepositoryRegistry]`](#groupwikirepositoryregistry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `GroupWikiRepositoryRegistryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`GroupWikiRepositoryRegistry`](#groupwikirepositoryregistry) | The item at the end of the edge. |

### `HttpIntegrationCreatePayload`

Autogenerated return type of HttpIntegrationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration) | The HTTP integration. |

### `HttpIntegrationDestroyPayload`

Autogenerated return type of HttpIntegrationDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration) | The HTTP integration. |

### `HttpIntegrationResetTokenPayload`

Autogenerated return type of HttpIntegrationResetToken.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration) | The HTTP integration. |

### `HttpIntegrationUpdatePayload`

Autogenerated return type of HttpIntegrationUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration) | The HTTP integration. |

### `IncidentManagementOncallRotation`

Describes an incident management on-call rotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `activePeriod` | [`OncallRotationActivePeriodType`](#oncallrotationactiveperiodtype) | Active period for the on-call rotation. |
| `endsAt` | [`Time`](#time) | End date and time of the on-call rotation. |
| `id` | [`IncidentManagementOncallRotationID!`](#incidentmanagementoncallrotationid) | ID of the on-call rotation. |
| `length` | [`Int`](#int) | Length of the on-call schedule, in the units specified by lengthUnit. |
| `lengthUnit` | [`OncallRotationUnitEnum`](#oncallrotationunitenum) | Unit of the on-call rotation length. |
| `name` | [`String!`](#string) | Name of the on-call rotation. |
| `participants` | [`OncallParticipantTypeConnection`](#oncallparticipanttypeconnection) | Participants of the on-call rotation. |
| `shifts` | [`IncidentManagementOncallShiftConnection`](#incidentmanagementoncallshiftconnection) | Blocks of time for which a participant is on-call within a given time frame. Time frame cannot exceed one month. |
| `startsAt` | [`Time`](#time) | Start date of the on-call rotation. |

### `IncidentManagementOncallRotationConnection`

The connection type for IncidentManagementOncallRotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[IncidentManagementOncallRotationEdge]`](#incidentmanagementoncallrotationedge) | A list of edges. |
| `nodes` | [`[IncidentManagementOncallRotation]`](#incidentmanagementoncallrotation) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `IncidentManagementOncallRotationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`IncidentManagementOncallRotation`](#incidentmanagementoncallrotation) | The item at the end of the edge. |

### `IncidentManagementOncallSchedule`

Describes an incident management on-call schedule.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the on-call schedule. |
| `iid` | [`ID!`](#id) | Internal ID of the on-call schedule. |
| `name` | [`String!`](#string) | Name of the on-call schedule. |
| `rotations` | [`IncidentManagementOncallRotationConnection!`](#incidentmanagementoncallrotationconnection) | On-call rotations for the on-call schedule. |
| `timezone` | [`String!`](#string) | Time zone of the on-call schedule. |

### `IncidentManagementOncallScheduleConnection`

The connection type for IncidentManagementOncallSchedule.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[IncidentManagementOncallScheduleEdge]`](#incidentmanagementoncallscheduleedge) | A list of edges. |
| `nodes` | [`[IncidentManagementOncallSchedule]`](#incidentmanagementoncallschedule) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `IncidentManagementOncallScheduleEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`IncidentManagementOncallSchedule`](#incidentmanagementoncallschedule) | The item at the end of the edge. |

### `IncidentManagementOncallShift`

A block of time for which a participant is on-call.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endsAt` | [`Time`](#time) | End time of the on-call shift. |
| `participant` | [`OncallParticipantType`](#oncallparticipanttype) | Participant assigned to the on-call shift. |
| `startsAt` | [`Time`](#time) | Start time of the on-call shift. |

### `IncidentManagementOncallShiftConnection`

The connection type for IncidentManagementOncallShift.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[IncidentManagementOncallShiftEdge]`](#incidentmanagementoncallshiftedge) | A list of edges. |
| `nodes` | [`[IncidentManagementOncallShift]`](#incidentmanagementoncallshift) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `IncidentManagementOncallShiftEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`IncidentManagementOncallShift`](#incidentmanagementoncallshift) | The item at the end of the edge. |

### `InstanceSecurityDashboard`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `projects` | [`ProjectConnection!`](#projectconnection) | Projects selected in Instance Security Dashboard. |
| `vulnerabilityGrades` | [`[VulnerableProjectsByGrade!]!`](#vulnerableprojectsbygrade) | Represents vulnerable project counts for each grade. |
| `vulnerabilityScanners` | [`VulnerabilityScannerConnection`](#vulnerabilityscannerconnection) | Vulnerability scanners reported on the vulnerabilities from projects selected in Instance Security Dashboard. |
| `vulnerabilitySeveritiesCount` | [`VulnerabilitySeveritiesCount`](#vulnerabilityseveritiescount) | Counts for each vulnerability severity from projects selected in Instance Security Dashboard. |

### `Issue`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alertManagementAlert` | [`AlertManagementAlert`](#alertmanagementalert) | Alert associated to this issue. |
| `assignees` | [`UserConnection`](#userconnection) | Assignees of the issue. |
| `author` | [`User!`](#user) | User that created the issue. |
| `blocked` | [`Boolean!`](#boolean) | Indicates the issue is blocked. |
| `blockedByCount` | [`Int`](#int) | Count of issues blocking this issue. |
| `blockedByIssues` | [`IssueConnection`](#issueconnection) | Issues blocking this issue. |
| `closedAt` | [`Time`](#time) | Timestamp of when the issue was closed. |
| `confidential` | [`Boolean!`](#boolean) | Indicates the issue is confidential. |
| `createNoteEmail` | [`String`](#string) | User specific email address for the issue. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the issue was created. |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `description` | [`String`](#string) | Description of the issue. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `designCollection` | [`DesignCollection`](#designcollection) | Collection of design images associated with this issue. |
| `discussionLocked` | [`Boolean!`](#boolean) | Indicates discussion is locked on the issue. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `downvotes` | [`Int!`](#int) | Number of downvotes the issue has received. |
| `dueDate` | [`Time`](#time) | Due date of the issue. |
| `emailsDisabled` | [`Boolean!`](#boolean) | Indicates if a project has email notifications disabled: `true` if email notifications are disabled. |
| `epic` | [`Epic`](#epic) | Epic to which this issue belongs. |
| `healthStatus` | [`HealthStatus`](#healthstatus) | Current health status. |
| `humanTimeEstimate` | [`String`](#string) | Human-readable time estimate of the issue. |
| `humanTotalTimeSpent` | [`String`](#string) | Human-readable total time reported as spent on the issue. |
| `id` | [`ID!`](#id) | ID of the issue. |
| `iid` | [`ID!`](#id) | Internal ID of the issue. |
| `iteration` | [`Iteration`](#iteration) | Iteration of the issue. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels of the issue. |
| `metricImages` | [`[MetricImage!]`](#metricimage) | Metric images associated to the issue. |
| `milestone` | [`Milestone`](#milestone) | Milestone of the issue. |
| `moved` | [`Boolean`](#boolean) | Indicates if issue got moved from other project. |
| `movedTo` | [`Issue`](#issue) | Updated Issue after it got moved to another project. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `participants` | [`UserConnection`](#userconnection) | List of participants in the issue. |
| `reference` | [`String!`](#string) | Internal reference of the issue. Returned in shortened format by default. |
| `relativePosition` | [`Int`](#int) | Relative position of the issue (used for positioning in epic tree and issue boards). |
| `severity` | [`IssuableSeverity`](#issuableseverity) | Severity level of the incident. |
| `slaDueAt` | [`Time`](#time) | Timestamp of when the issue SLA expires. |
| `state` | [`IssueState!`](#issuestate) | State of the issue. |
| `statusPagePublishedIncident` | [`Boolean`](#boolean) | Indicates whether an issue is published to the status page. |
| `subscribed` | [`Boolean!`](#boolean) | Indicates the currently logged in user is subscribed to the issue. |
| `taskCompletionStatus` | [`TaskCompletionStatus!`](#taskcompletionstatus) | Task completion status of the issue. |
| `timeEstimate` | [`Int!`](#int) | Time estimate of the issue. |
| `title` | [`String!`](#string) | Title of the issue. |
| `titleHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | [`Int!`](#int) | Total time reported as spent on the issue. |
| `type` | [`IssueType`](#issuetype) | Type of the issue. |
| `updatedAt` | [`Time!`](#time) | Timestamp of when the issue was last updated. |
| `updatedBy` | [`User`](#user) | User that last updated the issue. |
| `upvotes` | [`Int!`](#int) | Number of upvotes the issue has received. |
| `userDiscussionsCount` | [`Int!`](#int) | Number of user discussions in the issue. |
| `userNotesCount` | [`Int!`](#int) | Number of user notes of the issue. |
| `userPermissions` | [`IssuePermissions!`](#issuepermissions) | Permissions for the current user on the resource |
| `webPath` | [`String!`](#string) | Web path of the issue. |
| `webUrl` | [`String!`](#string) | Web URL of the issue. |
| `weight` | [`Int`](#int) | Weight of the issue. |

### `IssueConnection`

The connection type for Issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[IssueEdge]`](#issueedge) | A list of edges. |
| `nodes` | [`[Issue]`](#issue) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |
| `weight` | [`Int!`](#int) | Total weight of issues collection. |

### `IssueEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Issue`](#issue) | The item at the end of the edge. |

### `IssueMoveListPayload`

Autogenerated return type of IssueMoveList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueMovePayload`

Autogenerated return type of IssueMove.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssuePermissions`

Check permissions for the current user on a issue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminIssue` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_issue` on this resource |
| `createDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `create_design` on this resource |
| `createNote` | [`Boolean!`](#boolean) | Indicates the user can perform `create_note` on this resource |
| `destroyDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_design` on this resource |
| `readDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `read_design` on this resource |
| `readIssue` | [`Boolean!`](#boolean) | Indicates the user can perform `read_issue` on this resource |
| `reopenIssue` | [`Boolean!`](#boolean) | Indicates the user can perform `reopen_issue` on this resource |
| `updateIssue` | [`Boolean!`](#boolean) | Indicates the user can perform `update_issue` on this resource |

### `IssueSetAssigneesPayload`

Autogenerated return type of IssueSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetConfidentialPayload`

Autogenerated return type of IssueSetConfidential.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetDueDatePayload`

Autogenerated return type of IssueSetDueDate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetEpicPayload`

Autogenerated return type of IssueSetEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetIterationPayload`

Autogenerated return type of IssueSetIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetLockedPayload`

Autogenerated return type of IssueSetLocked.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetSeverityPayload`

Autogenerated return type of IssueSetSeverity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetSubscriptionPayload`

Autogenerated return type of IssueSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueSetWeightPayload`

Autogenerated return type of IssueSetWeight.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `IssueStatusCountsType`

Represents total number of issues for the represented statuses.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `all` | [`Int`](#int) | Number of issues with status ALL for the project |
| `closed` | [`Int`](#int) | Number of issues with status CLOSED for the project |
| `opened` | [`Int`](#int) | Number of issues with status OPENED for the project |

### `Iteration`

Represents an iteration object.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp of iteration creation. |
| `description` | [`String`](#string) | Description of the iteration. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `dueDate` | [`Time`](#time) | Timestamp of the iteration due date. |
| `id` | [`ID!`](#id) | ID of the iteration. |
| `iid` | [`ID!`](#id) | Internal ID of the iteration. |
| `report` | [`TimeboxReport`](#timeboxreport) | Historically accurate report about the timebox. |
| `scopedPath` | [`String`](#string) | Web path of the iteration, scoped to the query parent. Only valid for Project parents. Returns null in other contexts. |
| `scopedUrl` | [`String`](#string) | Web URL of the iteration, scoped to the query parent. Only valid for Project parents. Returns null in other contexts. |
| `startDate` | [`Time`](#time) | Timestamp of the iteration start date. |
| `state` | [`IterationState!`](#iterationstate) | State of the iteration. |
| `title` | [`String!`](#string) | Title of the iteration. |
| `updatedAt` | [`Time!`](#time) | Timestamp of last iteration update. |
| `webPath` | [`String!`](#string) | Web path of the iteration. |
| `webUrl` | [`String!`](#string) | Web URL of the iteration. |

### `IterationCadence`

Represents an iteration cadence.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Whether the iteration cadence is active. |
| `automatic` | [`Boolean`](#boolean) | Whether the iteration cadence should automatically generate future iterations. |
| `durationInWeeks` | [`Int`](#int) | Duration in weeks of the iterations within this cadence. |
| `id` | [`IterationsCadenceID!`](#iterationscadenceid) | Global ID of the iteration cadence. |
| `iterationsInAdvance` | [`Int`](#int) | Future iterations to be created when iteration cadence is set to automatic. |
| `startDate` | [`Time`](#time) | Timestamp of the iteration cadence start date. |
| `title` | [`String!`](#string) | Title of the iteration cadence. |

### `IterationCadenceConnection`

The connection type for IterationCadence.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[IterationCadenceEdge]`](#iterationcadenceedge) | A list of edges. |
| `nodes` | [`[IterationCadence]`](#iterationcadence) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `IterationCadenceCreatePayload`

Autogenerated return type of IterationCadenceCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `iterationCadence` | [`IterationCadence`](#iterationcadence) | The created iteration cadence. |

### `IterationCadenceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`IterationCadence`](#iterationcadence) | The item at the end of the edge. |

### `IterationConnection`

The connection type for Iteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[IterationEdge]`](#iterationedge) | A list of edges. |
| `nodes` | [`[Iteration]`](#iteration) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `IterationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Iteration`](#iteration) | The item at the end of the edge. |

### `JiraImport`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp of when the Jira import was created. |
| `failedToImportCount` | [`Int!`](#int) | Count of issues that failed to import. |
| `importedIssuesCount` | [`Int!`](#int) | Count of issues that were successfully imported. |
| `jiraProjectKey` | [`String!`](#string) | Project key for the imported Jira project. |
| `scheduledAt` | [`Time`](#time) | Timestamp of when the Jira import was scheduled. |
| `scheduledBy` | [`User`](#user) | User that started the Jira import. |
| `totalIssueCount` | [`Int!`](#int) | Total count of issues that were attempted to import. |

### `JiraImportConnection`

The connection type for JiraImport.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[JiraImportEdge]`](#jiraimportedge) | A list of edges. |
| `nodes` | [`[JiraImport]`](#jiraimport) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `JiraImportEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`JiraImport`](#jiraimport) | The item at the end of the edge. |

### `JiraImportStartPayload`

Autogenerated return type of JiraImportStart.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `jiraImport` | [`JiraImport`](#jiraimport) | The Jira import data after mutation. |

### `JiraImportUsersPayload`

Autogenerated return type of JiraImportUsers.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `jiraUsers` | [`[JiraUser!]`](#jirauser) | Users returned from Jira, matched by email and name if possible. |

### `JiraProject`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `key` | [`String!`](#string) | Key of the Jira project. |
| `name` | [`String`](#string) | Name of the Jira project. |
| `projectId` | [`Int!`](#int) | ID of the Jira project. |

### `JiraProjectConnection`

The connection type for JiraProject.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[JiraProjectEdge]`](#jiraprojectedge) | A list of edges. |
| `nodes` | [`[JiraProject]`](#jiraproject) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `JiraProjectEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`JiraProject`](#jiraproject) | The item at the end of the edge. |

### `JiraService`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Indicates if the service is active. |
| `projects` | [`JiraProjectConnection`](#jiraprojectconnection) | List of all Jira projects fetched through Jira REST API. |
| `type` | [`String`](#string) | Class name of the service. |

### `JiraUser`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `gitlabId` | [`Int`](#int) | ID of the matched GitLab user. |
| `gitlabName` | [`String`](#string) | Name of the matched GitLab user. |
| `gitlabUsername` | [`String`](#string) | Username of the matched GitLab user. |
| `jiraAccountId` | [`String!`](#string) | Account ID of the Jira user. |
| `jiraDisplayName` | [`String!`](#string) | Display name of the Jira user. |
| `jiraEmail` | [`String`](#string) | Email of the Jira user, returned only for users with public emails. |

### `Label`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `color` | [`String!`](#string) | Background color of the label. |
| `createdAt` | [`Time!`](#time) | When this label was created. |
| `description` | [`String`](#string) | Description of the label (Markdown rendered as HTML for caching). |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `id` | [`ID!`](#id) | Label ID. |
| `textColor` | [`String!`](#string) | Text color of the label. |
| `title` | [`String!`](#string) | Content of the label. |
| `updatedAt` | [`Time!`](#time) | When this label was last updated. |

### `LabelConnection`

The connection type for Label.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[LabelEdge]`](#labeledge) | A list of edges. |
| `nodes` | [`[Label]`](#label) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `LabelCreatePayload`

Autogenerated return type of LabelCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `label` | [`Label`](#label) | The label after mutation. |

### `LabelEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Label`](#label) | The item at the end of the edge. |

### `MarkAsSpamSnippetPayload`

Autogenerated return type of MarkAsSpamSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `snippet` | [`Snippet`](#snippet) | The snippet after mutation. |

### `MemberInterfaceConnection`

The connection type for MemberInterface.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[MemberInterfaceEdge]`](#memberinterfaceedge) | A list of edges. |
| `nodes` | [`[MemberInterface]`](#memberinterface) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `MemberInterfaceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`MemberInterface`](#memberinterface) | The item at the end of the edge. |

### `MergeRequest`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `allowCollaboration` | [`Boolean`](#boolean) | Indicates if members of the target project can push to the fork. |
| `approvalsLeft` | [`Int`](#int) | Number of approvals left. |
| `approvalsRequired` | [`Int`](#int) | Number of approvals required. |
| `approved` | [`Boolean!`](#boolean) | Indicates if the merge request has all the required approvals. Returns true if no required approvals are configured. |
| `approvedBy` | [`UserConnection`](#userconnection) | Users who approved the merge request. |
| `assignees` | [`UserConnection`](#userconnection) | Assignees of the merge request. |
| `author` | [`User`](#user) | User who created this merge request. |
| `autoMergeEnabled` | [`Boolean!`](#boolean) | Indicates if auto merge is enabled for the merge request. |
| `autoMergeStrategy` | [`String`](#string) | Selected auto merge strategy. |
| `availableAutoMergeStrategies` | [`[String!]`](#string) | Array of available auto merge strategies. |
| `commitCount` | [`Int`](#int) | Number of commits in the merge request. |
| `commitsWithoutMergeCommits` | [`CommitConnection`](#commitconnection) | Merge request commits excluding merge commits. |
| `conflicts` | [`Boolean!`](#boolean) | Indicates if the merge request has conflicts. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the merge request was created. |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |
| `defaultMergeCommitMessage` | [`String`](#string) | Default merge commit message of the merge request. |
| `defaultMergeCommitMessageWithDescription` | [`String`](#string) | Default merge commit message of the merge request with description. |
| `defaultSquashCommitMessage` | [`String`](#string) | Default squash commit message of the merge request. |
| `description` | [`String`](#string) | Description of the merge request (Markdown rendered as HTML for caching). |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `diffHeadSha` | [`String`](#string) | Diff head SHA of the merge request. |
| `diffRefs` | [`DiffRefs`](#diffrefs) | References of the base SHA, the head SHA, and the start SHA for this merge request. |
| `diffStats` | [`[DiffStats!]`](#diffstats) | Details about which files were changed in this merge request. |
| `diffStatsSummary` | [`DiffStatsSummary`](#diffstatssummary) | Summary of which files were changed in this merge request. |
| `discussionLocked` | [`Boolean!`](#boolean) | Indicates if comments on the merge request are locked to members only. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `divergedFromTargetBranch` | [`Boolean!`](#boolean) | Indicates if the source branch is behind the target branch. |
| `downvotes` | [`Int!`](#int) | Number of downvotes for the merge request. |
| `forceRemoveSourceBranch` | [`Boolean`](#boolean) | Indicates if the project settings will lead to source branch deletion after merge. |
| `hasCi` | [`Boolean!`](#boolean) | Indicates if the merge request has CI. |
| `hasSecurityReports` | [`Boolean!`](#boolean) | Indicates if the source branch has any security reports. |
| `headPipeline` | [`Pipeline`](#pipeline) | The pipeline running on the branch HEAD of the merge request. |
| `id` | [`ID!`](#id) | ID of the merge request. |
| `iid` | [`String!`](#string) | Internal ID of the merge request. |
| `inProgressMergeCommitSha` | [`String`](#string) | Commit SHA of the merge request if merge is in progress. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels of the merge request. |
| `mergeCommitSha` | [`String`](#string) | SHA of the merge request commit (set once merged). |
| `mergeError` | [`String`](#string) | Error message due to a merge error. |
| `mergeOngoing` | [`Boolean!`](#boolean) | Indicates if a merge is currently occurring. |
| `mergeStatus` | [`String`](#string) | Status of the merge request. |
| `mergeTrainsCount` | [`Int`](#int) | Number of merge requests in the merge train. |
| `mergeUser` | [`User`](#user) | User who merged this merge request. |
| `mergeWhenPipelineSucceeds` | [`Boolean`](#boolean) | Indicates if the merge has been set to be merged when its pipeline succeeds (MWPS). |
| `mergeable` | [`Boolean!`](#boolean) | Indicates if the merge request is mergeable. |
| `mergeableDiscussionsState` | [`Boolean`](#boolean) | Indicates if all discussions in the merge request have been resolved, allowing the merge request to be merged. |
| `mergedAt` | [`Time`](#time) | Timestamp of when the merge request was merged, null if not merged. |
| `milestone` | [`Milestone`](#milestone) | The milestone of the merge request. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `participants` | [`UserConnection`](#userconnection) | Participants in the merge request. This includes the author, assignees, reviewers, and users mentioned in notes. |
| `pipelines` | [`PipelineConnection`](#pipelineconnection) | Pipelines for the merge request. Note: for performance reasons, no more than the most recent 500 pipelines will be returned. |
| `project` | [`Project!`](#project) | Alias for target_project. |
| `projectId` | [`Int!`](#int) | ID of the merge request project. |
| `rebaseCommitSha` | [`String`](#string) | Rebase commit SHA of the merge request. |
| `rebaseInProgress` | [`Boolean!`](#boolean) | Indicates if there is a rebase currently in progress for the merge request. |
| `reference` | [`String!`](#string) | Internal reference of the merge request. Returned in shortened format by default. |
| `reviewers` | [`UserConnection`](#userconnection) | Users from whom a review has been requested. |
| `securityAutoFix` | [`Boolean`](#boolean) | Indicates if the merge request is created by @GitLab-Security-Bot. |
| `securityReportsUpToDateOnTargetBranch` | [`Boolean!`](#boolean) | Indicates if the target branch security reports are out of date. |
| `shouldBeRebased` | [`Boolean!`](#boolean) | Indicates if the merge request will be rebased. |
| `shouldRemoveSourceBranch` | [`Boolean`](#boolean) | Indicates if the source branch of the merge request will be deleted after merge. |
| `sourceBranch` | [`String!`](#string) | Source branch of the merge request. |
| `sourceBranchExists` | [`Boolean!`](#boolean) | Indicates if the source branch of the merge request exists. |
| `sourceBranchProtected` | [`Boolean!`](#boolean) | Indicates if the source branch is protected. |
| `sourceProject` | [`Project`](#project) | Source project of the merge request. |
| `sourceProjectId` | [`Int`](#int) | ID of the merge request source project. |
| `squash` | [`Boolean!`](#boolean) | Indicates if squash on merge is enabled. |
| `squashOnMerge` | [`Boolean!`](#boolean) | Indicates if squash on merge is enabled. |
| `state` | [`MergeRequestState!`](#mergerequeststate) | State of the merge request. |
| `subscribed` | [`Boolean!`](#boolean) | Indicates if the currently logged in user is subscribed to this merge request. |
| `targetBranch` | [`String!`](#string) | Target branch of the merge request. |
| `targetBranchExists` | [`Boolean!`](#boolean) | Indicates if the target branch of the merge request exists. |
| `targetProject` | [`Project!`](#project) | Target project of the merge request. |
| `targetProjectId` | [`Int!`](#int) | ID of the merge request target project. |
| `taskCompletionStatus` | [`TaskCompletionStatus!`](#taskcompletionstatus) | Completion status of tasks |
| `timeEstimate` | [`Int!`](#int) | Time estimate of the merge request. |
| `title` | [`String!`](#string) | Title of the merge request. |
| `titleHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `title` |
| `totalTimeSpent` | [`Int!`](#int) | Total time reported as spent on the merge request. |
| `updatedAt` | [`Time!`](#time) | Timestamp of when the merge request was last updated. |
| `upvotes` | [`Int!`](#int) | Number of upvotes for the merge request. |
| `userDiscussionsCount` | [`Int`](#int) | Number of user discussions in the merge request. |
| `userNotesCount` | [`Int`](#int) | User notes count of the merge request. |
| `userPermissions` | [`MergeRequestPermissions!`](#mergerequestpermissions) | Permissions for the current user on the resource |
| `webUrl` | [`String`](#string) | Web URL of the merge request. |
| `workInProgress` | [`Boolean!`](#boolean) | Indicates if the merge request is a draft. |

### `MergeRequestAcceptPayload`

Autogenerated return type of MergeRequestAccept.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestConnection`

The connection type for MergeRequest.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[MergeRequestEdge]`](#mergerequestedge) | A list of edges. |
| `nodes` | [`[MergeRequest]`](#mergerequest) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |
| `totalTimeToMerge` | [`Float`](#float) | Total sum of time to merge, in seconds, for the collection of merge requests. |

### `MergeRequestCreatePayload`

Autogenerated return type of MergeRequestCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestDiffRegistry`

Represents the Geo sync and verification state of a Merge Request diff.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp when the MergeRequestDiffRegistry was created |
| `id` | [`ID!`](#id) | ID of the MergeRequestDiffRegistry |
| `lastSyncFailure` | [`String`](#string) | Error message during sync of the MergeRequestDiffRegistry |
| `lastSyncedAt` | [`Time`](#time) | Timestamp of the most recent successful sync of the MergeRequestDiffRegistry |
| `mergeRequestDiffId` | [`ID!`](#id) | ID of the Merge Request diff. |
| `retryAt` | [`Time`](#time) | Timestamp after which the MergeRequestDiffRegistry should be resynced |
| `retryCount` | [`Int`](#int) | Number of consecutive failed sync attempts of the MergeRequestDiffRegistry |
| `state` | [`RegistryState`](#registrystate) | Sync state of the MergeRequestDiffRegistry |

### `MergeRequestDiffRegistryConnection`

The connection type for MergeRequestDiffRegistry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[MergeRequestDiffRegistryEdge]`](#mergerequestdiffregistryedge) | A list of edges. |
| `nodes` | [`[MergeRequestDiffRegistry]`](#mergerequestdiffregistry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `MergeRequestDiffRegistryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`MergeRequestDiffRegistry`](#mergerequestdiffregistry) | The item at the end of the edge. |

### `MergeRequestEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`MergeRequest`](#mergerequest) | The item at the end of the edge. |

### `MergeRequestPermissions`

Check permissions for the current user on a merge request.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_merge_request` on this resource |
| `canMerge` | [`Boolean!`](#boolean) | Indicates the user can perform `can_merge` on this resource |
| `cherryPickOnCurrentMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `cherry_pick_on_current_merge_request` on this resource |
| `createNote` | [`Boolean!`](#boolean) | Indicates the user can perform `create_note` on this resource |
| `pushToSourceBranch` | [`Boolean!`](#boolean) | Indicates the user can perform `push_to_source_branch` on this resource |
| `readMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `read_merge_request` on this resource |
| `removeSourceBranch` | [`Boolean!`](#boolean) | Indicates the user can perform `remove_source_branch` on this resource |
| `revertOnCurrentMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `revert_on_current_merge_request` on this resource |
| `updateMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `update_merge_request` on this resource |

### `MergeRequestReviewerRereviewPayload`

Autogenerated return type of MergeRequestReviewerRereview.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetAssigneesPayload`

Autogenerated return type of MergeRequestSetAssignees.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetLabelsPayload`

Autogenerated return type of MergeRequestSetLabels.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetLockedPayload`

Autogenerated return type of MergeRequestSetLocked.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetMilestonePayload`

Autogenerated return type of MergeRequestSetMilestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetSubscriptionPayload`

Autogenerated return type of MergeRequestSetSubscription.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestSetWipPayload`

Autogenerated return type of MergeRequestSetWip.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `MergeRequestUpdatePayload`

Autogenerated return type of MergeRequestUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | The merge request after mutation. |

### `Metadata`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `revision` | [`String!`](#string) | Revision. |
| `version` | [`String!`](#string) | Version. |

### `MetricImage`

Represents a metric image upload.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `fileName` | [`String`](#string) | File name of the metric image. |
| `filePath` | [`String`](#string) | File path of the metric image. |
| `id` | [`ID!`](#id) | ID of the metric upload. |
| `iid` | [`ID!`](#id) | Internal ID of the metric upload. |
| `url` | [`String!`](#string) | URL of the metric source. |

### `MetricsDashboard`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `annotations` | [`MetricsDashboardAnnotationConnection`](#metricsdashboardannotationconnection) | Annotations added to the dashboard. |
| `path` | [`String`](#string) | Path to a file with the dashboard definition. |
| `schemaValidationWarnings` | [`[String!]`](#string) | Dashboard schema validation warnings. |

### `MetricsDashboardAnnotation`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the annotation. |
| `endingAt` | [`Time`](#time) | Timestamp marking end of annotated time span. |
| `id` | [`ID!`](#id) | ID of the annotation. |
| `panelId` | [`String`](#string) | ID of a dashboard panel to which the annotation should be scoped. |
| `startingAt` | [`Time`](#time) | Timestamp marking start of annotated time span. |

### `MetricsDashboardAnnotationConnection`

The connection type for MetricsDashboardAnnotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[MetricsDashboardAnnotationEdge]`](#metricsdashboardannotationedge) | A list of edges. |
| `nodes` | [`[MetricsDashboardAnnotation]`](#metricsdashboardannotation) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `MetricsDashboardAnnotationEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`MetricsDashboardAnnotation`](#metricsdashboardannotation) | The item at the end of the edge. |

### `Milestone`

Represents a milestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp of milestone creation. |
| `description` | [`String`](#string) | Description of the milestone. |
| `dueDate` | [`Time`](#time) | Timestamp of the milestone due date. |
| `groupMilestone` | [`Boolean!`](#boolean) | Indicates if milestone is at group level. |
| `id` | [`ID!`](#id) | ID of the milestone. |
| `projectMilestone` | [`Boolean!`](#boolean) | Indicates if milestone is at project level. |
| `report` | [`TimeboxReport`](#timeboxreport) | Historically accurate report about the timebox. |
| `startDate` | [`Time`](#time) | Timestamp of the milestone start date. |
| `state` | [`MilestoneStateEnum!`](#milestonestateenum) | State of the milestone. |
| `stats` | [`MilestoneStats`](#milestonestats) | Milestone statistics. |
| `subgroupMilestone` | [`Boolean!`](#boolean) | Indicates if milestone is at subgroup level. |
| `title` | [`String!`](#string) | Title of the milestone. |
| `updatedAt` | [`Time!`](#time) | Timestamp of last milestone update. |
| `webPath` | [`String!`](#string) | Web path of the milestone. |

### `MilestoneConnection`

The connection type for Milestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[MilestoneEdge]`](#milestoneedge) | A list of edges. |
| `nodes` | [`[Milestone]`](#milestone) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `MilestoneEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Milestone`](#milestone) | The item at the end of the edge. |

### `MilestoneStats`

Contains statistics about a milestone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssuesCount` | [`Int`](#int) | Number of closed issues associated with the milestone. |
| `totalIssuesCount` | [`Int`](#int) | Total number of issues associated with the milestone. |

### `Namespace`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | [`Float`](#float) | Size limit for repositories in the namespace in bytes. |
| `additionalPurchasedStorageSize` | [`Float`](#float) | Additional storage purchased for the root namespace in bytes. |
| `complianceFrameworks` | [`ComplianceFrameworkConnection`](#complianceframeworkconnection) | Compliance frameworks available to projects in this namespace. Available only when feature flag `ff_custom_compliance_frameworks` is enabled. |
| `containsLockedProjects` | [`Boolean!`](#boolean) | Includes at least one project where the repository size exceeds the limit. |
| `description` | [`String`](#string) | Description of the namespace. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `fullName` | [`String!`](#string) | Full name of the namespace. |
| `fullPath` | [`ID!`](#id) | Full path of the namespace. |
| `id` | [`ID!`](#id) | ID of the namespace. |
| `isTemporaryStorageIncreaseEnabled` | [`Boolean!`](#boolean) | Status of the temporary storage increase. |
| `lfsEnabled` | [`Boolean`](#boolean) | Indicates if Large File Storage (LFS) is enabled for namespace. |
| `name` | [`String!`](#string) | Name of the namespace. |
| `packageSettings` | [`PackageSettings`](#packagesettings) | The package settings for the namespace. |
| `path` | [`String!`](#string) | Path of the namespace. |
| `projects` | [`ProjectConnection!`](#projectconnection) | Projects within this namespace. |
| `repositorySizeExcessProjectCount` | [`Int!`](#int) | Number of projects in the root namespace where the repository size exceeds the limit. |
| `requestAccessEnabled` | [`Boolean`](#boolean) | Indicates if users can request access to namespace. |
| `rootStorageStatistics` | [`RootStorageStatistics`](#rootstoragestatistics) | Aggregated storage statistics of the namespace. Only available for root namespaces. |
| `storageSizeLimit` | [`Float`](#float) | Total storage limit of the root namespace in bytes. |
| `temporaryStorageIncreaseEndsOn` | [`Time`](#time) | Date until the temporary storage increase is active. |
| `totalRepositorySize` | [`Float`](#float) | Total repository size of all projects in the root namespace in bytes. |
| `totalRepositorySizeExcess` | [`Float`](#float) | Total excess repository size of all projects in the root namespace in bytes. |
| `visibility` | [`String`](#string) | Visibility of the namespace. |

### `NamespaceConnection`

The connection type for Namespace.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[NamespaceEdge]`](#namespaceedge) | A list of edges. |
| `nodes` | [`[Namespace]`](#namespace) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `NamespaceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Namespace`](#namespace) | The item at the end of the edge. |

### `NamespaceIncreaseStorageTemporarilyPayload`

Autogenerated return type of NamespaceIncreaseStorageTemporarily.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `namespace` | [`Namespace`](#namespace) | The namespace after mutation. |

### `Note`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User!`](#user) | User who wrote this note. |
| `body` | [`String!`](#string) | Content of the note. |
| `bodyHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `note` |
| `confidential` | [`Boolean`](#boolean) | Indicates if this note is confidential. |
| `createdAt` | [`Time!`](#time) | Timestamp of the note creation. |
| `discussion` | [`Discussion`](#discussion) | The discussion this note is a part of. |
| `id` | [`NoteID!`](#noteid) | ID of the note. |
| `position` | [`DiffPosition`](#diffposition) | The position of this note on a diff. |
| `project` | [`Project`](#project) | Project associated with the note. |
| `resolvable` | [`Boolean!`](#boolean) | Indicates if the object can be resolved. |
| `resolved` | [`Boolean!`](#boolean) | Indicates if the object is resolved. |
| `resolvedAt` | [`Time`](#time) | Timestamp of when the object was resolved. |
| `resolvedBy` | [`User`](#user) | User who resolved the object. |
| `system` | [`Boolean!`](#boolean) | Indicates whether this note was created by the system or by a user. |
| `systemNoteIconName` | [`String`](#string) | Name of the icon corresponding to a system note. |
| `updatedAt` | [`Time!`](#time) | Timestamp of the note's last activity. |
| `url` | [`String`](#string) | URL to view this Note in the Web UI. |
| `userPermissions` | [`NotePermissions!`](#notepermissions) | Permissions for the current user on the resource |

### `NoteConnection`

The connection type for Note.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[NoteEdge]`](#noteedge) | A list of edges. |
| `nodes` | [`[Note]`](#note) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `NoteEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Note`](#note) | The item at the end of the edge. |

### `NotePermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminNote` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_note` on this resource |
| `awardEmoji` | [`Boolean!`](#boolean) | Indicates the user can perform `award_emoji` on this resource |
| `createNote` | [`Boolean!`](#boolean) | Indicates the user can perform `create_note` on this resource |
| `readNote` | [`Boolean!`](#boolean) | Indicates the user can perform `read_note` on this resource |
| `repositionNote` | [`Boolean!`](#boolean) | Indicates the user can perform `reposition_note` on this resource |
| `resolveNote` | [`Boolean!`](#boolean) | Indicates the user can perform `resolve_note` on this resource |

### `OncallParticipantType`

The rotation participant and color palette.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `colorPalette` | [`String`](#string) | The color palette to assign to the on-call user. For example "blue". |
| `colorWeight` | [`String`](#string) | The color weight to assign to for the on-call user, for example "500". Max 4 chars. For easy identification of the user. |
| `id` | [`IncidentManagementOncallParticipantID!`](#incidentmanagementoncallparticipantid) | ID of the on-call participant. |
| `user` | [`User!`](#user) | The user who is participating. |

### `OncallParticipantTypeConnection`

The connection type for OncallParticipantType.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[OncallParticipantTypeEdge]`](#oncallparticipanttypeedge) | A list of edges. |
| `nodes` | [`[OncallParticipantType]`](#oncallparticipanttype) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `OncallParticipantTypeEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`OncallParticipantType`](#oncallparticipanttype) | The item at the end of the edge. |

### `OncallRotationActivePeriodType`

Active period time range for on-call rotation.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endTime` | [`String`](#string) | The end of the rotation active period. |
| `startTime` | [`String`](#string) | The start of the rotation active period. |

### `OncallRotationCreatePayload`

Autogenerated return type of OncallRotationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallRotation` | [`IncidentManagementOncallRotation`](#incidentmanagementoncallrotation) | The on-call rotation. |

### `OncallRotationDestroyPayload`

Autogenerated return type of OncallRotationDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallRotation` | [`IncidentManagementOncallRotation`](#incidentmanagementoncallrotation) | The on-call rotation. |

### `OncallRotationUpdatePayload`

Autogenerated return type of OncallRotationUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallRotation` | [`IncidentManagementOncallRotation`](#incidentmanagementoncallrotation) | The on-call rotation. |

### `OncallScheduleCreatePayload`

Autogenerated return type of OncallScheduleCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallSchedule` | [`IncidentManagementOncallSchedule`](#incidentmanagementoncallschedule) | The on-call schedule. |

### `OncallScheduleDestroyPayload`

Autogenerated return type of OncallScheduleDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallSchedule` | [`IncidentManagementOncallSchedule`](#incidentmanagementoncallschedule) | The on-call schedule. |

### `OncallScheduleUpdatePayload`

Autogenerated return type of OncallScheduleUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `oncallSchedule` | [`IncidentManagementOncallSchedule`](#incidentmanagementoncallschedule) | The on-call schedule. |

### `Package`

Represents a package in the Package Registry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Date of creation. |
| `id` | [`PackagesPackageID!`](#packagespackageid) | ID of the package. |
| `metadata` | [`PackageMetadata`](#packagemetadata) | Package metadata. |
| `name` | [`String!`](#string) | Name of the package. |
| `packageType` | [`PackageTypeEnum!`](#packagetypeenum) | Package type. |
| `pipelines` | [`PipelineConnection`](#pipelineconnection) | Pipelines that built the package. |
| `project` | [`Project!`](#project) | Project where the package is stored. |
| `tags` | [`PackageTagConnection`](#packagetagconnection) | Package tags. |
| `updatedAt` | [`Time!`](#time) | Date of most recent update. |
| `version` | [`String`](#string) | Version string. |
| `versions` | [`PackageWithoutVersionsConnection`](#packagewithoutversionsconnection) | The other versions of the package. |

### `PackageComposerJsonType`

Represents a composer JSON file.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `license` | [`String`](#string) | The license set in the Composer JSON file. |
| `name` | [`String`](#string) | The name set in the Composer JSON file. |
| `type` | [`String`](#string) | The type set in the Composer JSON file. |
| `version` | [`String`](#string) | The version set in the Composer JSON file. |

### `PackageConnection`

The connection type for Package.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[PackageEdge]`](#packageedge) | A list of edges. |
| `nodes` | [`[Package]`](#package) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PackageEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Package`](#package) | The item at the end of the edge. |

### `PackageFileRegistry`

Represents the Geo sync and verification state of a package file.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp when the PackageFileRegistry was created |
| `id` | [`ID!`](#id) | ID of the PackageFileRegistry |
| `lastSyncFailure` | [`String`](#string) | Error message during sync of the PackageFileRegistry |
| `lastSyncedAt` | [`Time`](#time) | Timestamp of the most recent successful sync of the PackageFileRegistry |
| `packageFileId` | [`ID!`](#id) | ID of the PackageFile. |
| `retryAt` | [`Time`](#time) | Timestamp after which the PackageFileRegistry should be resynced |
| `retryCount` | [`Int`](#int) | Number of consecutive failed sync attempts of the PackageFileRegistry |
| `state` | [`RegistryState`](#registrystate) | Sync state of the PackageFileRegistry |

### `PackageFileRegistryConnection`

The connection type for PackageFileRegistry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[PackageFileRegistryEdge]`](#packagefileregistryedge) | A list of edges. |
| `nodes` | [`[PackageFileRegistry]`](#packagefileregistry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PackageFileRegistryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`PackageFileRegistry`](#packagefileregistry) | The item at the end of the edge. |

### `PackageSettings`

Namespace-level Package Registry settings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `mavenDuplicateExceptionRegex` | [`UntrustedRegexp`](#untrustedregexp) | When maven_duplicates_allowed is false, you can publish duplicate packages with names that match this regex. Otherwise, this setting has no effect. |
| `mavenDuplicatesAllowed` | [`Boolean!`](#boolean) | Indicates whether duplicate Maven packages are allowed for this namespace. |

### `PackageTag`

Represents a package tag.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | The created date. |
| `id` | [`ID!`](#id) | The ID of the tag. |
| `name` | [`String!`](#string) | The name of the tag. |
| `updatedAt` | [`Time!`](#time) | The updated date. |

### `PackageTagConnection`

The connection type for PackageTag.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[PackageTagEdge]`](#packagetagedge) | A list of edges. |
| `nodes` | [`[PackageTag]`](#packagetag) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PackageTagEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`PackageTag`](#packagetag) | The item at the end of the edge. |

### `PackageWithoutVersions`

Represents a version of a package in the Package Registry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Date of creation. |
| `id` | [`PackagesPackageID!`](#packagespackageid) | ID of the package. |
| `metadata` | [`PackageMetadata`](#packagemetadata) | Package metadata. |
| `name` | [`String!`](#string) | Name of the package. |
| `packageType` | [`PackageTypeEnum!`](#packagetypeenum) | Package type. |
| `pipelines` | [`PipelineConnection`](#pipelineconnection) | Pipelines that built the package. |
| `project` | [`Project!`](#project) | Project where the package is stored. |
| `tags` | [`PackageTagConnection`](#packagetagconnection) | Package tags. |
| `updatedAt` | [`Time!`](#time) | Date of most recent update. |
| `version` | [`String`](#string) | Version string. |

### `PackageWithoutVersionsConnection`

The connection type for PackageWithoutVersions.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[PackageWithoutVersionsEdge]`](#packagewithoutversionsedge) | A list of edges. |
| `nodes` | [`[PackageWithoutVersions]`](#packagewithoutversions) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PackageWithoutVersionsEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`PackageWithoutVersions`](#packagewithoutversions) | The item at the end of the edge. |

### `PageInfo`

Information about pagination in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `endCursor` | [`String`](#string) | When paginating forwards, the cursor to continue. |
| `hasNextPage` | [`Boolean!`](#boolean) | When paginating forwards, are there more items? |
| `hasPreviousPage` | [`Boolean!`](#boolean) | When paginating backwards, are there more items? |
| `startCursor` | [`String`](#string) | When paginating backwards, the cursor to continue. |

### `Pipeline`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean!`](#boolean) | Indicates if the pipeline is active. |
| `beforeSha` | [`String`](#string) | Base SHA of the source branch. |
| `cancelable` | [`Boolean!`](#boolean) | Specifies if a pipeline can be canceled. |
| `commitPath` | [`String`](#string) | Path to the commit that triggered the pipeline. |
| `committedAt` | [`Time`](#time) | Timestamp of the pipeline's commit. |
| `configSource` | [`PipelineConfigSourceEnum`](#pipelineconfigsourceenum) | Configuration source of the pipeline (UNKNOWN_SOURCE, REPOSITORY_SOURCE, AUTO_DEVOPS_SOURCE, WEBIDE_SOURCE, REMOTE_SOURCE, EXTERNAL_PROJECT_SOURCE, BRIDGE_SOURCE, PARAMETER_SOURCE, COMPLIANCE_SOURCE) |
| `coverage` | [`Float`](#float) | Coverage percentage. |
| `createdAt` | [`Time!`](#time) | Timestamp of the pipeline's creation. |
| `detailedStatus` | [`DetailedStatus!`](#detailedstatus) | Detailed status of the pipeline. |
| `downstream` | [`PipelineConnection`](#pipelineconnection) | Pipelines this pipeline will trigger. |
| `duration` | [`Int`](#int) | Duration of the pipeline in seconds. |
| `finishedAt` | [`Time`](#time) | Timestamp of the pipeline's completion. |
| `id` | [`ID!`](#id) | ID of the pipeline. |
| `iid` | [`String!`](#string) | Internal ID of the pipeline. |
| `jobs` | [`CiJobConnection`](#cijobconnection) | Jobs belonging to the pipeline. |
| `path` | [`String`](#string) | Relative path to the pipeline's page. |
| `project` | [`Project`](#project) | Project the pipeline belongs to. |
| `retryable` | [`Boolean!`](#boolean) | Specifies if a pipeline can be retried. |
| `securityReportFindings` | [`PipelineSecurityReportFindingConnection`](#pipelinesecurityreportfindingconnection) | Vulnerability findings reported on the pipeline. |
| `securityReportSummary` | [`SecurityReportSummary`](#securityreportsummary) | Vulnerability and scanned resource counts for each security scanner of the pipeline. |
| `sha` | [`String!`](#string) | SHA of the pipeline's commit. |
| `sourceJob` | [`CiJob`](#cijob) | Job where pipeline was triggered from. |
| `stages` | [`CiStageConnection`](#cistageconnection) | Stages of the pipeline. |
| `startedAt` | [`Time`](#time) | Timestamp when the pipeline was started. |
| `status` | [`PipelineStatusEnum!`](#pipelinestatusenum) | Status of the pipeline (CREATED, WAITING_FOR_RESOURCE, PREPARING, PENDING, RUNNING, FAILED, SUCCESS, CANCELED, SKIPPED, MANUAL, SCHEDULED) |
| `updatedAt` | [`Time!`](#time) | Timestamp of the pipeline's last activity. |
| `upstream` | [`Pipeline`](#pipeline) | Pipeline that triggered the pipeline. |
| `user` | [`User`](#user) | Pipeline user. |
| `userPermissions` | [`PipelinePermissions!`](#pipelinepermissions) | Permissions for the current user on the resource |
| `warnings` | [`Boolean!`](#boolean) | Indicates if a pipeline has warnings. |

### `PipelineAnalytics`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `monthPipelinesLabels` | [`[String!]`](#string) | Labels for the monthly pipeline count. |
| `monthPipelinesSuccessful` | [`[Int!]`](#int) | Total monthly successful pipeline count. |
| `monthPipelinesTotals` | [`[Int!]`](#int) | Total monthly pipeline count. |
| `pipelineTimesLabels` | [`[String!]`](#string) | Pipeline times labels. |
| `pipelineTimesValues` | [`[Int!]`](#int) | Pipeline times. |
| `weekPipelinesLabels` | [`[String!]`](#string) | Labels for the weekly pipeline count. |
| `weekPipelinesSuccessful` | [`[Int!]`](#int) | Total weekly successful pipeline count. |
| `weekPipelinesTotals` | [`[Int!]`](#int) | Total weekly pipeline count. |
| `yearPipelinesLabels` | [`[String!]`](#string) | Labels for the yearly pipeline count. |
| `yearPipelinesSuccessful` | [`[Int!]`](#int) | Total yearly successful pipeline count. |
| `yearPipelinesTotals` | [`[Int!]`](#int) | Total yearly pipeline count. |

### `PipelineCancelPayload`

Autogenerated return type of PipelineCancel.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `PipelineConnection`

The connection type for Pipeline.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[PipelineEdge]`](#pipelineedge) | A list of edges. |
| `nodes` | [`[Pipeline]`](#pipeline) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PipelineDestroyPayload`

Autogenerated return type of PipelineDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `PipelineEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Pipeline`](#pipeline) | The item at the end of the edge. |

### `PipelinePermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminPipeline` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_pipeline` on this resource |
| `destroyPipeline` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_pipeline` on this resource |
| `updatePipeline` | [`Boolean!`](#boolean) | Indicates the user can perform `update_pipeline` on this resource |

### `PipelineRetryPayload`

Autogenerated return type of PipelineRetry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipeline` | [`Pipeline`](#pipeline) | The pipeline after mutation. |

### `PipelineSecurityReportFinding`

Represents vulnerability finding of a security report on the pipeline.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `confidence` | [`String`](#string) | Type of the security report that found the vulnerability. |
| `description` | [`String`](#string) | Description of the vulnerability finding. |
| `identifiers` | [`[VulnerabilityIdentifier!]!`](#vulnerabilityidentifier) | Identifiers of the vulnerabilit finding. |
| `location` | [`VulnerabilityLocation`](#vulnerabilitylocation) | Location metadata for the vulnerability. Its fields depend on the type of security scan that found the vulnerability. |
| `name` | [`String`](#string) | Name of the vulnerability finding. |
| `project` | [`Project`](#project) | The project on which the vulnerability finding was found. |
| `projectFingerprint` | [`String`](#string) | Name of the vulnerability finding. |
| `reportType` | [`VulnerabilityReportType`](#vulnerabilityreporttype) | Type of the security report that found the vulnerability finding. |
| `scanner` | [`VulnerabilityScanner`](#vulnerabilityscanner) | Scanner metadata for the vulnerability. |
| `severity` | [`VulnerabilitySeverity`](#vulnerabilityseverity) | Severity of the vulnerability finding. |
| `solution` | [`String`](#string) | URL to the vulnerability's details page. |
| `uuid` | [`String`](#string) | Name of the vulnerability finding. |

### `PipelineSecurityReportFindingConnection`

The connection type for PipelineSecurityReportFinding.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[PipelineSecurityReportFindingEdge]`](#pipelinesecurityreportfindingedge) | A list of edges. |
| `nodes` | [`[PipelineSecurityReportFinding]`](#pipelinesecurityreportfinding) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `PipelineSecurityReportFindingEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`PipelineSecurityReportFinding`](#pipelinesecurityreportfinding) | The item at the end of the edge. |

### `Project`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `actualRepositorySizeLimit` | [`Float`](#float) | Size limit for the repository in bytes. |
| `alertManagementAlert` | [`AlertManagementAlert`](#alertmanagementalert) | A single Alert Management alert of the project. |
| `alertManagementAlertStatusCounts` | [`AlertManagementAlertStatusCountsType`](#alertmanagementalertstatuscountstype) | Counts of alerts by status for the project. |
| `alertManagementAlerts` | [`AlertManagementAlertConnection`](#alertmanagementalertconnection) | Alert Management alerts of the project. |
| `alertManagementHttpIntegrations` | [`AlertManagementHttpIntegrationConnection`](#alertmanagementhttpintegrationconnection) | HTTP Integrations which can receive alerts for the project. |
| `alertManagementIntegrations` | [`AlertManagementIntegrationConnection`](#alertmanagementintegrationconnection) | Integrations which can receive alerts for the project. |
| `alertManagementPayloadFields` | [`[AlertManagementPayloadAlertField!]`](#alertmanagementpayloadalertfield) | Extract alert fields from payload for custom mapping. |
| `allowMergeOnSkippedPipeline` | [`Boolean`](#boolean) | If `only_allow_merge_if_pipeline_succeeds` is true, indicates if merge requests of the project can also be merged with skipped jobs. |
| `apiFuzzingCiConfiguration` | [`ApiFuzzingCiConfiguration`](#apifuzzingciconfiguration) | API fuzzing configuration for the project. Available only when feature flag `api_fuzzing_configuration_ui` is enabled. |
| `archived` | [`Boolean`](#boolean) | Indicates the archived status of the project. |
| `autocloseReferencedIssues` | [`Boolean`](#boolean) | Indicates if issues referenced by merge requests and commits within the default branch are closed automatically. |
| `avatarUrl` | [`String`](#string) | URL to avatar image file of the project. |
| `board` | [`Board`](#board) | A single board of the project. |
| `boards` | [`BoardConnection`](#boardconnection) | Boards of the project. |
| `ciCdSettings` | [`ProjectCiCdSetting`](#projectcicdsetting) | CI/CD settings for the project. |
| `clusterAgent` | [`ClusterAgent`](#clusteragent) | Find a single cluster agent by name. |
| `clusterAgents` | [`ClusterAgentConnection`](#clusteragentconnection) | Cluster agents associated with the project. |
| `codeCoverageSummary` | [`CodeCoverageSummary`](#codecoveragesummary) | Code coverage summary associated with the project. |
| `complianceFrameworks` | [`ComplianceFrameworkConnection`](#complianceframeworkconnection) | Compliance frameworks associated with the project. |
| `containerExpirationPolicy` | [`ContainerExpirationPolicy`](#containerexpirationpolicy) | The container expiration policy of the project. |
| `containerRegistryEnabled` | [`Boolean`](#boolean) | Indicates if the project stores Docker container images in a container registry. |
| `containerRepositories` | [`ContainerRepositoryConnection`](#containerrepositoryconnection) | Container repositories of the project. |
| `containerRepositoriesCount` | [`Int!`](#int) | Number of container repositories in the project. |
| `createdAt` | [`Time`](#time) | Timestamp of the project creation. |
| `dastProfiles` | [`DastProfileConnection`](#dastprofileconnection) | DAST Profiles associated with the project. |
| `dastScannerProfiles` | [`DastScannerProfileConnection`](#dastscannerprofileconnection) | The DAST scanner profiles associated with the project. |
| `dastSiteProfile` | [`DastSiteProfile`](#dastsiteprofile) | DAST Site Profile associated with the project. |
| `dastSiteProfiles` | [`DastSiteProfileConnection`](#dastsiteprofileconnection) | DAST Site Profiles associated with the project. |
| `dastSiteValidations` | [`DastSiteValidationConnection`](#dastsitevalidationconnection) | DAST Site Validations associated with the project. |
| `description` | [`String`](#string) | Short description of the project. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `environment` | [`Environment`](#environment) | A single environment of the project. |
| `environments` | [`EnvironmentConnection`](#environmentconnection) | Environments of the project. |
| `forksCount` | [`Int!`](#int) | Number of times the project has been forked. |
| `fullPath` | [`ID!`](#id) | Full path of the project. |
| `grafanaIntegration` | [`GrafanaIntegration`](#grafanaintegration) | Grafana integration details for the project. |
| `group` | [`Group`](#group) | Group of the project. |
| `httpUrlToRepo` | [`String`](#string) | URL to connect to the project via HTTPS. |
| `id` | [`ID!`](#id) | ID of the project. |
| `importStatus` | [`String`](#string) | Status of import background job of the project. |
| `incidentManagementOncallSchedules` | [`IncidentManagementOncallScheduleConnection`](#incidentmanagementoncallscheduleconnection) | Incident Management On-call schedules of the project. |
| `issue` | [`Issue`](#issue) | A single issue of the project. |
| `issueStatusCounts` | [`IssueStatusCountsType`](#issuestatuscountstype) | Counts of issues by status for the project. |
| `issues` | [`IssueConnection`](#issueconnection) | Issues of the project. |
| `issuesEnabled` | [`Boolean`](#boolean) | Indicates if Issues are enabled for the current user |
| `iterationCadences` | [`IterationCadenceConnection`](#iterationcadenceconnection) | Find iteration cadences. |
| `iterations` | [`IterationConnection`](#iterationconnection) | Find iterations. |
| `jiraImportStatus` | [`String`](#string) | Status of Jira import background job of the project. |
| `jiraImports` | [`JiraImportConnection`](#jiraimportconnection) | Jira imports into the project. |
| `jobsEnabled` | [`Boolean`](#boolean) | Indicates if CI/CD pipeline jobs are enabled for the current user. |
| `label` | [`Label`](#label) | A label available on this project. |
| `labels` | [`LabelConnection`](#labelconnection) | Labels available on this project. |
| `lastActivityAt` | [`Time`](#time) | Timestamp of the project last activity. |
| `lfsEnabled` | [`Boolean`](#boolean) | Indicates if the project has Large File Storage (LFS) enabled. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | A single merge request of the project. |
| `mergeRequests` | [`MergeRequestConnection`](#mergerequestconnection) | Merge requests of the project. |
| `mergeRequestsEnabled` | [`Boolean`](#boolean) | Indicates if Merge Requests are enabled for the current user |
| `mergeRequestsFfOnlyEnabled` | [`Boolean`](#boolean) | Indicates if no merge commits should be created and all merges should instead be fast-forwarded, which means that merging is only allowed if the branch could be fast-forwarded. |
| `milestones` | [`MilestoneConnection`](#milestoneconnection) | Milestones of the project. |
| `name` | [`String!`](#string) | Name of the project (without namespace). |
| `nameWithNamespace` | [`String!`](#string) | Full name of the project with its namespace. |
| `namespace` | [`Namespace`](#namespace) | Namespace of the project. |
| `onlyAllowMergeIfAllDiscussionsAreResolved` | [`Boolean`](#boolean) | Indicates if merge requests of the project can only be merged when all the discussions are resolved. |
| `onlyAllowMergeIfPipelineSucceeds` | [`Boolean`](#boolean) | Indicates if merge requests of the project can only be merged with successful jobs. |
| `openIssuesCount` | [`Int`](#int) | Number of open issues for the project. |
| `packages` | [`PackageConnection`](#packageconnection) | Packages of the project. |
| `path` | [`String!`](#string) | Path of the project. |
| `pipeline` | [`Pipeline`](#pipeline) | Build pipeline of the project. |
| `pipelineAnalytics` | [`PipelineAnalytics`](#pipelineanalytics) | Pipeline analytics. |
| `pipelines` | [`PipelineConnection`](#pipelineconnection) | Build pipelines of the project. |
| `printingMergeRequestLinkEnabled` | [`Boolean`](#boolean) | Indicates if a link to create or view a merge request should display after a push to Git repositories of the project from the command line. |
| `projectMembers` | [`MemberInterfaceConnection`](#memberinterfaceconnection) | Members of the project. |
| `publicJobs` | [`Boolean`](#boolean) | Indicates if there is public access to pipelines and job details of the project, including output logs and artifacts. |
| `pushRules` | [`PushRules`](#pushrules) | The project's push rules settings. |
| `release` | [`Release`](#release) | A single release of the project. |
| `releases` | [`ReleaseConnection`](#releaseconnection) | Releases of the project. |
| `removeSourceBranchAfterMerge` | [`Boolean`](#boolean) | Indicates if `Delete source branch` option should be enabled by default for all new merge requests of the project. |
| `repository` | [`Repository`](#repository) | Git repository of the project. |
| `repositorySizeExcess` | [`Float`](#float) | Size of repository that exceeds the limit in bytes. |
| `requestAccessEnabled` | [`Boolean`](#boolean) | Indicates if users can request member access to the project. |
| `requirement` | [`Requirement`](#requirement) | Find a single requirement. |
| `requirementStatesCount` | [`RequirementStatesCount`](#requirementstatescount) | Number of requirements for the project by their state. |
| `requirements` | [`RequirementConnection`](#requirementconnection) | Find requirements. |
| `sastCiConfiguration` | [`SastCiConfiguration`](#sastciconfiguration) | SAST CI configuration for the project. |
| `securityDashboardPath` | [`String`](#string) | Path to project's security dashboard. |
| `securityScanners` | [`SecurityScanners`](#securityscanners) | Information about security analyzers used in the project. |
| `sentryDetailedError` | [`SentryDetailedError`](#sentrydetailederror) | Detailed version of a Sentry error on the project. |
| `sentryErrors` | [`SentryErrorCollection`](#sentryerrorcollection) | Paginated collection of Sentry errors on the project. |
| `serviceDeskAddress` | [`String`](#string) | E-mail address of the service desk. |
| `serviceDeskEnabled` | [`Boolean`](#boolean) | Indicates if the project has service desk enabled. |
| `services` | [`ServiceConnection`](#serviceconnection) | Project services. |
| `sharedRunnersEnabled` | [`Boolean`](#boolean) | Indicates if shared runners are enabled for the project. |
| `snippets` | [`SnippetConnection`](#snippetconnection) | Snippets of the project. |
| `snippetsEnabled` | [`Boolean`](#boolean) | Indicates if Snippets are enabled for the current user |
| `squashReadOnly` | [`Boolean!`](#boolean) | Indicates if `squashReadOnly` is enabled. |
| `sshUrlToRepo` | [`String`](#string) | URL to connect to the project via SSH. |
| `starCount` | [`Int!`](#int) | Number of times the project has been starred. |
| `statistics` | [`ProjectStatistics`](#projectstatistics) | Statistics of the project. |
| `suggestionCommitMessage` | [`String`](#string) | The commit message used to apply merge request suggestions. |
| `tagList` | [`String`](#string) | List of project topics (not Git tags). |
| `terraformState` | [`TerraformState`](#terraformstate) | Find a single Terraform state by name. |
| `terraformStates` | [`TerraformStateConnection`](#terraformstateconnection) | Terraform states associated with the project. |
| `userPermissions` | [`ProjectPermissions!`](#projectpermissions) | Permissions for the current user on the resource |
| `visibility` | [`String`](#string) | Visibility of the project. |
| `vulnerabilities` | [`VulnerabilityConnection`](#vulnerabilityconnection) | Vulnerabilities reported on the project. |
| `vulnerabilitiesCountByDay` | [`VulnerabilitiesCountByDayConnection`](#vulnerabilitiescountbydayconnection) | Number of vulnerabilities per day for the project. |
| `vulnerabilityScanners` | [`VulnerabilityScannerConnection`](#vulnerabilityscannerconnection) | Vulnerability scanners reported on the project vulnerabilities. |
| `vulnerabilitySeveritiesCount` | [`VulnerabilitySeveritiesCount`](#vulnerabilityseveritiescount) | Counts for each vulnerability severity in the project. |
| `webUrl` | [`String`](#string) | Web URL of the project. |
| `wikiEnabled` | [`Boolean`](#boolean) | Indicates if Wikis are enabled for the current user |

### `ProjectCiCdSetting`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `keepLatestArtifact` | [`Boolean`](#boolean) | Whether to keep the latest builds artifacts. |
| `mergePipelinesEnabled` | [`Boolean`](#boolean) | Whether merge pipelines are enabled. |
| `mergeTrainsEnabled` | [`Boolean`](#boolean) | Whether merge trains are enabled. |
| `project` | [`Project`](#project) | Project the CI/CD settings belong to. |

### `ProjectConnection`

The connection type for Project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ProjectEdge]`](#projectedge) | A list of edges. |
| `nodes` | [`[Project]`](#project) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ProjectEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Project`](#project) | The item at the end of the edge. |

### `ProjectMember`

Represents a Project Membership.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `accessLevel` | [`AccessLevel`](#accesslevel) | GitLab::Access level. |
| `createdAt` | [`Time`](#time) | Date and time the membership was created. |
| `createdBy` | [`User`](#user) | User that authorized membership. |
| `expiresAt` | [`Time`](#time) | Date and time the membership expires. |
| `id` | [`ID!`](#id) | ID of the member. |
| `project` | [`Project`](#project) | Project that User is a member of. |
| `updatedAt` | [`Time`](#time) | Date and time the membership was last updated. |
| `user` | [`User!`](#user) | User that is associated with the member object. |
| `userPermissions` | [`ProjectPermissions!`](#projectpermissions) | Permissions for the current user on the resource |

### `ProjectMemberConnection`

The connection type for ProjectMember.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ProjectMemberEdge]`](#projectmemberedge) | A list of edges. |
| `nodes` | [`[ProjectMember]`](#projectmember) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ProjectMemberEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ProjectMember`](#projectmember) | The item at the end of the edge. |

### `ProjectPermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminOperations` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_operations` on this resource |
| `adminProject` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_project` on this resource |
| `adminRemoteMirror` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_remote_mirror` on this resource |
| `adminWiki` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_wiki` on this resource |
| `archiveProject` | [`Boolean!`](#boolean) | Indicates the user can perform `archive_project` on this resource |
| `changeNamespace` | [`Boolean!`](#boolean) | Indicates the user can perform `change_namespace` on this resource |
| `changeVisibilityLevel` | [`Boolean!`](#boolean) | Indicates the user can perform `change_visibility_level` on this resource |
| `createDeployment` | [`Boolean!`](#boolean) | Indicates the user can perform `create_deployment` on this resource |
| `createDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `create_design` on this resource |
| `createIssue` | [`Boolean!`](#boolean) | Indicates the user can perform `create_issue` on this resource |
| `createLabel` | [`Boolean!`](#boolean) | Indicates the user can perform `create_label` on this resource |
| `createMergeRequestFrom` | [`Boolean!`](#boolean) | Indicates the user can perform `create_merge_request_from` on this resource |
| `createMergeRequestIn` | [`Boolean!`](#boolean) | Indicates the user can perform `create_merge_request_in` on this resource |
| `createPages` | [`Boolean!`](#boolean) | Indicates the user can perform `create_pages` on this resource |
| `createPipeline` | [`Boolean!`](#boolean) | Indicates the user can perform `create_pipeline` on this resource |
| `createPipelineSchedule` | [`Boolean!`](#boolean) | Indicates the user can perform `create_pipeline_schedule` on this resource |
| `createSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `create_snippet` on this resource |
| `createWiki` | [`Boolean!`](#boolean) | Indicates the user can perform `create_wiki` on this resource |
| `destroyDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_design` on this resource |
| `destroyPages` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_pages` on this resource |
| `destroyWiki` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_wiki` on this resource |
| `downloadCode` | [`Boolean!`](#boolean) | Indicates the user can perform `download_code` on this resource |
| `downloadWikiCode` | [`Boolean!`](#boolean) | Indicates the user can perform `download_wiki_code` on this resource |
| `forkProject` | [`Boolean!`](#boolean) | Indicates the user can perform `fork_project` on this resource |
| `pushCode` | [`Boolean!`](#boolean) | Indicates the user can perform `push_code` on this resource |
| `pushToDeleteProtectedBranch` | [`Boolean!`](#boolean) | Indicates the user can perform `push_to_delete_protected_branch` on this resource |
| `readCommitStatus` | [`Boolean!`](#boolean) | Indicates the user can perform `read_commit_status` on this resource |
| `readCycleAnalytics` | [`Boolean!`](#boolean) | Indicates the user can perform `read_cycle_analytics` on this resource |
| `readDesign` | [`Boolean!`](#boolean) | Indicates the user can perform `read_design` on this resource |
| `readMergeRequest` | [`Boolean!`](#boolean) | Indicates the user can perform `read_merge_request` on this resource |
| `readPagesContent` | [`Boolean!`](#boolean) | Indicates the user can perform `read_pages_content` on this resource |
| `readProject` | [`Boolean!`](#boolean) | Indicates the user can perform `read_project` on this resource |
| `readProjectMember` | [`Boolean!`](#boolean) | Indicates the user can perform `read_project_member` on this resource |
| `readWiki` | [`Boolean!`](#boolean) | Indicates the user can perform `read_wiki` on this resource |
| `removeForkProject` | [`Boolean!`](#boolean) | Indicates the user can perform `remove_fork_project` on this resource |
| `removePages` | [`Boolean!`](#boolean) | Indicates the user can perform `remove_pages` on this resource |
| `removeProject` | [`Boolean!`](#boolean) | Indicates the user can perform `remove_project` on this resource |
| `renameProject` | [`Boolean!`](#boolean) | Indicates the user can perform `rename_project` on this resource |
| `requestAccess` | [`Boolean!`](#boolean) | Indicates the user can perform `request_access` on this resource |
| `updatePages` | [`Boolean!`](#boolean) | Indicates the user can perform `update_pages` on this resource |
| `updateWiki` | [`Boolean!`](#boolean) | Indicates the user can perform `update_wiki` on this resource |
| `uploadFile` | [`Boolean!`](#boolean) | Indicates the user can perform `upload_file` on this resource |

### `ProjectStatistics`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buildArtifactsSize` | [`Float!`](#float) | Build artifacts size of the project in bytes. |
| `commitCount` | [`Float!`](#float) | Commit count of the project. |
| `lfsObjectsSize` | [`Float!`](#float) | Large File Storage (LFS) object size of the project in bytes. |
| `packagesSize` | [`Float!`](#float) | Packages size of the project in bytes. |
| `repositorySize` | [`Float!`](#float) | Repository size of the project in bytes. |
| `snippetsSize` | [`Float`](#float) | Snippets size of the project in bytes. |
| `storageSize` | [`Float!`](#float) | Storage size of the project in bytes. |
| `uploadsSize` | [`Float`](#float) | Uploads size of the project in bytes. |
| `wikiSize` | [`Float`](#float) | Wiki size of the project in bytes. |

### `PrometheusAlert`

The alert condition for Prometheus.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `humanizedText` | [`String!`](#string) | The human-readable text of the alert condition. |
| `id` | [`ID!`](#id) | ID of the alert condition. |

### `PrometheusIntegrationCreatePayload`

Autogenerated return type of PrometheusIntegrationCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementPrometheusIntegration`](#alertmanagementprometheusintegration) | The newly created integration. |

### `PrometheusIntegrationResetTokenPayload`

Autogenerated return type of PrometheusIntegrationResetToken.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementPrometheusIntegration`](#alertmanagementprometheusintegration) | The newly created integration. |

### `PrometheusIntegrationUpdatePayload`

Autogenerated return type of PrometheusIntegrationUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `integration` | [`AlertManagementPrometheusIntegration`](#alertmanagementprometheusintegration) | The newly created integration. |

### `PromoteToEpicPayload`

Autogenerated return type of PromoteToEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epic` | [`Epic`](#epic) | The epic after issue promotion. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `PushRules`

Represents rules that commit pushes must follow.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `rejectUnsignedCommits` | [`Boolean!`](#boolean) | Indicates whether commits not signed through GPG will be rejected. |

### `Release`

Represents a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assets` | [`ReleaseAssets`](#releaseassets) | Assets of the release. |
| `author` | [`User`](#user) | User that created the release. |
| `commit` | [`Commit`](#commit) | The commit associated with the release. |
| `createdAt` | [`Time`](#time) | Timestamp of when the release was created. |
| `description` | [`String`](#string) | Description (also known as "release notes") of the release. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `evidences` | [`ReleaseEvidenceConnection`](#releaseevidenceconnection) | Evidence for the release. |
| `links` | [`ReleaseLinks`](#releaselinks) | Links of the release. |
| `milestones` | [`MilestoneConnection`](#milestoneconnection) | Milestones associated to the release. |
| `name` | [`String`](#string) | Name of the release. |
| `releasedAt` | [`Time`](#time) | Timestamp of when the release was released. |
| `tagName` | [`String`](#string) | Name of the tag associated with the release. |
| `tagPath` | [`String`](#string) | Relative web path to the tag associated with the release. |
| `upcomingRelease` | [`Boolean`](#boolean) | Indicates the release is an upcoming release. |

### `ReleaseAssetLink`

Represents an asset link associated with a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `directAssetUrl` | [`String`](#string) | Direct asset URL of the link. |
| `external` | [`Boolean`](#boolean) | Indicates the link points to an external resource. |
| `id` | [`ID!`](#id) | ID of the link. |
| `linkType` | [`ReleaseAssetLinkType`](#releaseassetlinktype) | Type of the link: `other`, `runbook`, `image`, `package`; defaults to `other`. |
| `name` | [`String`](#string) | Name of the link. |
| `url` | [`String`](#string) | URL of the link. |

### `ReleaseAssetLinkConnection`

The connection type for ReleaseAssetLink.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ReleaseAssetLinkEdge]`](#releaseassetlinkedge) | A list of edges. |
| `nodes` | [`[ReleaseAssetLink]`](#releaseassetlink) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ReleaseAssetLinkCreatePayload`

Autogenerated return type of ReleaseAssetLinkCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `link` | [`ReleaseAssetLink`](#releaseassetlink) | The asset link after mutation. |

### `ReleaseAssetLinkEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ReleaseAssetLink`](#releaseassetlink) | The item at the end of the edge. |

### `ReleaseAssetLinkUpdatePayload`

Autogenerated return type of ReleaseAssetLinkUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `link` | [`ReleaseAssetLink`](#releaseassetlink) | The asset link after mutation. |

### `ReleaseAssets`

A container for all assets associated with a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int`](#int) | Number of assets of the release. |
| `links` | [`ReleaseAssetLinkConnection`](#releaseassetlinkconnection) | Asset links of the release. |
| `sources` | [`ReleaseSourceConnection`](#releasesourceconnection) | Sources of the release. |

### `ReleaseConnection`

The connection type for Release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[ReleaseEdge]`](#releaseedge) | A list of edges. |
| `nodes` | [`[Release]`](#release) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ReleaseCreatePayload`

Autogenerated return type of ReleaseCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `release` | [`Release`](#release) | The release after mutation. |

### `ReleaseDeletePayload`

Autogenerated return type of ReleaseDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `release` | [`Release`](#release) | The deleted release. |

### `ReleaseEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Release`](#release) | The item at the end of the edge. |

### `ReleaseEvidence`

Evidence for a release.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collectedAt` | [`Time`](#time) | Timestamp when the evidence was collected. |
| `filepath` | [`String`](#string) | URL from where the evidence can be downloaded. |
| `id` | [`ID!`](#id) | ID of the evidence. |
| `sha` | [`String`](#string) | SHA1 ID of the evidence hash. |

### `ReleaseEvidenceConnection`

The connection type for ReleaseEvidence.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ReleaseEvidenceEdge]`](#releaseevidenceedge) | A list of edges. |
| `nodes` | [`[ReleaseEvidence]`](#releaseevidence) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ReleaseEvidenceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ReleaseEvidence`](#releaseevidence) | The item at the end of the edge. |

### `ReleaseLinks`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `closedIssuesUrl` | [`String`](#string) | HTTP URL of the issues page, filtered by this release and `state=closed`. |
| `closedMergeRequestsUrl` | [`String`](#string) | HTTP URL of the merge request page , filtered by this release and `state=closed`. |
| `editUrl` | [`String`](#string) | HTTP URL of the release's edit page. |
| `mergedMergeRequestsUrl` | [`String`](#string) | HTTP URL of the merge request page , filtered by this release and `state=merged`. |
| `openedIssuesUrl` | [`String`](#string) | HTTP URL of the issues page, filtered by this release and `state=open`. |
| `openedMergeRequestsUrl` | [`String`](#string) | HTTP URL of the merge request page, filtered by this release and `state=open`. |
| `selfUrl` | [`String`](#string) | HTTP URL of the release. |

### `ReleaseSource`

Represents the source code attached to a release in a particular format.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `format` | [`String`](#string) | Format of the source. |
| `url` | [`String`](#string) | Download URL of the source. |

### `ReleaseSourceConnection`

The connection type for ReleaseSource.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ReleaseSourceEdge]`](#releasesourceedge) | A list of edges. |
| `nodes` | [`[ReleaseSource]`](#releasesource) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ReleaseSourceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ReleaseSource`](#releasesource) | The item at the end of the edge. |

### `ReleaseUpdatePayload`

Autogenerated return type of ReleaseUpdate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `release` | [`Release`](#release) | The release after mutation. |

### `RemoveAwardEmojiPayload`

Autogenerated return type of RemoveAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `RemoveProjectFromSecurityDashboardPayload`

Autogenerated return type of RemoveProjectFromSecurityDashboard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `RepositionImageDiffNotePayload`

Autogenerated return type of RepositionImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `Repository`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `empty` | [`Boolean!`](#boolean) | Indicates repository has no visible content. |
| `exists` | [`Boolean!`](#boolean) | Indicates a corresponding Git repository exists on disk. |
| `rootRef` | [`String`](#string) | Default branch of the repository. |
| `tree` | [`Tree`](#tree) | Tree of the repository. |

### `Requirement`

Represents a requirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User!`](#user) | Author of the requirement. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the requirement was created. |
| `description` | [`String`](#string) | Description of the requirement. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `id` | [`ID!`](#id) | ID of the requirement. |
| `iid` | [`ID!`](#id) | Internal ID of the requirement. |
| `lastTestReportManuallyCreated` | [`Boolean`](#boolean) | Indicates if latest test report was created by user. |
| `lastTestReportState` | [`TestReportState`](#testreportstate) | Latest requirement test report state. |
| `project` | [`Project!`](#project) | Project to which the requirement belongs. |
| `state` | [`RequirementState!`](#requirementstate) | State of the requirement. |
| `testReports` | [`TestReportConnection`](#testreportconnection) | Test reports of the requirement. |
| `title` | [`String`](#string) | Title of the requirement. |
| `titleHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `title` |
| `updatedAt` | [`Time!`](#time) | Timestamp of when the requirement was last updated. |
| `userPermissions` | [`RequirementPermissions!`](#requirementpermissions) | Permissions for the current user on the resource |

### `RequirementConnection`

The connection type for Requirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[RequirementEdge]`](#requirementedge) | A list of edges. |
| `nodes` | [`[Requirement]`](#requirement) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `RequirementEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Requirement`](#requirement) | The item at the end of the edge. |

### `RequirementPermissions`

Check permissions for the current user on a requirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminRequirement` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_requirement` on this resource |
| `createRequirement` | [`Boolean!`](#boolean) | Indicates the user can perform `create_requirement` on this resource |
| `destroyRequirement` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_requirement` on this resource |
| `readRequirement` | [`Boolean!`](#boolean) | Indicates the user can perform `read_requirement` on this resource |
| `updateRequirement` | [`Boolean!`](#boolean) | Indicates the user can perform `update_requirement` on this resource |

### `RequirementStatesCount`

Counts of requirements by their state.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `archived` | [`Int`](#int) | Number of archived requirements. |
| `opened` | [`Int`](#int) | Number of opened requirements. |

### `RevertVulnerabilityToDetectedPayload`

Autogenerated return type of RevertVulnerabilityToDetected.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after revert. |

### `RootStorageStatistics`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buildArtifactsSize` | [`Float!`](#float) | The CI artifacts size in bytes. |
| `lfsObjectsSize` | [`Float!`](#float) | The LFS objects size in bytes. |
| `packagesSize` | [`Float!`](#float) | The packages size in bytes. |
| `pipelineArtifactsSize` | [`Float!`](#float) | The CI pipeline artifacts size in bytes. |
| `repositorySize` | [`Float!`](#float) | The Git repository size in bytes. |
| `snippetsSize` | [`Float!`](#float) | The snippets size in bytes. |
| `storageSize` | [`Float!`](#float) | The total storage in bytes. |
| `uploadsSize` | [`Float!`](#float) | The uploads size in bytes. |
| `wikiSize` | [`Float!`](#float) | The wiki size in bytes. |

### `RunDASTScanPayload`

Autogenerated return type of RunDASTScan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `pipelineUrl` | [`String`](#string) | URL of the pipeline that was created. |

### `RunnerArchitecture`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `downloadLocation` | [`String!`](#string) | Download location for the runner for the platform architecture. |
| `name` | [`String!`](#string) | Name of the runner platform architecture. |

### `RunnerArchitectureConnection`

The connection type for RunnerArchitecture.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[RunnerArchitectureEdge]`](#runnerarchitectureedge) | A list of edges. |
| `nodes` | [`[RunnerArchitecture]`](#runnerarchitecture) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `RunnerArchitectureEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`RunnerArchitecture`](#runnerarchitecture) | The item at the end of the edge. |

### `RunnerPlatform`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `architectures` | [`RunnerArchitectureConnection`](#runnerarchitectureconnection) | Runner architectures supported for the platform. |
| `humanReadableName` | [`String!`](#string) | Human readable name of the runner platform. |
| `name` | [`String!`](#string) | Name slug of the runner platform. |

### `RunnerPlatformConnection`

The connection type for RunnerPlatform.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[RunnerPlatformEdge]`](#runnerplatformedge) | A list of edges. |
| `nodes` | [`[RunnerPlatform]`](#runnerplatform) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `RunnerPlatformEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`RunnerPlatform`](#runnerplatform) | The item at the end of the edge. |

### `RunnerSetup`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `installInstructions` | [`String!`](#string) | Instructions for installing the runner on the specified architecture. |
| `registerInstructions` | [`String`](#string) | Instructions for registering the runner. |

### `SastCiConfiguration`

Represents a CI configuration of SAST.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `analyzers` | [`SastCiConfigurationAnalyzersEntityConnection`](#sastciconfigurationanalyzersentityconnection) | List of analyzers entities attached to SAST configuration. |
| `global` | [`SastCiConfigurationEntityConnection`](#sastciconfigurationentityconnection) | List of global entities related to SAST configuration. |
| `pipeline` | [`SastCiConfigurationEntityConnection`](#sastciconfigurationentityconnection) | List of pipeline entities related to SAST configuration. |

### `SastCiConfigurationAnalyzersEntity`

Represents an analyzer entity in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Analyzer description that is displayed on the form. |
| `enabled` | [`Boolean`](#boolean) | Indicates whether an analyzer is enabled. |
| `label` | [`String`](#string) | Analyzer label used in the config UI. |
| `name` | [`String`](#string) | Name of the analyzer. |
| `variables` | [`SastCiConfigurationEntityConnection`](#sastciconfigurationentityconnection) | List of supported variables. |

### `SastCiConfigurationAnalyzersEntityConnection`

The connection type for SastCiConfigurationAnalyzersEntity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SastCiConfigurationAnalyzersEntityEdge]`](#sastciconfigurationanalyzersentityedge) | A list of edges. |
| `nodes` | [`[SastCiConfigurationAnalyzersEntity]`](#sastciconfigurationanalyzersentity) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SastCiConfigurationAnalyzersEntityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SastCiConfigurationAnalyzersEntity`](#sastciconfigurationanalyzersentity) | The item at the end of the edge. |

### `SastCiConfigurationEntity`

Represents an entity in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `defaultValue` | [`String`](#string) | Default value that is used if value is empty. |
| `description` | [`String`](#string) | Entity description that is displayed on the form. |
| `field` | [`String`](#string) | CI keyword of entity. |
| `label` | [`String`](#string) | Label for entity used in the form. |
| `options` | [`SastCiConfigurationOptionsEntityConnection`](#sastciconfigurationoptionsentityconnection) | Different possible values of the field. |
| `size` | [`SastUiComponentSize`](#sastuicomponentsize) | Size of the UI component. |
| `type` | [`String`](#string) | Type of the field value. |
| `value` | [`String`](#string) | Current value of the entity. |

### `SastCiConfigurationEntityConnection`

The connection type for SastCiConfigurationEntity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SastCiConfigurationEntityEdge]`](#sastciconfigurationentityedge) | A list of edges. |
| `nodes` | [`[SastCiConfigurationEntity]`](#sastciconfigurationentity) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SastCiConfigurationEntityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SastCiConfigurationEntity`](#sastciconfigurationentity) | The item at the end of the edge. |

### `SastCiConfigurationOptionsEntity`

Represents an entity for options in SAST CI configuration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `label` | [`String`](#string) | Label of option entity. |
| `value` | [`String`](#string) | Value of option entity. |

### `SastCiConfigurationOptionsEntityConnection`

The connection type for SastCiConfigurationOptionsEntity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SastCiConfigurationOptionsEntityEdge]`](#sastciconfigurationoptionsentityedge) | A list of edges. |
| `nodes` | [`[SastCiConfigurationOptionsEntity]`](#sastciconfigurationoptionsentity) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SastCiConfigurationOptionsEntityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SastCiConfigurationOptionsEntity`](#sastciconfigurationoptionsentity) | The item at the end of the edge. |

### `Scan`

Represents the security scan information.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `errors` | [`[String!]!`](#string) | List of errors. |
| `name` | [`String!`](#string) | Name of the scan. |

### `ScanConnection`

The connection type for Scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ScanEdge]`](#scanedge) | A list of edges. |
| `nodes` | [`[Scan]`](#scan) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ScanEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Scan`](#scan) | The item at the end of the edge. |

### `ScannedResource`

Represents a resource scanned by a security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `requestMethod` | [`String`](#string) | The HTTP request method used to access the URL. |
| `url` | [`String`](#string) | The URL scanned by the scanner. |

### `ScannedResourceConnection`

The connection type for ScannedResource.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ScannedResourceEdge]`](#scannedresourceedge) | A list of edges. |
| `nodes` | [`[ScannedResource]`](#scannedresource) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ScannedResourceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`ScannedResource`](#scannedresource) | The item at the end of the edge. |

### `SecurityReportSummary`

Represents summary of a security report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `apiFuzzing` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `api_fuzzing` scan |
| `containerScanning` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `container_scanning` scan |
| `coverageFuzzing` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `coverage_fuzzing` scan |
| `dast` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `dast` scan |
| `dependencyScanning` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `dependency_scanning` scan |
| `sast` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `sast` scan |
| `secretDetection` | [`SecurityReportSummarySection`](#securityreportsummarysection) | Aggregated counts for the `secret_detection` scan |

### `SecurityReportSummarySection`

Represents a section of a summary of a security report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `scannedResources` | [`ScannedResourceConnection`](#scannedresourceconnection) | A list of the first 20 scanned resources. |
| `scannedResourcesCount` | [`Int`](#int) | Total number of scanned resources. |
| `scannedResourcesCsvPath` | [`String`](#string) | Path to download all the scanned resources in CSV format. |
| `scans` | [`ScanConnection!`](#scanconnection) | List of security scans ran for the type. |
| `vulnerabilitiesCount` | [`Int`](#int) | Total number of vulnerabilities. |

### `SecurityScanners`

Represents a list of security scanners.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `available` | [`[SecurityScannerType!]`](#securityscannertype) | List of analyzers which are available for the project. |
| `enabled` | [`[SecurityScannerType!]`](#securityscannertype) | List of analyzers which are enabled for the project. |
| `pipelineRun` | [`[SecurityScannerType!]`](#securityscannertype) | List of analyzers which ran successfully in the latest pipeline. |

### `SentryDetailedError`

A Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Count of occurrences. |
| `culprit` | [`String!`](#string) | Culprit of the error. |
| `externalBaseUrl` | [`String!`](#string) | External Base URL of the Sentry Instance. |
| `externalUrl` | [`String!`](#string) | External URL of the error. |
| `firstReleaseLastCommit` | [`String`](#string) | Commit the error was first seen. |
| `firstReleaseShortVersion` | [`String`](#string) | Release short version the error was first seen. |
| `firstReleaseVersion` | [`String`](#string) | Release version the error was first seen. |
| `firstSeen` | [`Time!`](#time) | Timestamp when the error was first seen. |
| `frequency` | [`[SentryErrorFrequency!]!`](#sentryerrorfrequency) | Last 24hr stats of the error. |
| `gitlabCommit` | [`String`](#string) | GitLab commit SHA attributed to the Error based on the release version. |
| `gitlabCommitPath` | [`String`](#string) | Path to the GitLab page for the GitLab commit attributed to the error. |
| `gitlabIssuePath` | [`String`](#string) | URL of GitLab Issue. |
| `id` | [`ID!`](#id) | ID (global ID) of the error. |
| `lastReleaseLastCommit` | [`String`](#string) | Commit the error was last seen. |
| `lastReleaseShortVersion` | [`String`](#string) | Release short version the error was last seen. |
| `lastReleaseVersion` | [`String`](#string) | Release version the error was last seen. |
| `lastSeen` | [`Time!`](#time) | Timestamp when the error was last seen. |
| `message` | [`String`](#string) | Sentry metadata message of the error. |
| `sentryId` | [`String!`](#string) | ID (Sentry ID) of the error. |
| `sentryProjectId` | [`ID!`](#id) | ID of the project (Sentry project). |
| `sentryProjectName` | [`String!`](#string) | Name of the project affected by the error. |
| `sentryProjectSlug` | [`String!`](#string) | Slug of the project affected by the error. |
| `shortId` | [`String!`](#string) | Short ID (Sentry ID) of the error. |
| `status` | [`SentryErrorStatus!`](#sentryerrorstatus) | Status of the error. |
| `tags` | [`SentryErrorTags!`](#sentryerrortags) | Tags associated with the Sentry Error. |
| `title` | [`String!`](#string) | Title of the error. |
| `type` | [`String!`](#string) | Type of the error. |
| `userCount` | [`Int!`](#int) | Count of users affected by the error. |

### `SentryError`

A Sentry error. A simplified version of SentryDetailedError.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Count of occurrences. |
| `culprit` | [`String!`](#string) | Culprit of the error. |
| `externalUrl` | [`String!`](#string) | External URL of the error. |
| `firstSeen` | [`Time!`](#time) | Timestamp when the error was first seen. |
| `frequency` | [`[SentryErrorFrequency!]!`](#sentryerrorfrequency) | Last 24hr stats of the error. |
| `id` | [`ID!`](#id) | ID (global ID) of the error. |
| `lastSeen` | [`Time!`](#time) | Timestamp when the error was last seen. |
| `message` | [`String`](#string) | Sentry metadata message of the error. |
| `sentryId` | [`String!`](#string) | ID (Sentry ID) of the error. |
| `sentryProjectId` | [`ID!`](#id) | ID of the project (Sentry project). |
| `sentryProjectName` | [`String!`](#string) | Name of the project affected by the error. |
| `sentryProjectSlug` | [`String!`](#string) | Slug of the project affected by the error. |
| `shortId` | [`String!`](#string) | Short ID (Sentry ID) of the error. |
| `status` | [`SentryErrorStatus!`](#sentryerrorstatus) | Status of the error. |
| `title` | [`String!`](#string) | Title of the error. |
| `type` | [`String!`](#string) | Type of the error. |
| `userCount` | [`Int!`](#int) | Count of users affected by the error. |

### `SentryErrorCollection`

An object containing a collection of Sentry errors, and a detailed error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `detailedError` | [`SentryDetailedError`](#sentrydetailederror) | Detailed version of a Sentry error on the project. |
| `errorStackTrace` | [`SentryErrorStackTrace`](#sentryerrorstacktrace) | Stack Trace of Sentry Error. |
| `errors` | [`SentryErrorConnection`](#sentryerrorconnection) | Collection of Sentry Errors. |
| `externalUrl` | [`String`](#string) | External URL for Sentry. |

### `SentryErrorConnection`

The connection type for SentryError.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SentryErrorEdge]`](#sentryerroredge) | A list of edges. |
| `nodes` | [`[SentryError]`](#sentryerror) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SentryErrorEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SentryError`](#sentryerror) | The item at the end of the edge. |

### `SentryErrorFrequency`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Count of errors received since the previously recorded time. |
| `time` | [`Time!`](#time) | Time the error frequency stats were recorded. |

### `SentryErrorStackTrace`

An object containing a stack trace entry for a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dateReceived` | [`String!`](#string) | Time the stack trace was received by Sentry. |
| `issueId` | [`String!`](#string) | ID of the Sentry error. |
| `stackTraceEntries` | [`[SentryErrorStackTraceEntry!]!`](#sentryerrorstacktraceentry) | Stack trace entries for the Sentry error. |

### `SentryErrorStackTraceContext`

An object context for a Sentry error stack trace.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `code` | [`String!`](#string) | Code number of the context. |
| `line` | [`Int!`](#int) | Line number of the context. |

### `SentryErrorStackTraceEntry`

An object containing a stack trace entry for a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `col` | [`String`](#string) | Function in which the Sentry error occurred. |
| `fileName` | [`String`](#string) | File in which the Sentry error occurred. |
| `function` | [`String`](#string) | Function in which the Sentry error occurred. |
| `line` | [`String`](#string) | Function in which the Sentry error occurred. |
| `traceContext` | [`[SentryErrorStackTraceContext!]`](#sentryerrorstacktracecontext) | Context of the Sentry error. |

### `SentryErrorTags`

State of a Sentry error.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `level` | [`String`](#string) | Severity level of the Sentry Error. |
| `logger` | [`String`](#string) | Logger of the Sentry Error. |

### `ServiceConnection`

The connection type for Service.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[ServiceEdge]`](#serviceedge) | A list of edges. |
| `nodes` | [`[Service]`](#service) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `ServiceEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Service`](#service) | The item at the end of the edge. |

### `Snippet`

Represents a snippet entry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User`](#user) | The owner of the snippet. |
| `blob` **{warning-solid}** | [`SnippetBlob!`](#snippetblob) | **Deprecated:** Use `blobs`. Deprecated in 13.3. |
| `blobs` | [`SnippetBlobConnection`](#snippetblobconnection) | Snippet blobs. |
| `createdAt` | [`Time!`](#time) | Timestamp this snippet was created. |
| `description` | [`String`](#string) | Description of the snippet. |
| `descriptionHtml` | [`String`](#string) | The GitLab Flavored Markdown rendering of `description` |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `fileName` | [`String`](#string) | File Name of the snippet. |
| `httpUrlToRepo` | [`String`](#string) | HTTP URL to the snippet repository. |
| `id` | [`SnippetID!`](#snippetid) | ID of the snippet. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `project` | [`Project`](#project) | The project the snippet is associated with. |
| `rawUrl` | [`String!`](#string) | Raw URL of the snippet. |
| `sshUrlToRepo` | [`String`](#string) | SSH URL to the snippet repository. |
| `title` | [`String!`](#string) | Title of the snippet. |
| `updatedAt` | [`Time!`](#time) | Timestamp this snippet was updated. |
| `userPermissions` | [`SnippetPermissions!`](#snippetpermissions) | Permissions for the current user on the resource |
| `visibilityLevel` | [`VisibilityLevelsEnum!`](#visibilitylevelsenum) | Visibility Level of the snippet. |
| `webUrl` | [`String!`](#string) | Web URL of the snippet. |

### `SnippetBlob`

Represents the snippet blob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `binary` | [`Boolean!`](#boolean) | Shows whether the blob is binary. |
| `externalStorage` | [`String`](#string) | Blob external storage. |
| `mode` | [`String`](#string) | Blob mode. |
| `name` | [`String`](#string) | Blob name. |
| `path` | [`String`](#string) | Blob path. |
| `plainData` | [`String`](#string) | Blob plain highlighted data. |
| `rawPath` | [`String!`](#string) | Blob raw content endpoint path. |
| `renderedAsText` | [`Boolean!`](#boolean) | Shows whether the blob is rendered as text. |
| `richData` | [`String`](#string) | Blob highlighted data. |
| `richViewer` | [`SnippetBlobViewer`](#snippetblobviewer) | Blob content rich viewer. |
| `simpleViewer` | [`SnippetBlobViewer!`](#snippetblobviewer) | Blob content simple viewer. |
| `size` | [`Int!`](#int) | Blob size. |

### `SnippetBlobConnection`

The connection type for SnippetBlob.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SnippetBlobEdge]`](#snippetblobedge) | A list of edges. |
| `nodes` | [`[SnippetBlob]`](#snippetblob) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SnippetBlobEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SnippetBlob`](#snippetblob) | The item at the end of the edge. |

### `SnippetBlobViewer`

Represents how the blob content should be displayed.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `collapsed` | [`Boolean!`](#boolean) | Shows whether the blob should be displayed collapsed. |
| `fileType` | [`String!`](#string) | Content file type. |
| `loadAsync` | [`Boolean!`](#boolean) | Shows whether the blob content is loaded asynchronously. |
| `loadingPartialName` | [`String!`](#string) | Loading partial name. |
| `renderError` | [`String`](#string) | Error rendering the blob content. |
| `tooLarge` | [`Boolean!`](#boolean) | Shows whether the blob too large to be displayed. |
| `type` | [`BlobViewersType!`](#blobviewerstype) | Type of blob viewer. |

### `SnippetConnection`

The connection type for Snippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SnippetEdge]`](#snippetedge) | A list of edges. |
| `nodes` | [`[Snippet]`](#snippet) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SnippetEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Snippet`](#snippet) | The item at the end of the edge. |

### `SnippetPermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_snippet` on this resource |
| `awardEmoji` | [`Boolean!`](#boolean) | Indicates the user can perform `award_emoji` on this resource |
| `createNote` | [`Boolean!`](#boolean) | Indicates the user can perform `create_note` on this resource |
| `readSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `read_snippet` on this resource |
| `reportSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `report_snippet` on this resource |
| `updateSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `update_snippet` on this resource |

### `SnippetRepositoryRegistry`

Represents the Geo sync and verification state of a snippet repository.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp when the SnippetRepositoryRegistry was created |
| `id` | [`ID!`](#id) | ID of the SnippetRepositoryRegistry |
| `lastSyncFailure` | [`String`](#string) | Error message during sync of the SnippetRepositoryRegistry |
| `lastSyncedAt` | [`Time`](#time) | Timestamp of the most recent successful sync of the SnippetRepositoryRegistry |
| `retryAt` | [`Time`](#time) | Timestamp after which the SnippetRepositoryRegistry should be resynced |
| `retryCount` | [`Int`](#int) | Number of consecutive failed sync attempts of the SnippetRepositoryRegistry |
| `snippetRepositoryId` | [`ID!`](#id) | ID of the Snippet Repository. |
| `state` | [`RegistryState`](#registrystate) | Sync state of the SnippetRepositoryRegistry |

### `SnippetRepositoryRegistryConnection`

The connection type for SnippetRepositoryRegistry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SnippetRepositoryRegistryEdge]`](#snippetrepositoryregistryedge) | A list of edges. |
| `nodes` | [`[SnippetRepositoryRegistry]`](#snippetrepositoryregistry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SnippetRepositoryRegistryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`SnippetRepositoryRegistry`](#snippetrepositoryregistry) | The item at the end of the edge. |

### `StatusAction`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `buttonTitle` | [`String`](#string) | Title for the button, for example: Retry this job. |
| `icon` | [`String`](#string) | Icon used in the action button. |
| `method` | [`String`](#string) | Method for the action, for example: :post. |
| `path` | [`String`](#string) | Path for the action. |
| `title` | [`String`](#string) | Title for the action, for example: Retry. |

### `Submodule`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | [`String!`](#string) | Flat path of the entry. |
| `id` | [`ID!`](#id) | ID of the entry. |
| `name` | [`String!`](#string) | Name of the entry. |
| `path` | [`String!`](#string) | Path of the entry. |
| `sha` | [`String!`](#string) | Last commit SHA for the entry. |
| `treeUrl` | [`String`](#string) | Tree URL for the sub-module. |
| `type` | [`EntryType!`](#entrytype) | Type of tree entry. |
| `webUrl` | [`String`](#string) | Web URL for the sub-module. |

### `SubmoduleConnection`

The connection type for Submodule.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[SubmoduleEdge]`](#submoduleedge) | A list of edges. |
| `nodes` | [`[Submodule]`](#submodule) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `SubmoduleEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Submodule`](#submodule) | The item at the end of the edge. |

### `TaskCompletionStatus`

Completion status of tasks.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `completedCount` | [`Int!`](#int) | Number of completed tasks. |
| `count` | [`Int!`](#int) | Number of total tasks. |

### `TerraformState`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp the Terraform state was created. |
| `id` | [`ID!`](#id) | ID of the Terraform state. |
| `latestVersion` | [`TerraformStateVersion`](#terraformstateversion) | The latest version of the Terraform state. |
| `lockedAt` | [`Time`](#time) | Timestamp the Terraform state was locked. |
| `lockedByUser` | [`User`](#user) | The user currently holding a lock on the Terraform state. |
| `name` | [`String!`](#string) | Name of the Terraform state. |
| `updatedAt` | [`Time!`](#time) | Timestamp the Terraform state was updated. |

### `TerraformStateConnection`

The connection type for TerraformState.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Total count of collection. |
| `edges` | [`[TerraformStateEdge]`](#terraformstateedge) | A list of edges. |
| `nodes` | [`[TerraformState]`](#terraformstate) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TerraformStateDeletePayload`

Autogenerated return type of TerraformStateDelete.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `TerraformStateEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`TerraformState`](#terraformstate) | The item at the end of the edge. |

### `TerraformStateLockPayload`

Autogenerated return type of TerraformStateLock.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `TerraformStateUnlockPayload`

Autogenerated return type of TerraformStateUnlock.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `TerraformStateVersion`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time!`](#time) | Timestamp the version was created. |
| `createdByUser` | [`User`](#user) | The user that created this version. |
| `downloadPath` | [`String`](#string) | URL for downloading the version's JSON file. |
| `id` | [`ID!`](#id) | ID of the Terraform state version. |
| `job` | [`CiJob`](#cijob) | The job that created this version. |
| `serial` | [`Int`](#int) | Serial number of the version. |
| `updatedAt` | [`Time!`](#time) | Timestamp the version was updated. |

### `TerraformStateVersionRegistry`

Represents the Geo sync and verification state of a terraform state version.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createdAt` | [`Time`](#time) | Timestamp when the TerraformStateVersionRegistry was created |
| `id` | [`ID!`](#id) | ID of the TerraformStateVersionRegistry |
| `lastSyncFailure` | [`String`](#string) | Error message during sync of the TerraformStateVersionRegistry |
| `lastSyncedAt` | [`Time`](#time) | Timestamp of the most recent successful sync of the TerraformStateVersionRegistry |
| `retryAt` | [`Time`](#time) | Timestamp after which the TerraformStateVersionRegistry should be resynced |
| `retryCount` | [`Int`](#int) | Number of consecutive failed sync attempts of the TerraformStateVersionRegistry |
| `state` | [`RegistryState`](#registrystate) | Sync state of the TerraformStateVersionRegistry |
| `terraformStateVersionId` | [`ID!`](#id) | ID of the terraform state version. |

### `TerraformStateVersionRegistryConnection`

The connection type for TerraformStateVersionRegistry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[TerraformStateVersionRegistryEdge]`](#terraformstateversionregistryedge) | A list of edges. |
| `nodes` | [`[TerraformStateVersionRegistry]`](#terraformstateversionregistry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TerraformStateVersionRegistryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`TerraformStateVersionRegistry`](#terraformstateversionregistry) | The item at the end of the edge. |

### `TestReport`

Represents a requirement test report.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `author` | [`User`](#user) | Author of the test report. |
| `createdAt` | [`Time!`](#time) | Timestamp of when the test report was created. |
| `id` | [`ID!`](#id) | ID of the test report. |
| `state` | [`TestReportState!`](#testreportstate) | State of the test report. |

### `TestReportConnection`

The connection type for TestReport.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[TestReportEdge]`](#testreportedge) | A list of edges. |
| `nodes` | [`[TestReport]`](#testreport) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TestReportEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`TestReport`](#testreport) | The item at the end of the edge. |

### `TimeReportStats`

Represents the time report stats for timeboxes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `complete` | [`TimeboxMetrics`](#timeboxmetrics) | Completed issues metrics. |
| `incomplete` | [`TimeboxMetrics`](#timeboxmetrics) | Incomplete issues metrics. |
| `total` | [`TimeboxMetrics`](#timeboxmetrics) | Total issues metrics. |

### `TimeboxMetrics`

Represents measured stats metrics for timeboxes.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | The count metric. |
| `weight` | [`Int!`](#int) | The weight metric. |

### `TimeboxReport`

Represents a historically accurate report about the timebox.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `burnupTimeSeries` | [`[BurnupChartDailyTotals!]`](#burnupchartdailytotals) | Daily scope and completed totals for burnup charts. |
| `stats` | [`TimeReportStats`](#timereportstats) | Represents the time report stats for the timebox. |

### `Timelog`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `issue` | [`Issue`](#issue) | The issue that logged time was added to. |
| `note` | [`Note`](#note) | The note where the quick action to add the logged time was executed. |
| `spentAt` | [`Time`](#time) | Timestamp of when the time tracked was spent at. |
| `timeSpent` | [`Int!`](#int) | The time spent displayed in seconds. |
| `user` | [`User!`](#user) | The user that logged the time. |

### `TimelogConnection`

The connection type for Timelog.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[TimelogEdge]`](#timelogedge) | A list of edges. |
| `nodes` | [`[Timelog]`](#timelog) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TimelogEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Timelog`](#timelog) | The item at the end of the edge. |

### `Todo`

Representing a to-do entry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `action` | [`TodoActionEnum!`](#todoactionenum) | Action of the to-do item. |
| `author` | [`User!`](#user) | The author of this to-do item. |
| `body` | [`String!`](#string) | Body of the to-do item. |
| `createdAt` | [`Time!`](#time) | Timestamp this to-do item was created. |
| `group` | [`Group`](#group) | Group this to-do item is associated with. |
| `id` | [`ID!`](#id) | ID of the to-do item. |
| `project` | [`Project`](#project) | The project this to-do item is associated with. |
| `state` | [`TodoStateEnum!`](#todostateenum) | State of the to-do item. |
| `targetType` | [`TodoTargetEnum!`](#todotargetenum) | Target type of the to-do item. |

### `TodoConnection`

The connection type for Todo.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[TodoEdge]`](#todoedge) | A list of edges. |
| `nodes` | [`[Todo]`](#todo) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TodoCreatePayload`

Autogenerated return type of TodoCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `todo` | [`Todo`](#todo) | The to-do item created. |

### `TodoEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Todo`](#todo) | The item at the end of the edge. |

### `TodoMarkDonePayload`

Autogenerated return type of TodoMarkDone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `todo` | [`Todo!`](#todo) | The requested to-do item. |

### `TodoRestoreManyPayload`

Autogenerated return type of TodoRestoreMany.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `todos` | [`[Todo!]!`](#todo) | Updated to-do items. |
| `updatedIds` **{warning-solid}** | [`[TodoID!]!`](#todoid) | **Deprecated:** Use to-do items. Deprecated in 13.2. |

### `TodoRestorePayload`

Autogenerated return type of TodoRestore.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `todo` | [`Todo!`](#todo) | The requested to-do item. |

### `TodosMarkAllDonePayload`

Autogenerated return type of TodosMarkAllDone.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `todos` | [`[Todo!]!`](#todo) | Updated to-do items. |
| `updatedIds` **{warning-solid}** | [`[TodoID!]!`](#todoid) | **Deprecated:** Use to-do items. Deprecated in 13.2. |

### `ToggleAwardEmojiPayload`

Autogenerated return type of ToggleAwardEmoji.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `awardEmoji` | [`AwardEmoji`](#awardemoji) | The award emoji after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `toggledOn` | [`Boolean!`](#boolean) | Indicates the status of the emoji. True if the toggle awarded the emoji, and false if the toggle removed the emoji. |

### `Tree`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobs` | [`BlobConnection!`](#blobconnection) | Blobs of the tree. |
| `lastCommit` | [`Commit`](#commit) | Last commit for the tree. |
| `submodules` | [`SubmoduleConnection!`](#submoduleconnection) | Sub-modules of the tree. |
| `trees` | [`TreeEntryConnection!`](#treeentryconnection) | Trees of the tree. |

### `TreeEntry`

Represents a directory.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | [`String!`](#string) | Flat path of the entry. |
| `id` | [`ID!`](#id) | ID of the entry. |
| `name` | [`String!`](#string) | Name of the entry. |
| `path` | [`String!`](#string) | Path of the entry. |
| `sha` | [`String!`](#string) | Last commit SHA for the entry. |
| `type` | [`EntryType!`](#entrytype) | Type of tree entry. |
| `webPath` | [`String`](#string) | Web path for the tree entry (directory). |
| `webUrl` | [`String`](#string) | Web URL for the tree entry (directory). |

### `TreeEntryConnection`

The connection type for TreeEntry.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[TreeEntryEdge]`](#treeentryedge) | A list of edges. |
| `nodes` | [`[TreeEntry]`](#treeentry) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `TreeEntryEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`TreeEntry`](#treeentry) | The item at the end of the edge. |

### `UpdateAlertStatusPayload`

Autogenerated return type of UpdateAlertStatus.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `alert` | [`AlertManagementAlert`](#alertmanagementalert) | The alert after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue created after mutation. |
| `todo` | [`Todo`](#todo) | The to-do item after mutation. |

### `UpdateBoardEpicUserPreferencesPayload`

Autogenerated return type of UpdateBoardEpicUserPreferences.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epicUserPreferences` | [`BoardEpicUserPreferences`](#boardepicuserpreferences) | User preferences for the epic in the board after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `UpdateBoardListPayload`

Autogenerated return type of UpdateBoardList.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `list` | [`BoardList`](#boardlist) | Mutated list. |

### `UpdateBoardPayload`

Autogenerated return type of UpdateBoard.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `board` | [`Board`](#board) | The board after mutation. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `UpdateComplianceFrameworkPayload`

Autogenerated return type of UpdateComplianceFramework.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `complianceFramework` | [`ComplianceFramework`](#complianceframework) | The compliance framework after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `UpdateContainerExpirationPolicyPayload`

Autogenerated return type of UpdateContainerExpirationPolicy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `containerExpirationPolicy` | [`ContainerExpirationPolicy`](#containerexpirationpolicy) | The container expiration policy after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `UpdateEpicPayload`

Autogenerated return type of UpdateEpic.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `epic` | [`Epic`](#epic) | The epic after mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `UpdateImageDiffNotePayload`

Autogenerated return type of UpdateImageDiffNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `UpdateIssuePayload`

Autogenerated return type of UpdateIssue.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `issue` | [`Issue`](#issue) | The issue after mutation. |

### `UpdateIterationPayload`

Autogenerated return type of UpdateIteration.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `iteration` | [`Iteration`](#iteration) | Updated iteration. |

### `UpdateNamespacePackageSettingsPayload`

Autogenerated return type of UpdateNamespacePackageSettings.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `packageSettings` | [`PackageSettings`](#packagesettings) | The namespace package setting after mutation. |

### `UpdateNotePayload`

Autogenerated return type of UpdateNote.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `note` | [`Note`](#note) | The note after mutation. |

### `UpdateRequirementPayload`

Autogenerated return type of UpdateRequirement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `requirement` | [`Requirement`](#requirement) | Requirement after mutation. |

### `UpdateSnippetPayload`

Autogenerated return type of UpdateSnippet.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `captchaSiteKey` | [`String`](#string) | The CAPTCHA site key which must be used to render a challenge for the user to solve to obtain a valid captchaResponse value. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `needsCaptchaResponse` | [`Boolean`](#boolean) | Indicates whether the operation was detected as possible spam and not completed. If CAPTCHA is enabled, the request must be resubmitted with a valid CAPTCHA response and spam_log_id included for the operation to be completed. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |
| `snippet` | [`Snippet`](#snippet) | The snippet after mutation. |
| `spam` | [`Boolean`](#boolean) | Indicates whether the operation was detected as definite spam. There is no option to resubmit the request with a CAPTCHA response. |
| `spamLogId` | [`Int`](#int) | The spam log ID which must be passed along with a valid CAPTCHA response for an operation to be completed. Included only when an operation was not completed because "NeedsCaptchaResponse" is true. |

### `UsageTrendsMeasurement`

Represents a recorded measurement (object count) for the Admins.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Object count. |
| `identifier` | [`MeasurementIdentifier!`](#measurementidentifier) | The type of objects being measured. |
| `recordedAt` | [`Time`](#time) | The time the measurement was recorded. |

### `UsageTrendsMeasurementConnection`

The connection type for UsageTrendsMeasurement.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[UsageTrendsMeasurementEdge]`](#usagetrendsmeasurementedge) | A list of edges. |
| `nodes` | [`[UsageTrendsMeasurement]`](#usagetrendsmeasurement) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `UsageTrendsMeasurementEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`UsageTrendsMeasurement`](#usagetrendsmeasurement) | The item at the end of the edge. |

### `User`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `assignedMergeRequests` | [`MergeRequestConnection`](#mergerequestconnection) | Merge Requests assigned to the user. |
| `authoredMergeRequests` | [`MergeRequestConnection`](#mergerequestconnection) | Merge Requests authored by the user. |
| `avatarUrl` | [`String`](#string) | URL of the user's avatar. |
| `bot` | [`Boolean!`](#boolean) | Indicates if the user is a bot. |
| `callouts` | [`UserCalloutConnection`](#usercalloutconnection) | User callouts that belong to the user. |
| `email` **{warning-solid}** | [`String`](#string) | **Deprecated:** Use public_email. Deprecated in 13.7. |
| `groupCount` | [`Int`](#int) | Group count for the user. Available only when feature flag `user_group_counts` is enabled. |
| `groupMemberships` | [`GroupMemberConnection`](#groupmemberconnection) | Group memberships of the user. |
| `id` | [`ID!`](#id) | ID of the user. |
| `location` | [`String`](#string) | The location of the user. |
| `name` | [`String!`](#string) | Human-readable name of the user. |
| `projectMemberships` | [`ProjectMemberConnection`](#projectmemberconnection) | Project memberships of the user. |
| `publicEmail` | [`String`](#string) | User's public email. |
| `reviewRequestedMergeRequests` | [`MergeRequestConnection`](#mergerequestconnection) | Merge Requests assigned to the user for review. |
| `snippets` | [`SnippetConnection`](#snippetconnection) | Snippets authored by the user. |
| `starredProjects` | [`ProjectConnection`](#projectconnection) | Projects starred by the user. |
| `state` | [`UserState!`](#userstate) | State of the user. |
| `status` | [`UserStatus`](#userstatus) | User status. |
| `todos` | [`TodoConnection!`](#todoconnection) | To-do items of the user. |
| `userPermissions` | [`UserPermissions!`](#userpermissions) | Permissions for the current user on the resource |
| `username` | [`String!`](#string) | Username of the user. Unique within this instance of GitLab. |
| `webPath` | [`String!`](#string) | Web path of the user. |
| `webUrl` | [`String!`](#string) | Web URL of the user. |

### `UserCallout`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dismissedAt` | [`Time`](#time) | Date when the callout was dismissed. |
| `featureName` | [`UserCalloutFeatureNameEnum!`](#usercalloutfeaturenameenum) | Name of the feature that the callout is for. |

### `UserCalloutConnection`

The connection type for UserCallout.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[UserCalloutEdge]`](#usercalloutedge) | A list of edges. |
| `nodes` | [`[UserCallout]`](#usercallout) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `UserCalloutCreatePayload`

Autogenerated return type of UserCalloutCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `userCallout` | [`UserCallout!`](#usercallout) | The user callout dismissed. |

### `UserCalloutEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`UserCallout`](#usercallout) | The item at the end of the edge. |

### `UserConnection`

The connection type for User.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[UserEdge]`](#useredge) | A list of edges. |
| `nodes` | [`[User]`](#user) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `UserEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`User`](#user) | The item at the end of the edge. |

### `UserPermissions`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `createSnippet` | [`Boolean!`](#boolean) | Indicates the user can perform `create_snippet` on this resource |

### `UserStatus`

| Field | Type | Description |
| ----- | ---- | ----------- |
| `availability` | [`AvailabilityEnum!`](#availabilityenum) | User availability status. |
| `emoji` | [`String`](#string) | String representation of emoji. |
| `message` | [`String`](#string) | User status message. |
| `messageHtml` | [`String`](#string) | HTML of the user status message |

### `VulnerabilitiesCountByDay`

Represents the count of vulnerabilities by severity on a particular day. This data is retained for 365 days.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `critical` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with critical severity |
| `date` | [`ISO8601Date!`](#iso8601date) | Date for the count. |
| `high` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with high severity |
| `info` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with info severity |
| `low` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with low severity |
| `medium` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with medium severity |
| `total` | [`Int!`](#int) | Total number of vulnerabilities on a particular day. |
| `unknown` | [`Int!`](#int) | Total number of vulnerabilities on a particular day with unknown severity |

### `VulnerabilitiesCountByDayAndSeverity`

Represents the number of vulnerabilities for a particular severity on a particular day. This data is retained for 365 days.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int`](#int) | Number of vulnerabilities. |
| `day` | [`ISO8601Date`](#iso8601date) | Date for the count. |
| `severity` | [`VulnerabilitySeverity`](#vulnerabilityseverity) | Severity of the counted vulnerabilities. |

### `VulnerabilitiesCountByDayAndSeverityConnection`

The connection type for VulnerabilitiesCountByDayAndSeverity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilitiesCountByDayAndSeverityEdge]`](#vulnerabilitiescountbydayandseverityedge) | A list of edges. |
| `nodes` | [`[VulnerabilitiesCountByDayAndSeverity]`](#vulnerabilitiescountbydayandseverity) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilitiesCountByDayAndSeverityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`VulnerabilitiesCountByDayAndSeverity`](#vulnerabilitiescountbydayandseverity) | The item at the end of the edge. |

### `VulnerabilitiesCountByDayConnection`

The connection type for VulnerabilitiesCountByDay.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilitiesCountByDayEdge]`](#vulnerabilitiescountbydayedge) | A list of edges. |
| `nodes` | [`[VulnerabilitiesCountByDay]`](#vulnerabilitiescountbyday) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilitiesCountByDayEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`VulnerabilitiesCountByDay`](#vulnerabilitiescountbyday) | The item at the end of the edge. |

### `Vulnerability`

Represents a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `confirmedAt` | [`Time`](#time) | Timestamp of when the vulnerability state was changed to confirmed. |
| `confirmedBy` | [`User`](#user) | The user that confirmed the vulnerability. |
| `description` | [`String`](#string) | Description of the vulnerability. |
| `details` | [`[VulnerabilityDetail!]!`](#vulnerabilitydetail) | Details of the vulnerability. |
| `detectedAt` | [`Time!`](#time) | Timestamp of when the vulnerability was first detected. |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `dismissedAt` | [`Time`](#time) | Timestamp of when the vulnerability state was changed to dismissed. |
| `dismissedBy` | [`User`](#user) | The user that dismissed the vulnerability. |
| `externalIssueLinks` | [`VulnerabilityExternalIssueLinkConnection!`](#vulnerabilityexternalissuelinkconnection) | List of external issue links related to the vulnerability. |
| `hasSolutions` | [`Boolean`](#boolean) | Indicates whether there is a solution available for this vulnerability. |
| `id` | [`ID!`](#id) | GraphQL ID of the vulnerability. |
| `identifiers` | [`[VulnerabilityIdentifier!]!`](#vulnerabilityidentifier) | Identifiers of the vulnerability. |
| `issueLinks` | [`VulnerabilityIssueLinkConnection!`](#vulnerabilityissuelinkconnection) | List of issue links related to the vulnerability. |
| `location` | [`VulnerabilityLocation`](#vulnerabilitylocation) | Location metadata for the vulnerability. Its fields depend on the type of security scan that found the vulnerability. |
| `mergeRequest` | [`MergeRequest`](#mergerequest) | Merge request that fixes the vulnerability. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |
| `primaryIdentifier` | [`VulnerabilityIdentifier`](#vulnerabilityidentifier) | Primary identifier of the vulnerability. |
| `project` | [`Project`](#project) | The project on which the vulnerability was found. |
| `reportType` | [`VulnerabilityReportType`](#vulnerabilityreporttype) | Type of the security report that found the vulnerability (SAST, DEPENDENCY_SCANNING, CONTAINER_SCANNING, DAST, SECRET_DETECTION, COVERAGE_FUZZING, API_FUZZING). `Scan Type` in the UI. |
| `resolvedAt` | [`Time`](#time) | Timestamp of when the vulnerability state was changed to resolved. |
| `resolvedBy` | [`User`](#user) | The user that resolved the vulnerability. |
| `resolvedOnDefaultBranch` | [`Boolean!`](#boolean) | Indicates whether the vulnerability is fixed on the default branch or not. |
| `scanner` | [`VulnerabilityScanner`](#vulnerabilityscanner) | Scanner metadata for the vulnerability. |
| `severity` | [`VulnerabilitySeverity`](#vulnerabilityseverity) | Severity of the vulnerability (INFO, UNKNOWN, LOW, MEDIUM, HIGH, CRITICAL) |
| `state` | [`VulnerabilityState`](#vulnerabilitystate) | State of the vulnerability (DETECTED, CONFIRMED, RESOLVED, DISMISSED) |
| `title` | [`String`](#string) | Title of the vulnerability. |
| `userNotesCount` | [`Int!`](#int) | Number of user notes attached to the vulnerability. |
| `userPermissions` | [`VulnerabilityPermissions!`](#vulnerabilitypermissions) | Permissions for the current user on the resource |
| `vulnerabilityPath` | [`String`](#string) | URL to the vulnerability's details page. |

### `VulnerabilityConfirmPayload`

Autogenerated return type of VulnerabilityConfirm.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after state change. |

### `VulnerabilityConnection`

The connection type for Vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilityEdge]`](#vulnerabilityedge) | A list of edges. |
| `nodes` | [`[Vulnerability]`](#vulnerability) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilityDetailBase`

Represents the vulnerability details base.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |

### `VulnerabilityDetailBoolean`

Represents the vulnerability details boolean value.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`Boolean!`](#boolean) | Value of the field. |

### `VulnerabilityDetailCode`

Represents the vulnerability details code field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `lang` | [`String`](#string) | Language of the code. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`String!`](#string) | Source code. |

### `VulnerabilityDetailCommit`

Represents the vulnerability details commit field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`String!`](#string) | The commit SHA value. |

### `VulnerabilityDetailDiff`

Represents the vulnerability details diff field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `after` | [`String!`](#string) | Value of the field after the change. |
| `before` | [`String!`](#string) | Value of the field before the change. |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |

### `VulnerabilityDetailFileLocation`

Represents the vulnerability details location within a file in the project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `fileName` | [`String!`](#string) | File name. |
| `lineEnd` | [`Int!`](#int) | End line number of the file location. |
| `lineStart` | [`Int!`](#int) | Start line number of the file location. |
| `name` | [`String`](#string) | Name of the field. |

### `VulnerabilityDetailInt`

Represents the vulnerability details integer value.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`Int!`](#int) | Value of the field. |

### `VulnerabilityDetailList`

Represents the vulnerability details list value.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `items` | [`[VulnerabilityDetail!]!`](#vulnerabilitydetail) | List of details. |
| `name` | [`String`](#string) | Name of the field. |

### `VulnerabilityDetailMarkdown`

Represents the vulnerability details Markdown field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`String!`](#string) | Value of the Markdown field. |

### `VulnerabilityDetailModuleLocation`

Represents the vulnerability details location within a file in the project.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `moduleName` | [`String!`](#string) | Module name. |
| `name` | [`String`](#string) | Name of the field. |
| `offset` | [`Int!`](#int) | Offset of the module location. |

### `VulnerabilityDetailTable`

Represents the vulnerability details table value.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `headers` | [`[VulnerabilityDetail!]!`](#vulnerabilitydetail) | Table headers. |
| `name` | [`String`](#string) | Name of the field. |
| `rows` | [`[VulnerabilityDetail!]!`](#vulnerabilitydetail) | Table rows. |

### `VulnerabilityDetailText`

Represents the vulnerability details text field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `name` | [`String`](#string) | Name of the field. |
| `value` | [`String!`](#string) | Value of the text field. |

### `VulnerabilityDetailUrl`

Represents the vulnerability details URL field.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `description` | [`String`](#string) | Description of the field. |
| `fieldName` | [`String`](#string) | Name of the field. |
| `href` | [`String!`](#string) | Href of the URL. |
| `name` | [`String`](#string) | Name of the field. |
| `text` | [`String`](#string) | Text of the URL. |

### `VulnerabilityDismissPayload`

Autogenerated return type of VulnerabilityDismiss.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after dismissal. |

### `VulnerabilityEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`Vulnerability`](#vulnerability) | The item at the end of the edge. |

### `VulnerabilityExternalIssueLink`

Represents an external issue link of a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalIssue` | [`ExternalIssue`](#externalissue) | The external issue attached to the issue link. |
| `id` | [`VulnerabilitiesExternalIssueLinkID!`](#vulnerabilitiesexternalissuelinkid) | GraphQL ID of the external issue link. |
| `linkType` | [`VulnerabilityExternalIssueLinkType!`](#vulnerabilityexternalissuelinktype) | Type of the external issue link. |

### `VulnerabilityExternalIssueLinkConnection`

The connection type for VulnerabilityExternalIssueLink.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilityExternalIssueLinkEdge]`](#vulnerabilityexternalissuelinkedge) | A list of edges. |
| `nodes` | [`[VulnerabilityExternalIssueLink]`](#vulnerabilityexternalissuelink) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilityExternalIssueLinkCreatePayload`

Autogenerated return type of VulnerabilityExternalIssueLinkCreate.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `externalIssueLink` | [`VulnerabilityExternalIssueLink`](#vulnerabilityexternalissuelink) | The created external issue link. |

### `VulnerabilityExternalIssueLinkDestroyPayload`

Autogenerated return type of VulnerabilityExternalIssueLinkDestroy.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |

### `VulnerabilityExternalIssueLinkEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`VulnerabilityExternalIssueLink`](#vulnerabilityexternalissuelink) | The item at the end of the edge. |

### `VulnerabilityIdentifier`

Represents a vulnerability identifier.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalId` | [`String`](#string) | External ID of the vulnerability identifier. |
| `externalType` | [`String`](#string) | External type of the vulnerability identifier. |
| `name` | [`String`](#string) | Name of the vulnerability identifier. |
| `url` | [`String`](#string) | URL of the vulnerability identifier. |

### `VulnerabilityIssueLink`

Represents an issue link of a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `id` | [`ID!`](#id) | GraphQL ID of the vulnerability. |
| `issue` | [`Issue!`](#issue) | The issue attached to issue link. |
| `linkType` | [`VulnerabilityIssueLinkType!`](#vulnerabilityissuelinktype) | Type of the issue link. |

### `VulnerabilityIssueLinkConnection`

The connection type for VulnerabilityIssueLink.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilityIssueLinkEdge]`](#vulnerabilityissuelinkedge) | A list of edges. |
| `nodes` | [`[VulnerabilityIssueLink]`](#vulnerabilityissuelink) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilityIssueLinkEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`VulnerabilityIssueLink`](#vulnerabilityissuelink) | The item at the end of the edge. |

### `VulnerabilityLocationContainerScanning`

Represents the location of a vulnerability found by a container security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `dependency` | [`VulnerableDependency`](#vulnerabledependency) | Dependency containing the vulnerability. |
| `image` | [`String`](#string) | Name of the vulnerable container image. |
| `operatingSystem` | [`String`](#string) | Operating system that runs on the vulnerable container image. |

### `VulnerabilityLocationCoverageFuzzing`

Represents the location of a vulnerability found by a Coverage Fuzzing scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobPath` | [`String`](#string) | Blob path to the vulnerable file. |
| `endLine` | [`String`](#string) | Number of the last relevant line in the vulnerable file. |
| `file` | [`String`](#string) | Path to the vulnerable file. |
| `startLine` | [`String`](#string) | Number of the first relevant line in the vulnerable file. |
| `vulnerableClass` | [`String`](#string) | Class containing the vulnerability. |
| `vulnerableMethod` | [`String`](#string) | Method containing the vulnerability. |

### `VulnerabilityLocationDast`

Represents the location of a vulnerability found by a DAST scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `hostname` | [`String`](#string) | Domain name of the vulnerable request. |
| `param` | [`String`](#string) | Query parameter for the URL on which the vulnerability occurred. |
| `path` | [`String`](#string) | URL path and query string of the vulnerable request. |
| `requestMethod` | [`String`](#string) | HTTP method of the vulnerable request. |

### `VulnerabilityLocationDependencyScanning`

Represents the location of a vulnerability found by a dependency security scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobPath` | [`String`](#string) | Blob path to the vulnerable file. |
| `dependency` | [`VulnerableDependency`](#vulnerabledependency) | Dependency containing the vulnerability. |
| `file` | [`String`](#string) | Path to the vulnerable file. |

### `VulnerabilityLocationSast`

Represents the location of a vulnerability found by a SAST scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobPath` | [`String`](#string) | Blob path to the vulnerable file. |
| `endLine` | [`String`](#string) | Number of the last relevant line in the vulnerable file. |
| `file` | [`String`](#string) | Path to the vulnerable file. |
| `startLine` | [`String`](#string) | Number of the first relevant line in the vulnerable file. |
| `vulnerableClass` | [`String`](#string) | Class containing the vulnerability. |
| `vulnerableMethod` | [`String`](#string) | Method containing the vulnerability. |

### `VulnerabilityLocationSecretDetection`

Represents the location of a vulnerability found by a secret detection scan.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `blobPath` | [`String`](#string) | Blob path to the vulnerable file. |
| `endLine` | [`String`](#string) | Number of the last relevant line in the vulnerable file. |
| `file` | [`String`](#string) | Path to the vulnerable file. |
| `startLine` | [`String`](#string) | Number of the first relevant line in the vulnerable file. |
| `vulnerableClass` | [`String`](#string) | Class containing the vulnerability. |
| `vulnerableMethod` | [`String`](#string) | Method containing the vulnerability. |

### `VulnerabilityPermissions`

Check permissions for the current user on a vulnerability.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `adminVulnerability` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_vulnerability` on this resource |
| `adminVulnerabilityExternalIssueLink` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_vulnerability_external_issue_link` on this resource |
| `adminVulnerabilityIssueLink` | [`Boolean!`](#boolean) | Indicates the user can perform `admin_vulnerability_issue_link` on this resource |
| `createVulnerability` | [`Boolean!`](#boolean) | Indicates the user can perform `create_vulnerability` on this resource |
| `createVulnerabilityExport` | [`Boolean!`](#boolean) | Indicates the user can perform `create_vulnerability_export` on this resource |
| `createVulnerabilityFeedback` | [`Boolean!`](#boolean) | Indicates the user can perform `create_vulnerability_feedback` on this resource |
| `destroyVulnerabilityFeedback` | [`Boolean!`](#boolean) | Indicates the user can perform `destroy_vulnerability_feedback` on this resource |
| `readVulnerabilityFeedback` | [`Boolean!`](#boolean) | Indicates the user can perform `read_vulnerability_feedback` on this resource |
| `updateVulnerabilityFeedback` | [`Boolean!`](#boolean) | Indicates the user can perform `update_vulnerability_feedback` on this resource |

### `VulnerabilityResolvePayload`

Autogenerated return type of VulnerabilityResolve.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after state change. |

### `VulnerabilityRevertToDetectedPayload`

Autogenerated return type of VulnerabilityRevertToDetected.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `clientMutationId` | [`String`](#string) | A unique identifier for the client performing the mutation. |
| `errors` | [`[String!]!`](#string) | Errors encountered during execution of the mutation. |
| `vulnerability` | [`Vulnerability`](#vulnerability) | The vulnerability after revert. |

### `VulnerabilityScanner`

Represents a vulnerability scanner.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `externalId` | [`String`](#string) | External ID of the vulnerability scanner. |
| `name` | [`String`](#string) | Name of the vulnerability scanner. |
| `reportType` | [`VulnerabilityReportType`](#vulnerabilityreporttype) | Type of the vulnerability report. |
| `vendor` | [`String`](#string) | Vendor of the vulnerability scanner. |

### `VulnerabilityScannerConnection`

The connection type for VulnerabilityScanner.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `edges` | [`[VulnerabilityScannerEdge]`](#vulnerabilityscanneredge) | A list of edges. |
| `nodes` | [`[VulnerabilityScanner]`](#vulnerabilityscanner) | A list of nodes. |
| `pageInfo` | [`PageInfo!`](#pageinfo) | Information to aid in pagination. |

### `VulnerabilityScannerEdge`

An edge in a connection.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `cursor` | [`String!`](#string) | A cursor for use in pagination. |
| `node` | [`VulnerabilityScanner`](#vulnerabilityscanner) | The item at the end of the edge. |

### `VulnerabilitySeveritiesCount`

Represents vulnerability counts by severity.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `critical` | [`Int`](#int) | Number of vulnerabilities of CRITICAL severity of the project |
| `high` | [`Int`](#int) | Number of vulnerabilities of HIGH severity of the project |
| `info` | [`Int`](#int) | Number of vulnerabilities of INFO severity of the project |
| `low` | [`Int`](#int) | Number of vulnerabilities of LOW severity of the project |
| `medium` | [`Int`](#int) | Number of vulnerabilities of MEDIUM severity of the project |
| `unknown` | [`Int`](#int) | Number of vulnerabilities of UNKNOWN severity of the project |

### `VulnerableDependency`

Represents a vulnerable dependency. Used in vulnerability location data.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `package` | [`VulnerablePackage`](#vulnerablepackage) | The package associated with the vulnerable dependency. |
| `version` | [`String`](#string) | The version of the vulnerable dependency. |

### `VulnerablePackage`

Represents a vulnerable package. Used in vulnerability dependency data.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `name` | [`String`](#string) | The name of the vulnerable package. |

### `VulnerableProjectsByGrade`

Represents vulnerability letter grades with associated projects.

| Field | Type | Description |
| ----- | ---- | ----------- |
| `count` | [`Int!`](#int) | Number of projects within this grade. |
| `grade` | [`VulnerabilityGrade!`](#vulnerabilitygrade) | Grade based on the highest severity vulnerability present. |
| `projects` | [`ProjectConnection!`](#projectconnection) | Projects within this grade. |

## Enumeration types

Also called _Enums_, enumeration types are a special kind of scalar that
is restricted to a particular set of allowed values.

For more information, see
[Enumeration Types](https://graphql.org/learn/schema/#enumeration-types)
on `graphql.org`.

### `AccessLevelEnum`

Access level to a resource.

| Value | Description |
| ----- | ----------- |
| `DEVELOPER` | Developer access |
| `GUEST` | Guest access |
| `MAINTAINER` | Maintainer access |
| `MINIMAL_ACCESS` | Minimal access |
| `NO_ACCESS` | No access |
| `OWNER` | Owner access |
| `REPORTER` | Reporter access |

### `AlertManagementAlertSort`

Values for sorting alerts.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `CREATED_TIME_ASC` | Created time by ascending order. |
| `CREATED_TIME_DESC` | Created time by descending order. |
| `ENDED_AT_ASC` | End time by ascending order. |
| `ENDED_AT_DESC` | End time by descending order. |
| `EVENT_COUNT_ASC` | Events count by ascending order. |
| `EVENT_COUNT_DESC` | Events count by descending order. |
| `SEVERITY_ASC` | Severity from less critical to more critical. |
| `SEVERITY_DESC` | Severity from more critical to less critical. |
| `STARTED_AT_ASC` | Start time by ascending order. |
| `STARTED_AT_DESC` | Start time by descending order. |
| `STATUS_ASC` | Status by order: Ignored > Resolved > Acknowledged > Triggered. |
| `STATUS_DESC` | Status by order: Triggered > Acknowledged > Resolved > Ignored. |
| `UPDATED_ASC` | Updated at ascending order. |
| `UPDATED_DESC` | Updated at descending order. |
| `UPDATED_TIME_ASC` | Created time by ascending order. |
| `UPDATED_TIME_DESC` | Created time by descending order. |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### `AlertManagementDomainFilter`

Filters the alerts based on given domain.

| Value | Description |
| ----- | ----------- |
| `operations` | Alerts for operations domain. |
| `threat_monitoring` | Alerts for threat monitoring domain. |

### `AlertManagementIntegrationType`

Values of types of integrations.

| Value | Description |
| ----- | ----------- |
| `HTTP` | Integration with any monitoring tool. |
| `PROMETHEUS` | Prometheus integration. |

### `AlertManagementPayloadAlertFieldName`

Values for alert field names used in the custom mapping.

| Value | Description |
| ----- | ----------- |
| `DESCRIPTION` | A high-level summary of the problem. |
| `END_TIME` | The resolved time of the incident. |
| `FINGERPRINT` | The unique identifier of the alert. This can be used to group occurrences of the same alert. |
| `GITLAB_ENVIRONMENT_NAME` | The name of the associated GitLab environment. |
| `HOSTS` | One or more hosts, as to where this incident occurred. |
| `MONITORING_TOOL` | The name of the associated monitoring tool. |
| `SERVICE` | The affected service. |
| `SEVERITY` | The severity of the alert. |
| `START_TIME` | The time of the incident. |
| `TITLE` | The title of the incident. |

### `AlertManagementPayloadAlertFieldType`

Values for alert field types used in the custom mapping.

| Value | Description |
| ----- | ----------- |
| `ARRAY` | Array field type. |
| `DATETIME` | DateTime field type. |
| `STRING` | String field type. |

### `AlertManagementSeverity`

Alert severity values.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` | Critical severity |
| `HIGH` | High severity |
| `INFO` | Info severity |
| `LOW` | Low severity |
| `MEDIUM` | Medium severity |
| `UNKNOWN` | Unknown severity |

### `AlertManagementStatus`

Alert status values.

| Value | Description |
| ----- | ----------- |
| `ACKNOWLEDGED` | Acknowledged status |
| `IGNORED` | Ignored status |
| `RESOLVED` | Resolved status |
| `TRIGGERED` | Triggered status |

### `ApiFuzzingScanMode`

All possible ways to specify the API surface for an API fuzzing scan.

| Value | Description |
| ----- | ----------- |
| `HAR` | The API surface is specified by a HAR file. |
| `OPENAPI` | The API surface is specified by a OPENAPI file. |
| `POSTMAN` | The API surface is specified by a POSTMAN file. |

### `AvailabilityEnum`

User availability status.

| Value | Description |
| ----- | ----------- |
| `BUSY` | Busy |
| `NOT_SET` | Not Set |

### `BlobViewersType`

Types of blob viewers.

| Value | Description |
| ----- | ----------- |
| `auxiliary` | Auxiliary blob viewers type. |
| `rich` | Rich blob viewers type. |
| `simple` | Simple blob viewers type. |

### `CiConfigStatus`

Values for YAML processor result.

| Value | Description |
| ----- | ----------- |
| `INVALID` | The configuration file is not valid. |
| `VALID` | The configuration file is valid. |

### `CommitActionMode`

Mode of a commit action.

| Value | Description |
| ----- | ----------- |
| `CHMOD` | Chmod command. |
| `CREATE` | Create command. |
| `DELETE` | Delete command. |
| `MOVE` | Move command. |
| `UPDATE` | Update command. |

### `CommitEncoding`

| Value | Description |
| ----- | ----------- |
| `BASE64` | Base64 encoding. |
| `TEXT` | Text encoding. |

### `ContainerExpirationPolicyCadenceEnum`

| Value | Description |
| ----- | ----------- |
| `EVERY_DAY` | Every day |
| `EVERY_MONTH` | Every month |
| `EVERY_THREE_MONTHS` | Every three months |
| `EVERY_TWO_WEEKS` | Every two weeks |
| `EVERY_WEEK` | Every week |

### `ContainerExpirationPolicyKeepEnum`

| Value | Description |
| ----- | ----------- |
| `FIFTY_TAGS` | 50 tags per image name |
| `FIVE_TAGS` | 5 tags per image name |
| `ONE_HUNDRED_TAGS` | 100 tags per image name |
| `ONE_TAG` | 1 tag per image name |
| `TEN_TAGS` | 10 tags per image name |
| `TWENTY_FIVE_TAGS` | 25 tags per image name |

### `ContainerExpirationPolicyOlderThanEnum`

| Value | Description |
| ----- | ----------- |
| `FOURTEEN_DAYS` | 14 days until tags are automatically removed |
| `NINETY_DAYS` | 90 days until tags are automatically removed |
| `SEVEN_DAYS` | 7 days until tags are automatically removed |
| `THIRTY_DAYS` | 30 days until tags are automatically removed |

### `ContainerRepositoryCleanupStatus`

Status of the tags cleanup of a container repository.

| Value | Description |
| ----- | ----------- |
| `ONGOING` | The tags cleanup is ongoing. |
| `SCHEDULED` | The tags cleanup is scheduled and is going to be executed shortly. |
| `UNFINISHED` | The tags cleanup has been partially executed. There are still remaining tags to delete. |
| `UNSCHEDULED` | The tags cleanup is not scheduled. This is the default state. |

### `ContainerRepositorySort`

Values for sorting container repositories.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `NAME_ASC` | Name by ascending order. |
| `NAME_DESC` | Name by descending order. |
| `UPDATED_ASC` | Updated at ascending order. |
| `UPDATED_DESC` | Updated at descending order. |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### `ContainerRepositoryStatus`

Status of a container repository.

| Value | Description |
| ----- | ----------- |
| `DELETE_FAILED` | Delete Failed status. |
| `DELETE_SCHEDULED` | Delete Scheduled status. |

### `DastScanTypeEnum`

| Value | Description |
| ----- | ----------- |
| `ACTIVE` | Active DAST scan. This scan will make active attacks against the target site. |
| `PASSIVE` | Passive DAST scan. This scan will not make active attacks against the target site. |

### `DastSiteProfileValidationStatusEnum`

| Value | Description |
| ----- | ----------- |
| `FAILED_VALIDATION` | Site validation process finished but failed. |
| `INPROGRESS_VALIDATION` | Site validation process is in progress. |
| `NONE` | No site validation exists. |
| `PASSED_VALIDATION` | Site validation process finished successfully. |
| `PENDING_VALIDATION` | Site validation process has not started. |

### `DastSiteValidationStrategyEnum`

| Value | Description |
| ----- | ----------- |
| `HEADER` | Header validation. |
| `TEXT_FILE` | Text file validation. |

### `DataVisualizationColorEnum`

Color of the data visualization palette.

| Value | Description |
| ----- | ----------- |
| `AQUA` | Aqua color |
| `BLUE` | Blue color |
| `GREEN` | Green color |
| `MAGENTA` | Magenta color |
| `ORANGE` | Orange color |

### `DataVisualizationWeightEnum`

Weight of the data visualization palette.

| Value | Description |
| ----- | ----------- |
| `WEIGHT_100` | 100 weight |
| `WEIGHT_200` | 200 weight |
| `WEIGHT_300` | 300 weight |
| `WEIGHT_400` | 400 weight |
| `WEIGHT_50` | 50 weight |
| `WEIGHT_500` | 500 weight |
| `WEIGHT_600` | 600 weight |
| `WEIGHT_700` | 700 weight |
| `WEIGHT_800` | 800 weight |
| `WEIGHT_900` | 900 weight |
| `WEIGHT_950` | 950 weight |

### `DesignCollectionCopyState`

Copy state of a DesignCollection.

| Value | Description |
| ----- | ----------- |
| `ERROR` | The DesignCollection encountered an error during a copy |
| `IN_PROGRESS` | The DesignCollection is being copied |
| `READY` | The DesignCollection has no copy in progress |

### `DesignVersionEvent`

Mutation event of a design within a version.

| Value | Description |
| ----- | ----------- |
| `CREATION` | A creation event |
| `DELETION` | A deletion event |
| `MODIFICATION` | A modification event |
| `NONE` | No change. |

### `DiffPositionType`

Type of file the position refers to.

| Value | Description |
| ----- | ----------- |
| `image` | An image |
| `text` | A text file |

### `EntryType`

Type of a tree entry.

| Value | Description |
| ----- | ----------- |
| `blob` |  |
| `commit` |  |
| `tree` |  |

### `EpicSort`

Roadmap sort values.

| Value | Description |
| ----- | ----------- |
| `end_date_asc` | End date at ascending order. |
| `end_date_desc` | End date at descending order. |
| `start_date_asc` | Start date at ascending order. |
| `start_date_desc` | Start date at descending order. |

### `EpicState`

State of an epic.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `opened` |  |

### `EpicStateEvent`

State event of an epic.

| Value | Description |
| ----- | ----------- |
| `CLOSE` | Close the epic. |
| `REOPEN` | Reopen the epic. |

### `EpicWildcardId`

Epic ID wildcard values.

| Value | Description |
| ----- | ----------- |
| `ANY` | Any epic is assigned. |
| `NONE` | No epic is assigned. |

### `EventAction`

Event action.

| Value | Description |
| ----- | ----------- |
| `APPROVED` | Approved action |
| `ARCHIVED` | Archived action |
| `CLOSED` | Closed action |
| `COMMENTED` | Commented action |
| `CREATED` | Created action |
| `DESTROYED` | Destroyed action |
| `EXPIRED` | Expired action |
| `JOINED` | Joined action |
| `LEFT` | Left action |
| `MERGED` | Merged action |
| `PUSHED` | Pushed action |
| `REOPENED` | Reopened action |
| `UPDATED` | Updated action |

### `GroupMemberRelation`

Group member relation.

| Value | Description |
| ----- | ----------- |
| `DESCENDANTS` | Descendants members |
| `DIRECT` | Direct members |
| `INHERITED` | Inherited members |

### `HealthStatus`

Health status of an issue or epic.

| Value | Description |
| ----- | ----------- |
| `atRisk` |  |
| `needsAttention` |  |
| `onTrack` |  |

### `IssuableSeverity`

Incident severity.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` | Critical severity |
| `HIGH` | High severity |
| `LOW` | Low severity |
| `MEDIUM` | Medium severity |
| `UNKNOWN` | Unknown severity |

### `IssuableState`

State of a GitLab issue or merge request.

| Value | Description |
| ----- | ----------- |
| `all` | All available. |
| `closed` | In closed state. |
| `locked` | Discussion has been locked. |
| `opened` | In open state. |

### `IssueSort`

Values for sorting issues.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `DUE_DATE_ASC` | Due date by ascending order. |
| `DUE_DATE_DESC` | Due date by descending order. |
| `LABEL_PRIORITY_ASC` | Label priority by ascending order. |
| `LABEL_PRIORITY_DESC` | Label priority by descending order. |
| `MILESTONE_DUE_ASC` | Milestone due date by ascending order. |
| `MILESTONE_DUE_DESC` | Milestone due date by descending order. |
| `PRIORITY_ASC` | Priority by ascending order. |
| `PRIORITY_DESC` | Priority by descending order. |
| `PUBLISHED_ASC` | Published issues shown last. |
| `PUBLISHED_DESC` | Published issues shown first. |
| `RELATIVE_POSITION_ASC` | Relative position by ascending order. |
| `SEVERITY_ASC` | Severity from less critical to more critical. |
| `SEVERITY_DESC` | Severity from more critical to less critical. |
| `SLA_DUE_AT_ASC` | Issues with earliest SLA due time shown first. |
| `SLA_DUE_AT_DESC` | Issues with latest SLA due time shown first. |
| `UPDATED_ASC` | Updated at ascending order. |
| `UPDATED_DESC` | Updated at descending order. |
| `WEIGHT_ASC` | Weight by ascending order. |
| `WEIGHT_DESC` | Weight by descending order. |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### `IssueState`

State of a GitLab issue.

| Value | Description |
| ----- | ----------- |
| `all` | All available. |
| `closed` | In closed state. |
| `locked` | Discussion has been locked. |
| `opened` | In open state. |

### `IssueStateEvent`

Values for issue state events.

| Value | Description |
| ----- | ----------- |
| `CLOSE` | Closes the issue. |
| `REOPEN` | Reopens the issue. |

### `IssueType`

Issue type.

| Value | Description |
| ----- | ----------- |
| `INCIDENT` | Incident issue type |
| `ISSUE` | Issue issue type |
| `TEST_CASE` | Test Case issue type |

### `IterationState`

State of a GitLab iteration.

| Value | Description |
| ----- | ----------- |
| `all` |  |
| `closed` |  |
| `opened` |  |
| `started` |  |
| `upcoming` |  |

### `IterationWildcardId`

Iteration ID wildcard values.

| Value | Description |
| ----- | ----------- |
| `ANY` | An iteration is assigned. |
| `CURRENT` | Current iteration. |
| `NONE` | No iteration is assigned. |

### `JobArtifactFileType`

| Value | Description |
| ----- | ----------- |
| `ACCESSIBILITY` | ACCESSIBILITY job artifact file type. |
| `API_FUZZING` | API FUZZING job artifact file type. |
| `ARCHIVE` | ARCHIVE job artifact file type. |
| `BROWSER_PERFORMANCE` | BROWSER PERFORMANCE job artifact file type. |
| `CLUSTER_APPLICATIONS` | CLUSTER APPLICATIONS job artifact file type. |
| `COBERTURA` | COBERTURA job artifact file type. |
| `CODEQUALITY` | CODE QUALITY job artifact file type. |
| `CONTAINER_SCANNING` | CONTAINER SCANNING job artifact file type. |
| `COVERAGE_FUZZING` | COVERAGE FUZZING job artifact file type. |
| `DAST` | DAST job artifact file type. |
| `DEPENDENCY_SCANNING` | DEPENDENCY SCANNING job artifact file type. |
| `DOTENV` | DOTENV job artifact file type. |
| `JUNIT` | JUNIT job artifact file type. |
| `LICENSE_MANAGEMENT` | LICENSE MANAGEMENT job artifact file type. |
| `LICENSE_SCANNING` | LICENSE SCANNING job artifact file type. |
| `LOAD_PERFORMANCE` | LOAD PERFORMANCE job artifact file type. |
| `LSIF` | LSIF job artifact file type. |
| `METADATA` | METADATA job artifact file type. |
| `METRICS` | METRICS job artifact file type. |
| `METRICS_REFEREE` | METRICS REFEREE job artifact file type. |
| `NETWORK_REFEREE` | NETWORK REFEREE job artifact file type. |
| `PERFORMANCE` | PERFORMANCE job artifact file type. |
| `REQUIREMENTS` | REQUIREMENTS job artifact file type. |
| `SAST` | SAST job artifact file type. |
| `SECRET_DETECTION` | SECRET DETECTION job artifact file type. |
| `TERRAFORM` | TERRAFORM job artifact file type. |
| `TRACE` | TRACE job artifact file type. |

### `ListLimitMetric`

List limit metric setting.

| Value | Description |
| ----- | ----------- |
| `all_metrics` |  |
| `issue_count` |  |
| `issue_weights` |  |

### `MeasurementIdentifier`

Possible identifier types for a measurement.

| Value | Description |
| ----- | ----------- |
| `GROUPS` | Group count. |
| `ISSUES` | Issue count. |
| `MERGE_REQUESTS` | Merge request count. |
| `PIPELINES` | Pipeline count. |
| `PIPELINES_CANCELED` | Pipeline count with canceled status. |
| `PIPELINES_FAILED` | Pipeline count with failed status. |
| `PIPELINES_SKIPPED` | Pipeline count with skipped status. |
| `PIPELINES_SUCCEEDED` | Pipeline count with success status. |
| `PROJECTS` | Project count. |
| `USERS` | User count. |

### `MergeRequestNewState`

New state to apply to a merge request.

| Value | Description |
| ----- | ----------- |
| `CLOSED` | Close the merge request if it is open. |
| `OPEN` | Open the merge request if it is closed. |

### `MergeRequestSort`

Values for sorting merge requests.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `LABEL_PRIORITY_ASC` | Label priority by ascending order. |
| `LABEL_PRIORITY_DESC` | Label priority by descending order. |
| `MERGED_AT_ASC` | Merge time by ascending order. |
| `MERGED_AT_DESC` | Merge time by descending order. |
| `MILESTONE_DUE_ASC` | Milestone due date by ascending order. |
| `MILESTONE_DUE_DESC` | Milestone due date by descending order. |
| `PRIORITY_ASC` | Priority by ascending order. |
| `PRIORITY_DESC` | Priority by descending order. |
| `UPDATED_ASC` | Updated at ascending order. |
| `UPDATED_DESC` | Updated at descending order. |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### `MergeRequestState`

State of a GitLab merge request.

| Value | Description |
| ----- | ----------- |
| `all` | All available. |
| `closed` | In closed state. |
| `locked` | Discussion has been locked. |
| `merged` | Merge Request has been merged. |
| `opened` | In open state. |

### `MergeStrategyEnum`

| Value | Description |
| ----- | ----------- |
| `ADD_TO_MERGE_TRAIN_WHEN_PIPELINE_SUCCEEDS` | Use the add_to_merge_train_when_pipeline_succeeds merge strategy. |
| `MERGE_TRAIN` | Use the merge_train merge strategy. |
| `MERGE_WHEN_PIPELINE_SUCCEEDS` | Use the merge_when_pipeline_succeeds merge strategy. |

### `MilestoneStateEnum`

Current state of milestone.

| Value | Description |
| ----- | ----------- |
| `active` | Milestone is currently active. |
| `closed` | Milestone is closed. |

### `MoveType`

The position to which the adjacent object should be moved.

| Value | Description |
| ----- | ----------- |
| `after` | The adjacent object will be moved after the object that is being moved. |
| `before` | The adjacent object will be moved before the object that is being moved. |

### `MutationOperationMode`

Different toggles for changing mutator behavior.

| Value | Description |
| ----- | ----------- |
| `APPEND` | Performs an append operation. |
| `REMOVE` | Performs a removal operation. |
| `REPLACE` | Performs a replace operation. |

### `NamespaceProjectSort`

Values for sorting projects.

| Value | Description |
| ----- | ----------- |
| `SIMILARITY` | Most similar to the search query. |
| `STORAGE` | Sort by storage size. |

### `OncallRotationUnitEnum`

Rotation length unit of an on-call rotation.

| Value | Description |
| ----- | ----------- |
| `DAYS` | Days |
| `HOURS` | Hours |
| `WEEKS` | Weeks |

### `PackageTypeEnum`

| Value | Description |
| ----- | ----------- |
| `COMPOSER` | Packages from the Composer package manager |
| `CONAN` | Packages from the Conan package manager |
| `DEBIAN` | Packages from the Debian package manager |
| `GENERIC` | Packages from the Generic package manager |
| `GOLANG` | Packages from the Golang package manager |
| `MAVEN` | Packages from the Maven package manager |
| `NPM` | Packages from the npm package manager |
| `NUGET` | Packages from the Nuget package manager |
| `PYPI` | Packages from the PyPI package manager |
| `RUBYGEMS` | Packages from the Rubygems package manager |

### `PipelineConfigSourceEnum`

| Value | Description |
| ----- | ----------- |
| `AUTO_DEVOPS_SOURCE` |  |
| `BRIDGE_SOURCE` |  |
| `COMPLIANCE_SOURCE` |  |
| `EXTERNAL_PROJECT_SOURCE` |  |
| `PARAMETER_SOURCE` |  |
| `REMOTE_SOURCE` |  |
| `REPOSITORY_SOURCE` |  |
| `UNKNOWN_SOURCE` |  |
| `WEBIDE_SOURCE` |  |

### `PipelineStatusEnum`

| Value | Description |
| ----- | ----------- |
| `CANCELED` |  |
| `CREATED` |  |
| `FAILED` |  |
| `MANUAL` |  |
| `PENDING` |  |
| `PREPARING` |  |
| `RUNNING` |  |
| `SCHEDULED` |  |
| `SKIPPED` |  |
| `SUCCESS` |  |
| `WAITING_FOR_RESOURCE` |  |

### `ProjectMemberRelation`

Project member relation.

| Value | Description |
| ----- | ----------- |
| `DESCENDANTS` | Descendants members |
| `DIRECT` | Direct members |
| `INHERITED` | Inherited members |
| `INVITED_GROUPS` | Invited Groups members |

### `RegistryState`

State of a Geo registry.

| Value | Description |
| ----- | ----------- |
| `FAILED` | Registry that failed to sync. |
| `PENDING` | Registry waiting to be synced. |
| `STARTED` | Registry currently syncing. |
| `SYNCED` | Registry that is synced. |

### `ReleaseAssetLinkType`

Type of the link: `other`, `runbook`, `image`, `package`.

| Value | Description |
| ----- | ----------- |
| `IMAGE` | Image link type |
| `OTHER` | Other link type |
| `PACKAGE` | Package link type |
| `RUNBOOK` | Runbook link type |

### `ReleaseSort`

Values for sorting releases.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `RELEASED_AT_ASC` | Released at by ascending order. |
| `RELEASED_AT_DESC` | Released at by descending order. |

### `RequirementState`

State of a requirement.

| Value | Description |
| ----- | ----------- |
| `ARCHIVED` |  |
| `OPENED` |  |

### `RequirementStatusFilter`

Status of a requirement based on last test report.

| Value | Description |
| ----- | ----------- |
| `FAILED` |  |
| `MISSING` | Requirements without any test report. |
| `PASSED` |  |

### `SastUiComponentSize`

Size of UI component in SAST configuration page.

| Value | Description |
| ----- | ----------- |
| `LARGE` | The size of UI component in SAST configuration page is large. |
| `MEDIUM` | The size of UI component in SAST configuration page is medium. |
| `SMALL` | The size of UI component in SAST configuration page is small. |

### `SecurityReportTypeEnum`

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` | API FUZZING scan report |
| `CONTAINER_SCANNING` | CONTAINER SCANNING scan report |
| `COVERAGE_FUZZING` | COVERAGE FUZZING scan report |
| `DAST` | DAST scan report |
| `DEPENDENCY_SCANNING` | DEPENDENCY SCANNING scan report |
| `SAST` | SAST scan report |
| `SECRET_DETECTION` | SECRET DETECTION scan report |

### `SecurityScannerType`

The type of the security scanner.

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` |  |
| `CONTAINER_SCANNING` |  |
| `COVERAGE_FUZZING` |  |
| `DAST` |  |
| `DEPENDENCY_SCANNING` |  |
| `SAST` |  |
| `SECRET_DETECTION` |  |

### `SentryErrorStatus`

State of a Sentry error.

| Value | Description |
| ----- | ----------- |
| `IGNORED` | Error has been ignored. |
| `RESOLVED` | Error has been resolved. |
| `RESOLVED_IN_NEXT_RELEASE` | Error has been ignored until next release. |
| `UNRESOLVED` | Error is unresolved. |

### `ServiceType`

| Value | Description |
| ----- | ----------- |
| `ASANA_SERVICE` | AsanaService type |
| `ASSEMBLA_SERVICE` | AssemblaService type |
| `BAMBOO_SERVICE` | BambooService type |
| `BUGZILLA_SERVICE` | BugzillaService type |
| `BUILDKITE_SERVICE` | BuildkiteService type |
| `CAMPFIRE_SERVICE` | CampfireService type |
| `CONFLUENCE_SERVICE` | ConfluenceService type |
| `CUSTOM_ISSUE_TRACKER_SERVICE` | CustomIssueTrackerService type |
| `DATADOG_SERVICE` | DatadogService type |
| `DISCORD_SERVICE` | DiscordService type |
| `DRONE_CI_SERVICE` | DroneCiService type |
| `EMAILS_ON_PUSH_SERVICE` | EmailsOnPushService type |
| `EWM_SERVICE` | EwmService type |
| `EXTERNAL_WIKI_SERVICE` | ExternalWikiService type |
| `FLOWDOCK_SERVICE` | FlowdockService type |
| `GITHUB_SERVICE` | GithubService type |
| `HANGOUTS_CHAT_SERVICE` | HangoutsChatService type |
| `HIPCHAT_SERVICE` | HipchatService type |
| `IRKER_SERVICE` | IrkerService type |
| `JENKINS_SERVICE` | JenkinsService type |
| `JIRA_SERVICE` | JiraService type |
| `MATTERMOST_SERVICE` | MattermostService type |
| `MATTERMOST_SLASH_COMMANDS_SERVICE` | MattermostSlashCommandsService type |
| `MICROSOFT_TEAMS_SERVICE` | MicrosoftTeamsService type |
| `PACKAGIST_SERVICE` | PackagistService type |
| `PIPELINES_EMAIL_SERVICE` | PipelinesEmailService type |
| `PIVOTALTRACKER_SERVICE` | PivotaltrackerService type |
| `PROMETHEUS_SERVICE` | PrometheusService type |
| `PUSHOVER_SERVICE` | PushoverService type |
| `REDMINE_SERVICE` | RedmineService type |
| `SLACK_SERVICE` | SlackService type |
| `SLACK_SLASH_COMMANDS_SERVICE` | SlackSlashCommandsService type |
| `TEAMCITY_SERVICE` | TeamcityService type |
| `UNIFY_CIRCUIT_SERVICE` | UnifyCircuitService type |
| `WEBEX_TEAMS_SERVICE` | WebexTeamsService type |
| `YOUTRACK_SERVICE` | YoutrackService type |

### `SnippetBlobActionEnum`

Type of a snippet blob input action.

| Value | Description |
| ----- | ----------- |
| `create` |  |
| `delete` |  |
| `move` |  |
| `update` |  |

### `Sort`

Common sort values.

| Value | Description |
| ----- | ----------- |
| `CREATED_ASC` | Created at ascending order. |
| `CREATED_DESC` | Created at descending order. |
| `UPDATED_ASC` | Updated at ascending order. |
| `UPDATED_DESC` | Updated at descending order. |
| `created_asc` **{warning-solid}** | **Deprecated:** Use CREATED_ASC. Deprecated in 13.5. |
| `created_desc` **{warning-solid}** | **Deprecated:** Use CREATED_DESC. Deprecated in 13.5. |
| `updated_asc` **{warning-solid}** | **Deprecated:** Use UPDATED_ASC. Deprecated in 13.5. |
| `updated_desc` **{warning-solid}** | **Deprecated:** Use UPDATED_DESC. Deprecated in 13.5. |

### `TestReportState`

State of a test report.

| Value | Description |
| ----- | ----------- |
| `FAILED` |  |
| `PASSED` |  |

### `TodoActionEnum`

| Value | Description |
| ----- | ----------- |
| `approval_required` | User was set as an approver. |
| `assigned` | User was assigned. |
| `build_failed` | Build triggered by the user failed. |
| `directly_addressed` | User was directly addressed. |
| `marked` | User added a TODO. |
| `mentioned` | User was mentioned. |
| `merge_train_removed` | Merge request authored by the user was removed from the merge train. |
| `review_requested` | Review was requested from the user. |
| `unmergeable` | Merge request authored by the user could not be merged. |

### `TodoStateEnum`

| Value | Description |
| ----- | ----------- |
| `done` | The state of the todo is done. |
| `pending` | The state of the todo is pending. |

### `TodoTargetEnum`

| Value | Description |
| ----- | ----------- |
| `ALERT` | An Alert. |
| `COMMIT` | A Commit. |
| `DESIGN` | A Design. |
| `EPIC` | An Epic. |
| `ISSUE` | An Issue. |
| `MERGEREQUEST` | A MergeRequest. |

### `TypeEnum`

| Value | Description |
| ----- | ----------- |
| `personal` |  |
| `project` |  |

### `UserCalloutFeatureNameEnum`

Name of the feature that the callout is for.

| Value | Description |
| ----- | ----------- |
| `ACCOUNT_RECOVERY_REGULAR_CHECK` | Callout feature name for account_recovery_regular_check. |
| `ACTIVE_USER_COUNT_THRESHOLD` | Callout feature name for active_user_count_threshold. |
| `ADMIN_INTEGRATIONS_MOVED` | Callout feature name for admin_integrations_moved. |
| `BUY_PIPELINE_MINUTES_NOTIFICATION_DOT` | Callout feature name for buy_pipeline_minutes_notification_dot. |
| `CANARY_DEPLOYMENT` | Callout feature name for canary_deployment. |
| `CLUSTER_SECURITY_WARNING` | Callout feature name for cluster_security_warning. |
| `CUSTOMIZE_HOMEPAGE` | Callout feature name for customize_homepage. |
| `EOA_BRONZE_PLAN_BANNER` | Callout feature name for eoa_bronze_plan_banner. |
| `FEATURE_FLAGS_NEW_VERSION` | Callout feature name for feature_flags_new_version. |
| `GCP_SIGNUP_OFFER` | Callout feature name for gcp_signup_offer. |
| `GEO_ENABLE_HASHED_STORAGE` | Callout feature name for geo_enable_hashed_storage. |
| `GEO_MIGRATE_HASHED_STORAGE` | Callout feature name for geo_migrate_hashed_storage. |
| `GKE_CLUSTER_INTEGRATION` | Callout feature name for gke_cluster_integration. |
| `GOLD_TRIAL_BILLINGS` | Callout feature name for gold_trial_billings. |
| `NEW_USER_SIGNUPS_CAP_REACHED` | Callout feature name for new_user_signups_cap_reached. |
| `PERSONAL_ACCESS_TOKEN_EXPIRY` | Callout feature name for personal_access_token_expiry. |
| `REGISTRATION_ENABLED_CALLOUT` | Callout feature name for registration_enabled_callout. |
| `SERVICE_TEMPLATES_DEPRECATED` | Callout feature name for service_templates_deprecated. |
| `SUGGEST_PIPELINE` | Callout feature name for suggest_pipeline. |
| `SUGGEST_POPOVER_DISMISSED` | Callout feature name for suggest_popover_dismissed. |
| `TABS_POSITION_HIGHLIGHT` | Callout feature name for tabs_position_highlight. |
| `THREAT_MONITORING_INFO` | Callout feature name for threat_monitoring_info. |
| `ULTIMATE_TRIAL` | Callout feature name for ultimate_trial. |
| `UNFINISHED_TAG_CLEANUP_CALLOUT` | Callout feature name for unfinished_tag_cleanup_callout. |
| `WEBHOOKS_MOVED` | Callout feature name for webhooks_moved. |
| `WEB_IDE_ALERT_DISMISSED` | Callout feature name for web_ide_alert_dismissed. |

### `UserState`

Possible states of a user.

| Value | Description |
| ----- | ----------- |
| `active` | The user is active and is able to use the system. |
| `blocked` | The user has been blocked and is prevented from using the system. |
| `deactivated` | The user is no longer active and is unable to use the system. |

### `VisibilityLevelsEnum`

| Value | Description |
| ----- | ----------- |
| `internal` | Internal visibility level. |
| `private` | Private visibility level. |
| `public` | Public visibility level. |

### `VisibilityScopesEnum`

| Value | Description |
| ----- | ----------- |
| `internal` |  |
| `private` |  |
| `public` |  |

### `VulnerabilityDismissalReason`

The dismissal reason of the Vulnerability.

| Value | Description |
| ----- | ----------- |
| `ACCEPTABLE_RISK` | The likelihood of the Vulnerability occurring and its impact are deemed acceptable |
| `FALSE_POSITIVE` | The Vulnerability was incorrectly identified as being present |
| `MITIGATING_CONTROL` | There is a mitigating control that eliminates the Vulnerability or makes its risk acceptable |
| `NOT_APPLICABLE` | Other reasons for dismissal |
| `USED_IN_TESTS` | The Vulnerability is used in tests and does not pose an actual risk |

### `VulnerabilityExternalIssueLinkExternalTracker`

The external tracker of the external issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `JIRA` | Jira external tracker |

### `VulnerabilityExternalIssueLinkType`

The type of the external issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `CREATED` | Created link type |

### `VulnerabilityGrade`

The grade of the vulnerable project.

| Value | Description |
| ----- | ----------- |
| `A` |  |
| `B` |  |
| `C` |  |
| `D` |  |
| `F` |  |

### `VulnerabilityIssueLinkType`

The type of the issue link related to a vulnerability.

| Value | Description |
| ----- | ----------- |
| `CREATED` |  |
| `RELATED` |  |

### `VulnerabilityReportType`

The type of the security scan that found the vulnerability.

| Value | Description |
| ----- | ----------- |
| `API_FUZZING` |  |
| `CONTAINER_SCANNING` |  |
| `COVERAGE_FUZZING` |  |
| `DAST` |  |
| `DEPENDENCY_SCANNING` |  |
| `SAST` |  |
| `SECRET_DETECTION` |  |

### `VulnerabilitySeverity`

The severity of the vulnerability.

| Value | Description |
| ----- | ----------- |
| `CRITICAL` |  |
| `HIGH` |  |
| `INFO` |  |
| `LOW` |  |
| `MEDIUM` |  |
| `UNKNOWN` |  |

### `VulnerabilitySort`

Vulnerability sort values.

| Value | Description |
| ----- | ----------- |
| `detected_asc` | Detection timestamp in ascending order. |
| `detected_desc` | Detection timestamp in descending order. |
| `report_type_asc` | Report Type in ascending order. |
| `report_type_desc` | Report Type in descending order. |
| `severity_asc` | Severity in ascending order. |
| `severity_desc` | Severity in descending order. |
| `state_asc` | State in ascending order. |
| `state_desc` | State in descending order. |
| `title_asc` | Title in ascending order. |
| `title_desc` | Title in descending order. |

### `VulnerabilityState`

The state of the vulnerability.

| Value | Description |
| ----- | ----------- |
| `CONFIRMED` |  |
| `DETECTED` |  |
| `DISMISSED` |  |
| `RESOLVED` |  |

## Scalar types

Scalar values are atomic values, and do not have fields of their own.
Basic scalars include strings, boolean values, and numbers. This schema also
defines various custom scalar values, such as types for times and dates.

This schema includes custom scalar types for identifiers, with a specific type for
each kind of object.

For more information, read about [Scalar Types](https://graphql.org/learn/schema/#scalar-types) on `graphql.org`.

### `AlertManagementHttpIntegrationID`

A `AlertManagementHttpIntegrationID` is a global ID. It is encoded as a string.

An example `AlertManagementHttpIntegrationID` is: `"gid://gitlab/AlertManagement::HttpIntegration/1"`.

### `AnalyticsDevopsAdoptionSegmentID`

A `AnalyticsDevopsAdoptionSegmentID` is a global ID. It is encoded as a string.

An example `AnalyticsDevopsAdoptionSegmentID` is: `"gid://gitlab/Analytics::DevopsAdoption::Segment/1"`.

### `AwardableID`

A `AwardableID` is a global ID. It is encoded as a string.

An example `AwardableID` is: `"gid://gitlab/Awardable/1"`.

### `BigInt`

Represents non-fractional signed whole numeric values. Since the value may exceed the size of a 32-bit integer, it's encoded as a string.

### `BoardID`

A `BoardID` is a global ID. It is encoded as a string.

An example `BoardID` is: `"gid://gitlab/Board/1"`.

### `BoardsEpicBoardID`

A `BoardsEpicBoardID` is a global ID. It is encoded as a string.

An example `BoardsEpicBoardID` is: `"gid://gitlab/Boards::EpicBoard/1"`.

### `BoardsEpicListID`

A `BoardsEpicListID` is a global ID. It is encoded as a string.

An example `BoardsEpicListID` is: `"gid://gitlab/Boards::EpicList/1"`.

### `Boolean`

Represents `true` or `false` values.

### `CiPipelineID`

A `CiPipelineID` is a global ID. It is encoded as a string.

An example `CiPipelineID` is: `"gid://gitlab/Ci::Pipeline/1"`.

### `ClustersAgentID`

A `ClustersAgentID` is a global ID. It is encoded as a string.

An example `ClustersAgentID` is: `"gid://gitlab/Clusters::Agent/1"`.

### `ClustersAgentTokenID`

A `ClustersAgentTokenID` is a global ID. It is encoded as a string.

An example `ClustersAgentTokenID` is: `"gid://gitlab/Clusters::AgentToken/1"`.

### `ClustersClusterID`

A `ClustersClusterID` is a global ID. It is encoded as a string.

An example `ClustersClusterID` is: `"gid://gitlab/Clusters::Cluster/1"`.

### `ComplianceManagementFrameworkID`

A `ComplianceManagementFrameworkID` is a global ID. It is encoded as a string.

An example `ComplianceManagementFrameworkID` is: `"gid://gitlab/ComplianceManagement::Framework/1"`.

### `ContainerRepositoryID`

A `ContainerRepositoryID` is a global ID. It is encoded as a string.

An example `ContainerRepositoryID` is: `"gid://gitlab/ContainerRepository/1"`.

### `CustomEmojiID`

A `CustomEmojiID` is a global ID. It is encoded as a string.

An example `CustomEmojiID` is: `"gid://gitlab/CustomEmoji/1"`.

### `DastProfileID`

A `DastProfileID` is a global ID. It is encoded as a string.

An example `DastProfileID` is: `"gid://gitlab/Dast::Profile/1"`.

### `DastScannerProfileID`

A `DastScannerProfileID` is a global ID. It is encoded as a string.

An example `DastScannerProfileID` is: `"gid://gitlab/DastScannerProfile/1"`.

### `DastSiteProfileID`

A `DastSiteProfileID` is a global ID. It is encoded as a string.

An example `DastSiteProfileID` is: `"gid://gitlab/DastSiteProfile/1"`.

### `DastSiteTokenID`

A `DastSiteTokenID` is a global ID. It is encoded as a string.

An example `DastSiteTokenID` is: `"gid://gitlab/DastSiteToken/1"`.

### `DastSiteValidationID`

A `DastSiteValidationID` is a global ID. It is encoded as a string.

An example `DastSiteValidationID` is: `"gid://gitlab/DastSiteValidation/1"`.

### `Date`

Date represented in ISO 8601.

### `DesignManagementDesignAtVersionID`

A `DesignManagementDesignAtVersionID` is a global ID. It is encoded as a string.

An example `DesignManagementDesignAtVersionID` is: `"gid://gitlab/DesignManagement::DesignAtVersion/1"`.

### `DesignManagementDesignID`

A `DesignManagementDesignID` is a global ID. It is encoded as a string.

An example `DesignManagementDesignID` is: `"gid://gitlab/DesignManagement::Design/1"`.

### `DesignManagementVersionID`

A `DesignManagementVersionID` is a global ID. It is encoded as a string.

An example `DesignManagementVersionID` is: `"gid://gitlab/DesignManagement::Version/1"`.

### `DiffNoteID`

A `DiffNoteID` is a global ID. It is encoded as a string.

An example `DiffNoteID` is: `"gid://gitlab/DiffNote/1"`.

### `DiscussionID`

A `DiscussionID` is a global ID. It is encoded as a string.

An example `DiscussionID` is: `"gid://gitlab/Discussion/1"`.

### `EnvironmentID`

A `EnvironmentID` is a global ID. It is encoded as a string.

An example `EnvironmentID` is: `"gid://gitlab/Environment/1"`.

### `EpicID`

A `EpicID` is a global ID. It is encoded as a string.

An example `EpicID` is: `"gid://gitlab/Epic/1"`.

### `EpicTreeSortingID`

A `EpicTreeSortingID` is a global ID. It is encoded as a string.

An example `EpicTreeSortingID` is: `"gid://gitlab/EpicTreeSorting/1"`.

### `Float`

Represents signed double-precision fractional values as specified by [IEEE 754](https://en.wikipedia.org/wiki/IEEE_floating_point).

### `GitlabErrorTrackingDetailedErrorID`

A `GitlabErrorTrackingDetailedErrorID` is a global ID. It is encoded as a string.

An example `GitlabErrorTrackingDetailedErrorID` is: `"gid://gitlab/Gitlab::ErrorTracking::DetailedError/1"`.

### `GroupID`

A `GroupID` is a global ID. It is encoded as a string.

An example `GroupID` is: `"gid://gitlab/Group/1"`.

### `ID`

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as `"VXNlci0xMA=="`) or integer (such as `4`) input value will be accepted as an ID.

### `ISO8601Date`

An ISO 8601-encoded date.

### `IncidentManagementOncallParticipantID`

A `IncidentManagementOncallParticipantID` is a global ID. It is encoded as a string.

An example `IncidentManagementOncallParticipantID` is: `"gid://gitlab/IncidentManagement::OncallParticipant/1"`.

### `IncidentManagementOncallRotationID`

A `IncidentManagementOncallRotationID` is a global ID. It is encoded as a string.

An example `IncidentManagementOncallRotationID` is: `"gid://gitlab/IncidentManagement::OncallRotation/1"`.

### `Int`

Represents non-fractional signed whole numeric values. Int can represent values between -(2^31) and 2^31 - 1.

### `IssueID`

A `IssueID` is a global ID. It is encoded as a string.

An example `IssueID` is: `"gid://gitlab/Issue/1"`.

### `IterationID`

A `IterationID` is a global ID. It is encoded as a string.

An example `IterationID` is: `"gid://gitlab/Iteration/1"`.

### `IterationsCadenceID`

A `IterationsCadenceID` is a global ID. It is encoded as a string.

An example `IterationsCadenceID` is: `"gid://gitlab/Iterations::Cadence/1"`.

### `JSON`

Represents untyped JSON.

### `JsonString`

JSON object as raw string.

### `LabelID`

A `LabelID` is a global ID. It is encoded as a string.

An example `LabelID` is: `"gid://gitlab/Label/1"`.

### `ListID`

A `ListID` is a global ID. It is encoded as a string.

An example `ListID` is: `"gid://gitlab/List/1"`.

### `MergeRequestID`

A `MergeRequestID` is a global ID. It is encoded as a string.

An example `MergeRequestID` is: `"gid://gitlab/MergeRequest/1"`.

### `MetricsDashboardAnnotationID`

A `MetricsDashboardAnnotationID` is a global ID. It is encoded as a string.

An example `MetricsDashboardAnnotationID` is: `"gid://gitlab/Metrics::Dashboard::Annotation/1"`.

### `MilestoneID`

A `MilestoneID` is a global ID. It is encoded as a string.

An example `MilestoneID` is: `"gid://gitlab/Milestone/1"`.

### `NamespaceID`

A `NamespaceID` is a global ID. It is encoded as a string.

An example `NamespaceID` is: `"gid://gitlab/Namespace/1"`.

### `NoteID`

A `NoteID` is a global ID. It is encoded as a string.

An example `NoteID` is: `"gid://gitlab/Note/1"`.

### `NoteableID`

A `NoteableID` is a global ID. It is encoded as a string.

An example `NoteableID` is: `"gid://gitlab/Noteable/1"`.

### `PackagesPackageID`

A `PackagesPackageID` is a global ID. It is encoded as a string.

An example `PackagesPackageID` is: `"gid://gitlab/Packages::Package/1"`.

### `ProjectID`

A `ProjectID` is a global ID. It is encoded as a string.

An example `ProjectID` is: `"gid://gitlab/Project/1"`.

### `PrometheusServiceID`

A `PrometheusServiceID` is a global ID. It is encoded as a string.

An example `PrometheusServiceID` is: `"gid://gitlab/PrometheusService/1"`.

### `ReleasesLinkID`

A `ReleasesLinkID` is a global ID. It is encoded as a string.

An example `ReleasesLinkID` is: `"gid://gitlab/Releases::Link/1"`.

### `SnippetID`

A `SnippetID` is a global ID. It is encoded as a string.

An example `SnippetID` is: `"gid://gitlab/Snippet/1"`.

### `String`

Represents textual data as UTF-8 character sequences. This type is most often used by GraphQL to represent free-form human-readable text.

### `TerraformStateID`

A `TerraformStateID` is a global ID. It is encoded as a string.

An example `TerraformStateID` is: `"gid://gitlab/Terraform::State/1"`.

### `Time`

Time represented in ISO 8601.

For example: "2021-03-09T14:58:50+00:00".

See `https://www.iso.org/iso-8601-date-and-time-format.html`.

### `TodoID`

A `TodoID` is a global ID. It is encoded as a string.

An example `TodoID` is: `"gid://gitlab/Todo/1"`.

### `TodoableID`

A `TodoableID` is a global ID. It is encoded as a string.

An example `TodoableID` is: `"gid://gitlab/Todoable/1"`.

### `UntrustedRegexp`

A regexp containing patterns sourced from user input.

### `Upload`

### `UserID`

A `UserID` is a global ID. It is encoded as a string.

An example `UserID` is: `"gid://gitlab/User/1"`.

### `VulnerabilitiesExternalIssueLinkID`

A `VulnerabilitiesExternalIssueLinkID` is a global ID. It is encoded as a string.

An example `VulnerabilitiesExternalIssueLinkID` is: `"gid://gitlab/Vulnerabilities::ExternalIssueLink/1"`.

### `VulnerabilityID`

A `VulnerabilityID` is a global ID. It is encoded as a string.

An example `VulnerabilityID` is: `"gid://gitlab/Vulnerability/1"`.

## Abstract types

Abstract types (unions and interfaces) are ways the schema can represent
values that may be one of several concrete types.

- A [`Union`](https://graphql.org/learn/schema/#union-types) is a set of possible types.
  The types might not have any fields in common.
- An [`Interface`](https://graphql.org/learn/schema/#interfaces) is a defined set of fields.
  Types may `implement` an interface, which
  guarantees that they have all the fields in the set. A type may implement more than
  one interface.

See the [GraphQL documentation](https://graphql.org/learn/) for more information on using
abstract types.

### Unions

#### `PackageMetadata`

Represents metadata associated with a Package.

One of:

- [`ComposerMetadata`](#composermetadata)

#### `VulnerabilityDetail`

Represents a vulnerability detail field. The fields with data will depend on the vulnerability detail type.

One of:

- [`VulnerabilityDetailBase`](#vulnerabilitydetailbase)
- [`VulnerabilityDetailBoolean`](#vulnerabilitydetailboolean)
- [`VulnerabilityDetailCode`](#vulnerabilitydetailcode)
- [`VulnerabilityDetailCommit`](#vulnerabilitydetailcommit)
- [`VulnerabilityDetailDiff`](#vulnerabilitydetaildiff)
- [`VulnerabilityDetailFileLocation`](#vulnerabilitydetailfilelocation)
- [`VulnerabilityDetailInt`](#vulnerabilitydetailint)
- [`VulnerabilityDetailList`](#vulnerabilitydetaillist)
- [`VulnerabilityDetailMarkdown`](#vulnerabilitydetailmarkdown)
- [`VulnerabilityDetailModuleLocation`](#vulnerabilitydetailmodulelocation)
- [`VulnerabilityDetailTable`](#vulnerabilitydetailtable)
- [`VulnerabilityDetailText`](#vulnerabilitydetailtext)
- [`VulnerabilityDetailUrl`](#vulnerabilitydetailurl)

#### `VulnerabilityLocation`

Represents a vulnerability location. The fields with data will depend on the vulnerability report type.

One of:

- [`VulnerabilityLocationContainerScanning`](#vulnerabilitylocationcontainerscanning)
- [`VulnerabilityLocationCoverageFuzzing`](#vulnerabilitylocationcoveragefuzzing)
- [`VulnerabilityLocationDast`](#vulnerabilitylocationdast)
- [`VulnerabilityLocationDependencyScanning`](#vulnerabilitylocationdependencyscanning)
- [`VulnerabilityLocationSast`](#vulnerabilitylocationsast)
- [`VulnerabilityLocationSecretDetection`](#vulnerabilitylocationsecretdetection)

### Interfaces

#### `AlertManagementIntegration`

Implementations:

- [`AlertManagementHttpIntegration`](#alertmanagementhttpintegration)
- [`AlertManagementPrometheusIntegration`](#alertmanagementprometheusintegration)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Whether the endpoint is currently accepting alerts. |
| `apiUrl` | [`String`](#string) | URL at which Prometheus metrics can be queried to populate the metrics dashboard. |
| `id` | [`ID!`](#id) | ID of the integration. |
| `name` | [`String`](#string) | Name of the integration. |
| `token` | [`String`](#string) | Token used to authenticate alert notification requests. |
| `type` | [`AlertManagementIntegrationType!`](#alertmanagementintegrationtype) | Type of integration. |
| `url` | [`String`](#string) | Endpoint which accepts alert notifications. |

#### `CurrentUserTodos`

Implementations:

- [`BoardEpic`](#boardepic)
- [`Design`](#design)
- [`Epic`](#epic)
- [`EpicIssue`](#epicissue)
- [`Issue`](#issue)
- [`MergeRequest`](#mergerequest)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `currentUserTodos` | [`TodoConnection!`](#todoconnection) | To-do items for the current user. |

#### `DesignFields`

Implementations:

- [`Design`](#design)
- [`DesignAtVersion`](#designatversion)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `diffRefs` | [`DiffRefs!`](#diffrefs) | The diff refs for this design. |
| `event` | [`DesignVersionEvent!`](#designversionevent) | How this design was changed in the current version. |
| `filename` | [`String!`](#string) | The filename of the design. |
| `fullPath` | [`String!`](#string) | The full path to the design file. |
| `id` | [`ID!`](#id) | The ID of this design. |
| `image` | [`String!`](#string) | The URL of the full-sized image. |
| `imageV432x230` | [`String`](#string) | The URL of the design resized to fit within the bounds of 432x230. This will be `null` if the image has not been generated |
| `issue` | [`Issue!`](#issue) | The issue the design belongs to. |
| `notesCount` | [`Int!`](#int) | The total count of user-created notes for this design. |
| `project` | [`Project!`](#project) | The project the design belongs to. |

#### `Entry`

Implementations:

- [`Blob`](#blob)
- [`Submodule`](#submodule)
- [`TreeEntry`](#treeentry)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `flatPath` | [`String!`](#string) | Flat path of the entry. |
| `id` | [`ID!`](#id) | ID of the entry. |
| `name` | [`String!`](#string) | Name of the entry. |
| `path` | [`String!`](#string) | Path of the entry. |
| `sha` | [`String!`](#string) | Last commit SHA for the entry. |
| `type` | [`EntryType!`](#entrytype) | Type of tree entry. |

#### `Eventable`

Implementations:

- [`BoardEpic`](#boardepic)
- [`Epic`](#epic)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `events` | [`EventConnection`](#eventconnection) | A list of events associated with the object. |

#### `MemberInterface`

Implementations:

- [`GroupMember`](#groupmember)
- [`ProjectMember`](#projectmember)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `accessLevel` | [`AccessLevel`](#accesslevel) | GitLab::Access level. |
| `createdAt` | [`Time`](#time) | Date and time the membership was created. |
| `createdBy` | [`User`](#user) | User that authorized membership. |
| `expiresAt` | [`Time`](#time) | Date and time the membership expires. |
| `id` | [`ID!`](#id) | ID of the member. |
| `updatedAt` | [`Time`](#time) | Date and time the membership was last updated. |
| `user` | [`User!`](#user) | User that is associated with the member object. |

#### `Noteable`

Implementations:

- [`AlertManagementAlert`](#alertmanagementalert)
- [`BoardEpic`](#boardepic)
- [`Design`](#design)
- [`Epic`](#epic)
- [`EpicIssue`](#epicissue)
- [`Issue`](#issue)
- [`MergeRequest`](#mergerequest)
- [`Snippet`](#snippet)
- [`Vulnerability`](#vulnerability)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `discussions` | [`DiscussionConnection!`](#discussionconnection) | All discussions on this noteable. |
| `notes` | [`NoteConnection!`](#noteconnection) | All notes on this noteable. |

#### `ResolvableInterface`

Implementations:

- [`Discussion`](#discussion)
- [`Note`](#note)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `resolvable` | [`Boolean!`](#boolean) | Indicates if the object can be resolved. |
| `resolved` | [`Boolean!`](#boolean) | Indicates if the object is resolved. |
| `resolvedAt` | [`Time`](#time) | Timestamp of when the object was resolved. |
| `resolvedBy` | [`User`](#user) | User who resolved the object. |

#### `Service`

Implementations:

- [`BaseService`](#baseservice)
- [`JiraService`](#jiraservice)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `active` | [`Boolean`](#boolean) | Indicates if the service is active. |
| `type` | [`String`](#string) | Class name of the service. |

#### `TimeboxReportInterface`

Implementations:

- [`Iteration`](#iteration)
- [`Milestone`](#milestone)

| Field | Type | Description |
| ----- | ---- | ----------- |
| `report` | [`TimeboxReport`](#timeboxreport) | Historically accurate report about the timebox. |
